@@ -29,7 +29,7 @@
 
 #include "../utils/cbuffer_t.h"
 
-#include "../vehicle/simvehicle.h"
+#include "../vehicle/vehicle.h"
 
 
 /* The flesh for the place with road for headquarters searcher ... */
@@ -472,7 +472,7 @@ bool ai_t::create_simple_road_transport(koord platz1, koord size1, koord platz2,
 	}
 
 	// is there already a connection?
-	// get a default vehikel
+	// get a default vehicle
 	vehicle_desc_t test_desc(road_wt, 25, vehicle_desc_t::diesel );
 	vehicle_t* test_driver = vehicle_builder_t::build(welt->lookup_kartenboden(platz1)->get_pos(), this, NULL, &test_desc);
 	test_driver->set_flag( obj_t::not_on_map );
@@ -536,10 +536,14 @@ DBG_MESSAGE("ai_passenger_t::create_simple_road_transport()","Already connection
 
 
 /* create new AI */
-ai_t::ai_t(uint8 nr) : player_t( nr )
+ai_t::ai_t(uint8 nr) :
+	player_t( nr ),
+	road_transport(false),
+	rail_transport(false),
+	ship_transport(false),
+	air_transport(false),
+	construction_speed(env_t::default_ai_construction_speed)
 {
-	road_transport = rail_transport = air_transport = ship_transport = false;
-	construction_speed = env_t::default_ai_construction_speed;
 }
 
 
@@ -560,8 +564,8 @@ void ai_t::rdwr(loadsave_t *file)
 }
 
 
-const vehicle_desc_t *ai_t::vehikel_search(waytype_t typ, const uint32 target_power, const sint32 target_speed, const goods_desc_t * target_freight, bool include_electric)
+const vehicle_desc_t *ai_t::vehicle_search(waytype_t typ, const uint32 target_power, const sint32 target_speed, const goods_desc_t * target_freight, bool include_electric)
 {
 	bool obsolete_allowed = welt->get_settings().get_allow_buying_obsolete_vehicles();
-	return vehicle_builder_t::vehikel_search(typ, welt->get_timeline_year_month(), target_power, target_speed, target_freight, include_electric, !obsolete_allowed);
+	return vehicle_builder_t::vehicle_search(typ, welt->get_timeline_year_month(), target_power, target_speed, target_freight, include_electric, !obsolete_allowed);
 }
