@@ -87,8 +87,8 @@ public:
 	// builds a round between those two places or returns false
 	bool create_simple_road_transport(koord platz1, koord size1, koord platz2, koord size2, const way_desc_t *road );
 
-	/// helper method to call vehicle_builder_t::vehikel_search and fill in time-line related parameters
-	static const vehicle_desc_t *vehikel_search(waytype_t typ, const uint32 target_power, const sint32 target_speed, const goods_desc_t * target_freight, bool include_electric);
+	/// helper method to call vehicle_builder_t::vehicle_search and fill in time-line related parameters
+	static const vehicle_desc_t *vehicle_search(waytype_t typ, const uint32 target_power, const sint32 target_speed, const goods_desc_t * target_freight, bool include_electric);
 };
 
 #endif
