@@ -26,7 +26,7 @@
 #include "../utils/simrandom.h"
 #include "../utils/simstring.h"
 
-#include "../vehicle/simvehicle.h"
+#include "../vehicle/vehicle.h"
 
 #include "ai_passenger.h"
 #include "finance.h"
@@ -59,7 +59,7 @@ bool ai_passenger_t::set_active(bool new_state)
 {
 	// only activate, when there are buses available!
 	if(  new_state  ) {
-		new_state = NULL!=vehikel_search( road_wt, 50, 80, goods_manager_t::passengers, false);
+		new_state = NULL!=vehicle_search( road_wt, 50, 80, goods_manager_t::passengers, false);
 	}
 	return player_t::set_active( new_state );
 }
@@ -172,9 +172,9 @@ koord ai_passenger_t::find_harbour_pos(karte_t* welt, const stadt_t *s )
 }
 
 
-bool ai_passenger_t::create_water_transport_vehikel(const stadt_t* start_stadt, const koord target_pos)
+bool ai_passenger_t::create_water_transport_vehicle(const stadt_t* start_stadt, const koord target_pos)
 {
-	const vehicle_desc_t *v_desc = vehikel_search(water_wt, 10, 40, goods_manager_t::passengers, false);
+	const vehicle_desc_t *v_desc = vehicle_search(water_wt, 10, 40, goods_manager_t::passengers, false);
 	if(v_desc==NULL  ) {
 		// no ship there
 		return false;
@@ -425,20 +425,20 @@ bool ai_passenger_t::create_water_transport_vehikel(const stadt_t* start_stadt,
 	vehicle_t* v = vehicle_builder_t::build( koord3d( start_pos, welt->get_water_hgt( start_pos ) ), this, NULL, v_desc );
 	convoi_t* cnv = new convoi_t(this);
 	cnv->set_name(v->get_desc()->get_name());
-	cnv->add_vehikel( v );
+	cnv->add_vehicle( v );
 	cnv->set_line(line);
 	cnv->start();
 
 	// eventually build a shuttle bus ...
 	if(start_connect_hub.is_bound()  &&  start_connect_hub!=start_hub) {
 		koord stops[2] = { start_harbour+start_dx, start_connect_hub->get_basis_pos() };
-		create_bus_transport_vehikel( stops[1], 1, stops, 2, false );
+		create_bus_transport_vehicle( stops[1], 1, stops, 2, false );
 	}
 
 	// eventually build a airport shuttle bus ...
 	if(end_connect_hub.is_bound()  &&  end_connect_hub!=end_hub) {
 		koord stops[2] = { end_harbour+end_dx, end_connect_hub->get_basis_pos() };
-		create_bus_transport_vehikel( stops[1], 1, stops, 2, false );
+		create_bus_transport_vehicle( stops[1], 1, stops, 2, false );
 	}
 
 	return true;
@@ -569,14 +569,14 @@ halthandle_t ai_passenger_t::build_airport(const stadt_t* city, koord pos, int r
 	// now the airstops (only on single tiles, this will always work
 	const building_desc_t* airstop_desc = hausbauer_t::get_random_station(building_desc_t::generic_stop, air_wt, welt->get_timeline_year_month(), 0 );
 	for(  int i=0;  i<4;  i++  ) {
-		if(  koord_distance(center+koord::nsew[i],bushalt)==1  &&  ribi_t::is_single( welt->lookup_kartenboden(center+koord::nsew[i])->get_weg_ribi_unmasked(air_wt) )  ) {
-			call_general_tool( TOOL_BUILD_STATION, center+koord::nsew[i], airstop_desc->get_name() );
+		if(  koord_distance(center+koord::nesw[i],bushalt)==1  &&  ribi_t::is_single( welt->lookup_kartenboden(center+koord::nesw[i])->get_weg_ribi_unmasked(air_wt) )  ) {
+			call_general_tool( TOOL_BUILD_STATION, center+koord::nesw[i], airstop_desc->get_name() );
 		}
 	}
 	// and now the one far away ...
 	for(  int i=0;  i<4;  i++  ) {
-		if(  koord_distance(center+koord::nsew[i],bushalt)>1  &&  ribi_t::is_single( welt->lookup_kartenboden(center+koord::nsew[i])->get_weg_ribi_unmasked(air_wt) )  ) {
-			call_general_tool( TOOL_BUILD_STATION, center+koord::nsew[i], airstop_desc->get_name() );
+		if(  koord_distance(center+koord::nesw[i],bushalt)>1  &&  ribi_t::is_single( welt->lookup_kartenboden(center+koord::nesw[i])->get_weg_ribi_unmasked(air_wt) )  ) {
+			call_general_tool( TOOL_BUILD_STATION, center+koord::nesw[i], airstop_desc->get_name() );
 		}
 	}
 	// success
@@ -611,9 +611,9 @@ static koord find_airport_pos(karte_t* welt, const stadt_t *s )
 
 /** build airports and planes
  */
-bool ai_passenger_t::create_air_transport_vehikel(const stadt_t *start_stadt, const stadt_t *end_stadt)
+bool ai_passenger_t::create_air_transport_vehicle(const stadt_t *start_stadt, const stadt_t *end_stadt)
 {
-	const vehicle_desc_t *v_desc = vehikel_search(air_wt, 10, 900, goods_manager_t::passengers, false);
+	const vehicle_desc_t *v_desc = vehicle_search(air_wt, 10, 900, goods_manager_t::passengers, false);
 	if(v_desc==NULL) {
 		// no aircraft there
 		return false;
@@ -743,20 +743,20 @@ bool ai_passenger_t::create_air_transport_vehikel(const stadt_t *start_stadt, co
 	vehicle_t* v = vehicle_builder_t::build( start->get_pos(), this, NULL, v_desc);
 	convoi_t* cnv = new convoi_t(this);
 	cnv->set_name(v->get_desc()->get_name());
-	cnv->add_vehikel( v );
+	cnv->add_vehicle( v );
 	cnv->set_line(line);
 	cnv->start();
 
 	// eventually build a airport shuttle bus ...
 	if(start_connect_hub.is_bound()  &&  start_connect_hub!=start_hub) {
 		koord stops[2] = { start_hub->get_basis_pos(), start_connect_hub->get_basis_pos() };
-		create_bus_transport_vehikel( stops[1], 1, stops, 2, false );
+		create_bus_transport_vehicle( stops[1], 1, stops, 2, false );
 	}
 
 	// eventually build a airport shuttle bus ...
 	if(end_connect_hub.is_bound()  &&  end_connect_hub!=end_hub) {
 		koord stops[2] = { end_hub->get_basis_pos(), end_connect_hub->get_basis_pos() };
-		create_bus_transport_vehikel( stops[1], 1, stops, 2, false );
+		create_bus_transport_vehicle( stops[1], 1, stops, 2, false );
 	}
 
 	return true;
@@ -765,9 +765,9 @@ bool ai_passenger_t::create_air_transport_vehikel(const stadt_t *start_stadt, co
 
 /** creates a more general road transport
  */
-void ai_passenger_t::create_bus_transport_vehikel(koord startpos2d,int anz_vehikel,koord *stops,int count,bool do_wait)
+void ai_passenger_t::create_bus_transport_vehicle(koord startpos2d,int vehicle_count,koord *stops,int count,bool do_wait)
 {
-DBG_MESSAGE("ai_passenger_t::create_bus_transport_vehikel()","bus at (%i,%i)",startpos2d.x,startpos2d.y);
+DBG_MESSAGE("ai_passenger_t::create_bus_transport_vehicle()","bus at (%i,%i)",startpos2d.x,startpos2d.y);
 	// now start all vehicle one field before, so they load immediately
 	koord3d startpos = welt->lookup_kartenboden(startpos2d)->get_pos();
 
@@ -783,7 +783,7 @@ DBG_MESSAGE("ai_passenger_t::create_bus_transport_vehikel()","bus at (%i,%i)",st
 	delete schedule;
 
 	// now create all vehicles as convois
-	for(int i=0;  i<anz_vehikel;  i++) {
+	for(int i=0;  i<vehicle_count;  i++) {
 		vehicle_t* v = vehicle_builder_t::build(startpos, this, NULL, road_vehicle);
 		if(  convoihandle_t::is_exhausted()  ) {
 			// too many convois => cannot do anything about this ...
@@ -792,7 +792,7 @@ DBG_MESSAGE("ai_passenger_t::create_bus_transport_vehikel()","bus at (%i,%i)",st
 		convoi_t* cnv = new convoi_t(this);
 		// give the new convoi name from first vehicle
 		cnv->set_name(v->get_desc()->get_name());
-		cnv->add_vehikel( v );
+		cnv->add_vehicle( v );
 
 		cnv->set_line(line);
 		cnv->start();
@@ -815,13 +815,13 @@ void ai_passenger_t::walk_city(linehandle_t const line, grund_t* const start, in
 	for(int r=0; r<4; r++) {
 
 		// a way in our direction?
-		if(  (ribi & ribi_t::nsew[r])==0  ) {
+		if(  (ribi & ribi_t::nesw[r])==0  ) {
 			continue;
 		}
 
 		// ok, if connected, not marked, and not owner by somebody else
 		grund_t *to;
-		if(  start->get_neighbour(to, road_wt, ribi_t::nsew[r] )  &&  !marker->is_marked(to)  &&  check_owner(to->obj_bei(0)->get_owner(),this)  ) {
+		if(  start->get_neighbour(to, road_wt, ribi_t::nesw[r] )  &&  !marker->is_marked(to)  &&  check_owner(to->obj_bei(0)->get_owner(),this)  ) {
 
 			// ok, here is a valid street tile
 			marker->mark(to);
@@ -905,14 +905,14 @@ void ai_passenger_t::cover_city_with_bus_route(koord start_pos, int number_of_st
 	walk_city( line, start, number_of_stops );
 	line->get_schedule()->finish_editing();
 
-	road_vehicle = vehikel_search( road_wt, 1, 50, goods_manager_t::passengers, false);
+	road_vehicle = vehicle_search( road_wt, 1, 50, goods_manager_t::passengers, false);
 	if( line->get_schedule()->get_count()>1  ) {
 		// success: add a bus to the line
 		vehicle_t* v = vehicle_builder_t::build(start->get_pos(), this, NULL, road_vehicle);
 		convoi_t* cnv = new convoi_t(this);
 
 		cnv->set_name(v->get_desc()->get_name());
-		cnv->add_vehikel( v );
+		cnv->add_vehicle( v );
 
 		cnv->set_line(line);
 		cnv->start();
@@ -960,25 +960,32 @@ void ai_passenger_t::step()
 			int count = staedte.get_count();
 			int offset = (count>1) ? simrand(count-1) : 0;
 			// start with previous target
-			const stadt_t* last_start_stadt=start_stadt;
+			const stadt_t* last_start_stadt = start_stadt;
 			start_stadt = end_stadt;
 			end_stadt = NULL;
 			end_attraction = NULL;
 			ziel = NULL;
 			platz2 = koord::invalid;
+
 			// if no previous town => find one
 			if(start_stadt==NULL) {
+				if (staedte.empty()) {
+					return;
+				}
+
 				// larger start town preferred
 				start_stadt = pick_any_weighted(staedte);
 				offset = staedte.index_of(start_stadt);
 			}
+
 DBG_MESSAGE("ai_passenger_t::do_passenger_ki()","using city %s for start",start_stadt->get_name());
 			const halthandle_t start_halt = get_our_hub(start_stadt);
 			// find starting place
 
-if(!start_halt.is_bound()) {
-	DBG_MESSAGE("ai_passenger_t::do_passenger_ki()","new_hub");
-}
+			if(!start_halt.is_bound()) {
+				DBG_MESSAGE("ai_passenger_t::do_passenger_ki()","new_hub");
+			}
+
 			platz1 = start_halt.is_bound() ? start_halt->get_basis_pos() : find_place_for_hub( start_stadt );
 			if(platz1==koord::invalid) {
 				return;
@@ -1122,7 +1129,7 @@ DBG_MESSAGE("ai_passenger_t::do_passenger_ki()","no suitable hub found");
 		// wait for construction semaphore
 		{
 			// we want the fastest we can get!
-			road_vehicle = vehikel_search( road_wt, 50, 80, goods_manager_t::passengers, false);
+			road_vehicle = vehicle_search( road_wt, 50, 80, goods_manager_t::passengers, false);
 			if(road_vehicle!=NULL) {
 				// find the best => AI will never survive
 //				road_weg = way_builder_t::weg_search( road_wt, road_vehicle->get_topspeed(), welt->get_timeline_year_month(),type_flat );
@@ -1169,7 +1176,7 @@ DBG_MESSAGE("ai_passenger_t::do_passenger_ki()","using %s on %s",road_vehicle->g
 				if(ok) {
 					koord list[2]={ platz1, platz2 };
 					// wait only, if target is not a hub but an attraction/factory
-					create_bus_transport_vehikel(platz1,1,list,2,end_stadt==NULL);
+					create_bus_transport_vehicle(platz1,1,list,2,end_stadt==NULL);
 					state = NR_SUCCESS;
 					// tell the player
 					cbuffer_t buf;
@@ -1202,7 +1209,7 @@ DBG_MESSAGE("ai_passenger_t::do_passenger_ki()","using %s on %s",road_vehicle->g
 				break;
 			}
 			if(  end_attraction == NULL  &&  ship_transport  &&
-					create_water_transport_vehikel(start_stadt, end_stadt ? end_stadt->get_pos() : ziel->get_pos().get_2d())) {
+					create_water_transport_vehicle(start_stadt, end_stadt ? end_stadt->get_pos() : ziel->get_pos().get_2d())) {
 				// add two intown routes
 				cover_city_with_bus_route( get_our_hub(start_stadt)->get_basis_pos(), 6);
 				if(end_stadt!=NULL) {
@@ -1231,7 +1238,7 @@ DBG_MESSAGE("ai_passenger_t::do_passenger_ki()","using %s on %s",road_vehicle->g
 		case NR_BAUE_AIRPORT_ROUTE:
 			// try airline (if we are wealthy enough) ...
 			if(  !air_transport  ||  finance->get_history_com_month(1, ATC_CASH) < finance->get_starting_money()  ||
-			     !end_stadt  ||  !create_air_transport_vehikel( start_stadt, end_stadt )  ) {
+			     !end_stadt  ||  !create_air_transport_vehicle( start_stadt, end_stadt )  ) {
 				state = NR_BAUE_CLEAN_UP;
 			}
 			else {
@@ -1303,7 +1310,7 @@ DBG_MESSAGE("ai_passenger_t::do_passenger_ki()","using %s on %s",road_vehicle->g
 							// now try to find new vehicle
 							vehicle_t              const& v       = *line->get_convoy(0)->front();
 							waytype_t              const  wt      = v.get_waytype();
-							vehicle_desc_t const* const  v_desc = vehicle_builder_t::vehikel_search(wt, welt->get_current_month(), 50, welt->get_average_speed(wt), goods_manager_t::passengers, false, true);
+							vehicle_desc_t const* const  v_desc = vehicle_builder_t::vehicle_search(wt, welt->get_current_month(), 50, welt->get_average_speed(wt), goods_manager_t::passengers, false, true);
 							if (!v_desc->is_retired(welt->get_current_month()) && v_desc != v.get_desc()) {
 								// there is a newer one ...
 								for(  uint32 new_capacity=0;  capacity>new_capacity;  new_capacity+=v_desc->get_capacity()) {
@@ -1314,7 +1321,7 @@ DBG_MESSAGE("ai_passenger_t::do_passenger_ki()","using %s on %s",road_vehicle->g
 									vehicle_t* v = vehicle_builder_t::build( line->get_schedule()->entries[0].pos, this, NULL, v_desc  );
 									convoi_t* new_cnv = new convoi_t(this);
 									new_cnv->set_name( v->get_desc()->get_name() );
-									new_cnv->add_vehikel( v );
+									new_cnv->add_vehicle( v );
 									new_cnv->set_line(line);
 									new_cnv->start();
 								}
@@ -1344,7 +1351,7 @@ DBG_MESSAGE("ai_passenger_t::do_passenger_ki()","using %s on %s",road_vehicle->g
 					vehicle_t* const v = vehicle_builder_t::build(line->get_schedule()->entries[0].pos, this, NULL, line->get_convoy(0)->front()->get_desc());
 					convoi_t* new_cnv = new convoi_t(this);
 					new_cnv->set_name( v->get_desc()->get_name() );
-					new_cnv->add_vehikel( v );
+					new_cnv->add_vehicle( v );
 					new_cnv->set_line( line );
 					// on waiting line, wait at alternating stations for load balancing
 					if(  line->get_schedule()->entries[1].minimum_loading==90  &&  line->get_linetype()!=simline_t::truckline  &&  (line->count_convoys()&1)==0  ) {
@@ -1467,7 +1474,7 @@ void ai_passenger_t::finish_rd()
 {
 	if (!road_vehicle) {
 		dbg->warning("ai_passenger_t::finish_rd", "Default road vehicle could not be loaded, searching for one...");
-		road_vehicle = vehikel_search( road_wt, 50, 80, goods_manager_t::passengers, false);
+		road_vehicle = vehicle_search( road_wt, 50, 80, goods_manager_t::passengers, false);
 	}
 
 	if (road_vehicle == NULL) {
