@@ -1,5 +1,11 @@
-#ifndef _API_H_
-#define _API_H_
+/*
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
+ */
+
+#ifndef SCRIPT_API_API_H
+#define SCRIPT_API_API_H
+
 
 /** @file api.h declarations of export functions. */
 
@@ -22,7 +28,7 @@ void export_schedule(HSQUIRRELVM vm);
 void export_simple(HSQUIRRELVM vm);
 void export_string_methods(HSQUIRRELVM vm);  // api_scenario.cc
 void export_tiles(HSQUIRRELVM vm);
-void export_world(HSQUIRRELVM vm);
+void export_world(HSQUIRRELVM vm, bool scenario);
 
 void export_pathfinding(HSQUIRRELVM vm);
 
