@@ -12,7 +12,7 @@
 #include "../api_class.h"
 #include "../api_function.h"
 
-#include "../../simobj.h"
+#include "../../obj/simobj.h"
 #include "../../simdepot.h"
 #include "../../simworld.h"
 #include "../../boden/grund.h"
@@ -25,11 +25,13 @@
 #include "../../obj/leitung2.h"
 #include "../../obj/roadsign.h"
 #include "../../obj/signal.h"
+#include "../../obj/wayobj.h"
 #include "../../player/simplay.h"
 
 // for depot tools
 #include "../../simconvoi.h"
 #include "../../simmenu.h"
+#include "../../descriptor/building_desc.h"
 #include "../../descriptor/vehicle_desc.h"
 
 
@@ -66,10 +68,10 @@ template<class D> struct access_objs {
 				// object or tile disappeared: clear userpointer
 				sq_setinstanceup(vm, index, NULL);
 			}
-			sq_raise_error(vm, "Object of type %s vanished from (%s).", param<D>::squirrel_type, pos.get_str());
+			sq_raise_error(vm, "Object of type %s vanished from (%s).", param<D*>::squirrel_type(), pos.get_str());
 		}
 		else {
-			sq_raise_error(vm, "Object is not of type %s.", param<D>::squirrel_type);
+			sq_raise_error(vm, "Object is not of type %s.", param<D*>::squirrel_type);
 		}
 		return NULL;
 	}
@@ -182,6 +184,7 @@ getpush_obj_pos(label_t, obj_t::label);
 getpush_obj_pos(weg_t, obj_t::way);
 getpush_obj_pos(leitung_t, obj_t::leitung);
 getpush_obj_pos(field_t, obj_t::field);
+getpush_obj_pos(wayobj_t, obj_t::wayobj);
 
 namespace script_api {
 	// each depot has its own class
@@ -257,6 +260,7 @@ SQInteger script_api::param<obj_t*>::push(HSQUIRRELVM vm, obj_t* const& obj)
 		case_resolve_obj(pumpe_t);
 		case_resolve_obj(senke_t);
 
+		case_resolve_obj(wayobj_t);
 		default:
 			return access_objs<obj_t>::push_with_pos(vm, obj);
 	}
@@ -431,6 +435,26 @@ bool field_is_deleteable(field_t* f)
 	return f->is_deletable( welt->get_player(1) ) == NULL;
 }
 
+
+vector_tpl<sint64> const& get_way_stat(weg_t* weg, sint32 INDEX)
+{
+	static vector_tpl<sint64> v;
+	v.clear();
+	if (weg  &&  0<=INDEX  &&  INDEX<WAY_STAT_MAX) {
+		for(uint16 i = 0; i < MAX_WAY_STAT_MONTHS; i++) {
+			v.append( weg->get_stat(i, INDEX) );
+		}
+	}
+	return v;
+}
+
+vector_tpl<grund_t*> const& get_tile_list( gebaeude_t *gb )
+{
+	static vector_tpl<grund_t*> list;
+	gb->get_tile_list( list );
+	return list;
+}
+
 void export_map_objects(HSQUIRRELVM vm)
 {
 	/**
@@ -443,6 +467,7 @@ void export_map_objects(HSQUIRRELVM vm)
 	/**
 	 * Constructor. Implemented by derived classes.
 	 * Fails if no object of precisely the requested type is on the tile.
+	 * If there is more than one object of this type on the tile then it will return the first.
 	 * @param x
 	 * @param y
 	 * @param z
@@ -547,6 +572,10 @@ void export_map_objects(HSQUIRRELVM vm)
 	 * @returns object descriptor.
 	 */
 	register_method(vm, &gebaeude_t::get_tile, "get_desc");
+	/**
+	 * @returns coord for all tiles
+	 */
+	register_method( vm, &get_tile_list, "get_tile_list", true );
 	/**
 	 * @returns true if both building tiles are part of one (multi-tile) building
 	 */
@@ -634,6 +663,22 @@ void export_map_objects(HSQUIRRELVM vm)
 	 * @returns object descriptor.
 	 */
 	register_method(vm, &weg_t::get_desc, "get_desc");
+	/**
+	 * Returns maximal allowed speed on this way.
+	 * Takes limits from crossings, overhead-wires, bridges, etc, into account.
+	 * @returns max speed in kmh.
+	 */
+	register_method(vm, &weg_t::get_max_speed, "get_max_speed");
+	/**
+	 * Get monthly statistics of goods transported on this way.
+	 * @returns array, index [0] corresponds to current month
+	 */
+	register_method_fv(vm, &get_way_stat, "get_transported_goods", freevariable<sint32>(WAY_STAT_GOODS), true);
+	/**
+	 * Get monthly statistics of convoys that used this way.
+	 * @returns array, index [0] corresponds to current month
+	 */
+	register_method_fv(vm, &get_way_stat, "get_convoys_passed",    freevariable<sint32>(WAY_STAT_CONVOIS), true);
 	end_class(vm);
 
 
@@ -721,4 +766,14 @@ void export_map_objects(HSQUIRRELVM vm)
 	 */
 	register_method(vm, &field_t::get_factory, "get_factory");
 	end_class(vm);
+
+	/**
+	 * Way-objects: overhead-wires, fences, etc. Only one such object can exist on a tile.
+	 */
+	begin_obj_class<wayobj_t>(vm, "wayobj_x", "map_object_x");
+	/**
+	 * @returns object descriptor.
+	 */
+	register_method(vm, &wayobj_t::get_desc, "get_desc");
+	end_class(vm);
 }
