@@ -18,13 +18,17 @@
 #include "../../descriptor/vehicle_desc.h"
 #include "../../descriptor/goods_desc.h"
 #include "../../descriptor/roadsign_desc.h"
+#include "../../descriptor/way_obj_desc.h"
+#include "../../descriptor/factory_desc.h"
 #include "../../bauer/brueckenbauer.h"
 #include "../../bauer/hausbauer.h"
+#include "../../bauer/fabrikbauer.h"
 #include "../../bauer/tunnelbauer.h"
 #include "../../bauer/vehikelbauer.h"
 #include "../../bauer/goods_manager.h"
 #include "../../bauer/wegbauer.h"
 #include "../../obj/roadsign.h"
+#include "../../obj/wayobj.h"
 #include "../../simhalt.h"
 #include "../../simware.h"
 #include "../../simworld.h"
@@ -152,9 +156,17 @@ const vector_tpl<const building_desc_t*>& get_available_stations(building_desc_t
 		}
 	}
 
+	// use wt_all (which is equal to invalid_wt, see api_const.cc) to get buildings for all waytypes
+	bool accept_all_wt = wt == invalid_wt  ||  wt == ignore_wt  ||  wt == any_wt;
+
 	uint16 time = welt->get_timeline_year_month();
 	FOR(vector_tpl<building_desc_t const*>, const desc, *p) {
-		if(  desc->get_type()==type  &&  desc->get_extra()==(uint32)wt  &&  (enables==0  ||  (desc->get_enabled()&enables)!=0)  &&  desc->is_available(time)) {
+		if(  desc->get_type()==type
+			&&  (accept_all_wt  ||  desc->get_extra()==(uint32)wt)
+			&&  (enables==0  ||  (desc->get_enabled()&enables)!=0)
+			&&  desc->is_available(time))
+		{
+
 			dummy.append(desc);
 		}
 	}
@@ -251,6 +263,75 @@ bool is_traffic_light(const roadsign_desc_t *d)
 }
 
 
+sint64 tree_get_price()
+{
+	return -welt->get_settings().cst_remove_tree;
+}
+
+
+const vector_tpl<const way_obj_desc_t*>& get_available_wayobjs(waytype_t wt)
+{
+	static vector_tpl<const way_obj_desc_t*> dummy;
+
+	uint16 time = welt->get_timeline_year_month();
+
+	dummy.clear();
+	FOR(stringhashtable_tpl<const way_obj_desc_t*> const, i, wayobj_t::get_list()) {
+		const way_obj_desc_t* desc = i.value;
+		if (desc->get_waytype()==wt  &&  desc->is_available(time)) {
+			dummy.append(desc);
+		}
+	}
+	return dummy;
+}
+
+
+#ifdef DOXYGEN
+/**
+ * Description of input/output slots
+ */
+struct factory_slot_information_x { // begin_class("factory_slot_information_x")
+	good_desc_x good; ///< type of produced/consumed good
+	integer capacity; ///< capacity to store the good
+	integer factor;   ///< production/consumption factor
+}; // end_class
+#endif
+
+SQInteger get_factory_outputs(HSQUIRRELVM vm)
+{
+	const factory_desc_t *desc = param<const factory_desc_t *>::get(vm, -1);
+	sq_newarray(vm, 0);
+	if (desc) {
+		for(uint16 i=0; i<desc->get_product_count(); i++) {
+			const factory_product_desc_t *fp = desc->get_product(i);
+			sq_newtable(vm);
+			create_slot(vm, "good", fp->get_output_type());
+			create_slot(vm, "capacity", fp->get_capacity());
+			create_slot(vm, "factor", fp->get_factor());
+			sq_arrayappend(vm, -2);
+		}
+	}
+	return 1;
+}
+
+SQInteger get_factory_inputs(HSQUIRRELVM vm)
+{
+	const factory_desc_t *desc = param<const factory_desc_t *>::get(vm, -1);
+	sq_newarray(vm, 0);
+	if (desc) {
+		for(uint16 i=0; i<desc->get_supplier_count(); i++) {
+			const factory_supplier_desc_t *fp = desc->get_supplier(i);
+			sq_newtable(vm);
+			create_slot(vm, "good", fp->get_input_type());
+			create_slot(vm, "capacity", fp->get_capacity());
+			create_slot(vm, "factor", fp->get_consumption());
+			sq_arrayappend(vm, -2);
+		}
+	}
+	return 1;
+}
+
+
 void export_goods_desc(HSQUIRRELVM vm)
 {
 	/**
@@ -314,7 +395,7 @@ void export_goods_desc(HSQUIRRELVM vm)
 	 */
 	register_local_method(vm, &get_scaled_maintenance, "get_maintenance");
 	/**
-	 * @returns cost [in 1/100 credits] to buy or build on piece or tile of this thing.
+	 * @returns cost [in 1/100 credits] to buy or build one piece or tile of this thing.
 	 */
 	register_method(vm, &obj_desc_transport_related_t::get_price, "get_cost");
 	/**
@@ -399,6 +480,12 @@ void export_goods_desc(HSQUIRRELVM vm)
 	 * Object descriptors for trees.
 	 */
 	begin_desc_class(vm, "tree_desc_x", "obj_desc_x", (GETDESCFUNC)param<const tree_desc_t*>::getfunc());
+
+	/**
+	 * Returns price to fell one tree.
+	 * @returns price (should be positive)
+	 */
+	STATIC register_method(vm, tree_get_price, "get_price", false, true);
 	end_class(vm);
 
 	/**
@@ -499,7 +586,7 @@ void export_goods_desc(HSQUIRRELVM vm)
 	 * Returns an array of available station/extension/depot buildings.
 	 * Entries are of type @ref building_desc_x.
 	 * @param type building type from @ref building_desc_x::building_type
-	 * @param wt waytype
+	 * @param wt waytype (can be wt_all to ignore waytype of desc)
 	 * @param freight station should accept this freight (if null then return all buildings)
 	 * @returns the list
 	 */
@@ -512,6 +599,49 @@ void export_goods_desc(HSQUIRRELVM vm)
 
 	end_class(vm);
 
+	/**
+	 * Object descriptors for factories.
+	 */
+	begin_desc_class(vm, "factory_desc_x", "obj_desc_x", (GETDESCFUNC)param<const factory_desc_t*>::getfunc());
+	/**
+	 * @returns name
+	 */
+	register_method(vm, &factory_desc_t::get_name, "get_name");
+	/**
+	 * Descriptor of associated building.
+	 */
+	register_method(vm, &factory_desc_t::get_building, "get_building_desc");
+	/**
+	 * @returns true if this factory produces electricity
+	 */
+	register_method(vm, &factory_desc_t::is_electricity_producer, "is_electricity_producer");
+	/**
+	 * Initial production of a factory is get_productivity_base() + rand( get_productivity_range() ).
+	 * @returns base production
+	 */
+	register_method(vm, &factory_desc_t::get_productivity, "get_productivity_base");
+	/**
+	 * @returns base production variable range
+	 */
+	register_method(vm, &factory_desc_t::get_range, "get_productivity_range");
+	/**
+	 * Returns array with information about input goods
+	 * @typemask array<factory_slot_information_x> ()
+	 */
+	register_function(vm, get_factory_inputs, "get_inputs", 1, "t|x|y");
+	/**
+	 * Returns array with information about input goods
+	 * @typemask array<factory_slot_information_x> ()
+	 */
+	register_function(vm, get_factory_outputs, "get_outputs", 1, "t|x|y");
+	/**
+	 * Returns table with all factory types.
+	 * The factory names are used as table keys.
+	 */
+	register_method(vm, &factory_builder_t::get_factory_table, "get_list", 1);
+
+	end_class(vm);
+
 	/**
 	 * Object descriptors for ways.
 	 */
@@ -683,11 +813,24 @@ void export_goods_desc(HSQUIRRELVM vm)
 	 */
 	register_method(vm, &roadsign_desc_t::is_end_choose_signal, "is_end_choose_signal");
 	/**
-	 * Returns a list with available bridge types.
+	 * Returns a list with available sign types.
 	 * @param wt waytype
 	 */
 	STATIC register_method(vm, roadsign_t::get_available_signs, "get_available_signs", false, true);
 
 	end_class(vm);
-
+	/**
+	 * Descriptor of way-objects.
+	 */
+	begin_desc_class(vm, "wayobj_desc_x", "obj_desc_transport_x", (GETDESCFUNC)param<const way_obj_desc_t*>::getfunc());
+	/**
+	 * @returns true for over-head lines.
+	 */
+	register_method(vm, &way_obj_desc_t::is_overhead_line, "is_overhead_line");
+	/**
+	 * Returns a list with available wayobj-types.
+	 * @param wt waytype
+	 */
+	STATIC register_method(vm, get_available_wayobjs, "get_available_wayobjs", false, true);
+	end_class(vm);
 }
