@@ -566,7 +566,7 @@ namespace script_api {
 
 	SQInteger param<schedule_entry_t>::push(HSQUIRRELVM vm, schedule_entry_t const& v)
 	{
-		return push_instance(vm, "schedule_entry_x", v.pos, v.minimum_loading, v.waiting_time_shift);
+		return push_instance(vm, "schedule_entry_x", v.pos, v.minimum_loading, v.waiting_time);
 	}
 
 
