@@ -21,13 +21,10 @@
 #include "scenario_frame.h"
 #include "server_frame.h"
 #include "components/gui_image.h"
+#include "optionen.h"
 
-#define L_LINESPACE_EXTRA_2  ( LINESPACE + 2 )
-#define L_LINESPACE_EXTRA_5  ( LINESPACE + 5 )
-#define L_LINESPACE_EXTRA_7  ( LINESPACE + 7 )
 
 // Local adjustments
-#define L_TEXT_INDENT        ( 24 )                            // Shadow text indent
 #define L_BANNER_ROWS        ( 5 )                             // Rows of scroll text
 #define L_BANNER_TEXT_INDENT ( 4 )                             // Scroll text padding (left/right)
 #define L_BANNER_HEIGHT      ( L_BANNER_ROWS * LINESPACE + 2 ) // Banner control height in pixels
@@ -69,10 +66,14 @@ banner_t::banner_t() : gui_frame_t("")
 	new_component<gui_label_t>("This is Simutrans" SIM_VERSION_BUILD_STRING, SYSCOL_TEXT_TITLE, gui_label_t::left)->set_shadow(SYSCOL_TEXT_SHADOW, true);
 
 #ifdef REVISION
-	new_component<gui_label_t>("Version " VERSION_NUMBER " " VERSION_DATE " r" QUOTEME(REVISION) L_DEBUG_TEXT, SYSCOL_TEXT_HIGHLIGHT, gui_label_t::left)->set_shadow(SYSCOL_TEXT_SHADOW, true);
+	new_component<gui_label_t>("Version " VERSION_NUMBER " " VERSION_DATE " r" QUOTEME(REVISION)
 #else
-	new_component<gui_label_t>("Version " VERSION_NUMBER " " VERSION_DATE L_DEBUG_TEXT, SYSCOL_TEXT_HIGHLIGHT, gui_label_t::left)->set_shadow(SYSCOL_TEXT_SHADOW, true);
+	new_component<gui_label_t>("Version " VERSION_NUMBER " " VERSION_DATE
 #endif
+#ifdef GIT_HASH
+		" hash " QUOTEME(GIT_HASH)
+#endif
+		L_DEBUG_TEXT, SYSCOL_TEXT_HIGHLIGHT, gui_label_t::left)->set_shadow(SYSCOL_TEXT_SHADOW, true);
 
 	add_table(5,0);
 	{
@@ -98,9 +99,9 @@ banner_t::banner_t() : gui_frame_t("")
 	{
 		new_component<gui_fill_t>();
 		add_table(1,0);
-		new_component<gui_label_t>("http://www.simutrans.com", SYSCOL_TEXT_HIGHLIGHT, gui_label_t::left)->set_shadow(SYSCOL_TEXT_SHADOW, true);
-		new_component<gui_label_t>("http://forum.simutrans.com", SYSCOL_TEXT_HIGHLIGHT, gui_label_t::left)->set_shadow(SYSCOL_TEXT_SHADOW, true);
-		new_component<gui_label_t>("http://wiki.simutrans.com", SYSCOL_TEXT_HIGHLIGHT, gui_label_t::left)->set_shadow(SYSCOL_TEXT_SHADOW, true);
+		new_component<gui_label_t>("https://www.simutrans.com", SYSCOL_TEXT_HIGHLIGHT, gui_label_t::left)->set_shadow(SYSCOL_TEXT_SHADOW, true);
+		new_component<gui_label_t>("https://forum.simutrans.com", SYSCOL_TEXT_HIGHLIGHT, gui_label_t::left)->set_shadow(SYSCOL_TEXT_SHADOW, true);
+		new_component<gui_label_t>("https://wiki.simutrans.com", SYSCOL_TEXT_HIGHLIGHT, gui_label_t::left)->set_shadow(SYSCOL_TEXT_SHADOW, true);
 		end_table();
 		new_component<gui_fill_t>();
 	}
@@ -127,7 +128,10 @@ banner_t::banner_t() : gui_frame_t("")
 		load_scenario.add_listener( this );
 		add_component( &load_scenario );
 
-		new_component<gui_empty_t>();
+		// Options button
+		options.init( button_t::roundbox | button_t::flexible, "Optionen");
+		options.add_listener( this );
+		add_component( &options );
 
 		// Play online button
 		join_map.init( button_t::roundbox | button_t::flexible, "join game");
@@ -171,6 +175,10 @@ bool banner_t::action_triggered( gui_action_creator_t *comp, value_t)
 		destroy_all_win(true);
 		create_win( new scenario_frame_t(), w_info, magic_load_t );
 	}
+	else if(  comp == &options  ) {
+		destroy_all_win(true);
+		create_win( new optionen_gui_t(), w_info, magic_optionen_gui_t );
+	}
 	else if(  comp == &join_map  ) {
 		destroy_all_win(true);
 		create_win( new server_frame_t(), w_info, magic_server_frame_t );
@@ -179,14 +187,6 @@ bool banner_t::action_triggered( gui_action_creator_t *comp, value_t)
 }
 
 
-void banner_t::draw(scr_coord pos, scr_size size )
-{
-	gui_frame_t::draw( pos, size );
-
-	// add white line on top since this frame has no title bar.
-	display_fillbox_wh_clip_rgb(pos.x, pos.y, size.w, 1, color_idx_to_rgb(COL_GREY6), false);
-}
-
 void banner_text_t::draw(scr_coord offset)
 {
 	// now the scrolling
