@@ -9,10 +9,9 @@
 
 cd aero
 rm -rf *.pak
-# Aero is somewhat broken, please fix!
-#../makeobj pak aerotheme.pak skins_aero.dat
-#mv *.pak ../../simutrans/themes
-#cp *.tab ../../simutrans/themes
+../makeobj pak aerotheme.pak skins_aero.dat
+mv *.pak ../../simutrans/themes
+cp *.tab ../../simutrans/themes
 
 cd ../flat
 rm -rf *.pak
