@@ -1,12 +1,11 @@
 /*
- * Copyright (c) 1997 - 2002 Hansjrg Malthaner
- *
- * This file is part of the Simutrans project under the artistic license.
- * (see license.txt)
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
  */
 
-#ifndef building_place_finder_t_h
-#define building_place_finder_t_h
+#ifndef FINDER_BUILDING_PLACEFINDER_H
+#define FINDER_BUILDING_PLACEFINDER_H
+
 
 #include "placefinder.h"
 #include "../simworld.h"
@@ -15,8 +14,6 @@
  * building_placefinder_t:
  *
  * Search a free site for building using function find_place().
- *
- * @author V. Meyer
  */
 class building_placefinder_t : public placefinder_t {
 public:
