@@ -33,13 +33,16 @@ private:
 	button_t bt_com;
 	button_t bt_ind;
 
-	void fill_list( bool translate ) OVERRIDE;
+	void fill_list() OVERRIDE;
+	void put_item_in_list( const building_desc_t* desc );
 
 	void change_item_info( sint32 i ) OVERRIDE;
 
 public:
 	citybuilding_edit_frame_t(player_t* player);
 
+	static bool sortreverse;
+
 	/**
 	* in top-level windows the name is displayed in titlebar
 	* @return the non-translated component name
