@@ -1,11 +1,11 @@
 /*
- *  Copyright (c) 1997 - 2002 by Volker Meyer & Hansjrg Malthaner
- *
- * This file is part of the Simutrans project under the artistic licence.
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
  */
 
-#ifndef __CITYCAR_DESC_H
-#define __CITYCAR_DESC_H
+#ifndef DESCRIPTOR_CITYCAR_DESC_H
+#define DESCRIPTOR_CITYCAR_DESC_H
+
 
 #include "obj_base_desc.h"
 #include "image_list.h"
@@ -14,17 +14,13 @@
 #include "../network/checksum.h"
 
 
-/*
- *  Author:
- *      Volker Meyer
+/**
+ * Private city cars, not player owned. They automatically appear in cities.
  *
- *  Description:
- *	Private city cars, not player owned. They automatically appear in cities.
- *
- *  Child nodes:
- *	0   Name
- *	1   Copyright
- *	2   Image-list
+ * Child nodes:
+ *  0   Name
+ *  1   Copyright
+ *  2   Image-list
  */
 class citycar_desc_t : public obj_desc_timelined_t {
 	friend class citycar_reader_t;
