@@ -10,6 +10,7 @@
 #include "../player/simplay.h"
 #include "../dataobj/translator.h"
 #include "../simcolor.h"
+#include "../simhalt.h"
 #include "../dataobj/environment.h"
 #include "../utils/cbuffer_t.h"
 #include "components/gui_button_to_chart.h"
@@ -76,6 +77,9 @@ const uint8 citylist_frame_t::hist_type_type[karte_t::MAX_WORLD_COST] =
 	STANDARD
 };
 
+char citylist_frame_t::name_filter[256] = "";
+
+
 class playername_const_scroll_item_t : public gui_scrolled_list_t::const_text_scrollitem_t {
 public:
 	const uint8 player_nr;
@@ -89,6 +93,7 @@ citylist_frame_t::citylist_frame_t() :
 	scrolly(gui_scrolled_list_t::windowskin, citylist_stats_t::compare)
 {
 	old_city_count = 0;
+	old_halt_count = 0;
 
 	set_table_layout(1,0);
 
@@ -98,22 +103,19 @@ citylist_frame_t::citylist_frame_t() :
 	main.add_tab( &list, translator::translate("City list") );
 
 	list.set_table_layout(1,0);
-	list.new_component<gui_label_t>("hl_txt_sort");
 
-	list.add_table(4,0);
-	sortedby.init(button_t::roundbox, sort_text[citylist_stats_t::sort_mode & 0x1F]);
-	sortedby.add_listener(this);
-	list.add_component(&sortedby);
-
-	sorteddir.init(button_t::roundbox, citylist_stats_t::sort_mode > citylist_stats_t::SORT_MODES ? "hl_btn_sort_desc" : "hl_btn_sort_asc");
-	sorteddir.add_listener(this);
-	list.add_component(&sorteddir);
+	list.add_table(3, 3);
+	list.new_component<gui_label_t>("Filter:");
+	name_filter_input.set_text(name_filter, lengthof(name_filter));
+	list.add_component(&name_filter_input);
+	list.new_component<gui_fill_t>();
 
 	filter_by_owner.init( button_t::square_automatic, "Served by" );
 	filter_by_owner.add_listener(this);
-	filter_by_owner.set_tooltip( "At least one stop is connected to the town" );
+	filter_by_owner.set_tooltip( "At least one stop is connected to the town." );
 	list.add_component(&filter_by_owner);
 
+	filterowner.new_component<gui_scrolled_list_t::const_text_scrollitem_t>(translator::translate("No player"), SYSCOL_TEXT);
 	for( int i = 0; i < MAX_PLAYER_COUNT; i++ ) {
 		if( player_t *pl=welt->get_player(i) ) {
 			filterowner.new_component<playername_const_scroll_item_t>(pl);
@@ -124,6 +126,23 @@ citylist_frame_t::citylist_frame_t() :
 	}
 	filterowner.add_listener(this);
 	list.add_component(&filterowner);
+	list.new_component<gui_fill_t>();
+
+
+	list.new_component<gui_label_t>("hl_txt_sort");
+	sortedby.set_unsorted(); // do not sort
+	for (size_t i = 0; i < lengthof(sort_text); i++) {
+		sortedby.new_component<gui_scrolled_list_t::const_text_scrollitem_t>(translator::translate(sort_text[i]), SYSCOL_TEXT);
+	}
+	sortedby.set_selection(citylist_stats_t::sort_mode & 0x1F);
+	sortedby.add_listener(this);
+	list.add_component(&sortedby);
+
+	sorteddir.init(button_t::sortarrow_state, NULL);
+	sorteddir.pressed = citylist_stats_t::sort_mode > citylist_stats_t::SORT_MODES;
+	sorteddir.add_listener(this);
+	list.add_component(&sorteddir);
+
 
 	list.end_table();
 	list.add_component(&scrolly);
@@ -194,30 +213,49 @@ void citylist_frame_t::fill_list()
 {
 	old_city_count = world()->get_cities().get_count();
 	scrolly.clear_elements();
-	player_t *pl = (filter_by_owner.pressed  &&  filterowner.get_selection()>0) ? world()->get_player(filterowner.get_selection()) : NULL;
-	FOR( const weighted_vector_tpl<stadt_t *>, city, world()->get_cities() ) {
-		if( pl == NULL || city->is_within_players_network( pl ) ) {
-			scrolly.new_component<citylist_stats_t>( city );
+	strcpy(last_name_filter, name_filter);
+	if (filter_by_owner.pressed && filterowner.get_selection() == 0) {
+		FOR(const weighted_vector_tpl<stadt_t*>, city, world()->get_cities()) {
+			bool add = (name_filter[0] == 0 || utf8caseutf8(city->get_name(), name_filter));
+			for (int i = 0; add && i < MAX_PLAYER_COUNT; i++) {
+				if (player_t* pl = welt->get_player(i)) {
+					if (city->is_within_players_network(pl)) {
+						// already connected
+						add = false;
+					}
+				}
+			}
+			if (add) {
+				scrolly.new_component<citylist_stats_t>(city);
+			}
 		}
 	}
+	else {
+		player_t* pl = (filter_by_owner.pressed && filterowner.get_selection() >= 0) ? welt->get_player(((const playername_const_scroll_item_t* )(filterowner.get_selected_item()))->player_nr) : NULL;
+		FOR( const weighted_vector_tpl<stadt_t *>, city, world()->get_cities() ) {
+			if(  pl == NULL  ||  city->is_within_players_network( pl ) ) {
+				if(  last_name_filter[0] == 0  ||  utf8caseutf8(city->get_name(), last_name_filter)  ) {
+					scrolly.new_component<citylist_stats_t>(city);
+				}
+			}
+		}
+	}
+	old_halt_count = haltestelle_t::get_alle_haltestellen().get_count();
 	scrolly.sort(0);
 	scrolly.set_size( scrolly.get_size());
 }
 
 
-bool citylist_frame_t::action_triggered( gui_action_creator_t *comp, value_t)
+bool citylist_frame_t::action_triggered( gui_action_creator_t *comp, value_t v)
 {
 	if(comp == &sortedby) {
-		int i = citylist_stats_t::sort_mode & ~citylist_stats_t::SORT_REVERSE;
-		i = (i + 1) % citylist_stats_t::SORT_MODES;
-		sortedby.set_text(sort_text[i]);
-		citylist_stats_t::sort_mode = (citylist_stats_t::sort_mode_t)(i | (citylist_stats_t::sort_mode & citylist_stats_t::SORT_REVERSE));
+		citylist_stats_t::sort_mode = (citylist_stats_t::sort_mode_t)(v.i | (citylist_stats_t::sort_mode & citylist_stats_t::SORT_REVERSE));
 		scrolly.sort(0);
 	}
 	else if(comp == &sorteddir) {
 		bool reverse = citylist_stats_t::sort_mode <= citylist_stats_t::SORT_MODES;
-		sorteddir.set_text(reverse ? "hl_btn_sort_desc" : "hl_btn_sort_asc");
-		citylist_stats_t::sort_mode = (citylist_stats_t::sort_mode_t)((citylist_stats_t::sort_mode & ~citylist_stats_t::SORT_REVERSE) + (reverse*citylist_stats_t::SORT_REVERSE) );
+		sorteddir.pressed = reverse;
+		citylist_stats_t::sort_mode = (citylist_stats_t::sort_mode_t)((citylist_stats_t::sort_mode & ~citylist_stats_t::SORT_REVERSE) + (reverse * citylist_stats_t::SORT_REVERSE));
 		scrolly.sort(0);
 	}
 	else if(comp == &filterowner) {
@@ -236,10 +274,36 @@ void citylist_frame_t::draw(scr_coord pos, scr_size size)
 {
 	welt->update_history();
 
-	if(  world()->get_cities().get_count() != old_city_count  ) {
+	if(  world()->get_cities().get_count() != old_city_count  ||  strcmp(last_name_filter, name_filter)  ) {
+		fill_list();
+	}
+	else if(  filter_by_owner.pressed  &&  old_halt_count != haltestelle_t::get_alle_haltestellen().get_count()  ) {
 		fill_list();
 	}
 	update_label();
 
 	gui_frame_t::draw(pos, size);
 }
+
+
+void citylist_frame_t::rdwr(loadsave_t* file)
+{
+	scr_size size = get_windowsize();
+	sint16 sort_mode = citylist_stats_t::sort_mode;
+
+	size.rdwr(file);
+	scrolly.rdwr(file);
+	year_month_tabs.rdwr(file);
+	main.rdwr(file);
+	filterowner.rdwr(file);
+	sortedby.rdwr(file);
+	file->rdwr_str(name_filter, lengthof(name_filter));
+	file->rdwr_short(sort_mode);
+	if (file->is_loading()) {
+		citylist_stats_t::sort_mode = (citylist_stats_t::sort_mode_t)sort_mode;
+		bool reverse = citylist_stats_t::sort_mode <= citylist_stats_t::SORT_MODES;
+		sorteddir.pressed = reverse;
+		fill_list();
+		set_windowsize(size);
+	}
+}
