@@ -10,7 +10,11 @@
 #include "../simdebug.h"
 #include "../dataobj/translator.h"
 
+#ifndef __APPLE__
 #include <SDL2/SDL.h>
+#else
+#include <SDL.h>
+#endif
 
 #include <string.h>
 
