@@ -152,6 +152,17 @@ public:
 
 	void enable();
 	void disable();
+	void enable( bool yesno ) {
+		if( yesno && !is_focusable() ) {
+			enable();
+		}
+		else if( !yesno  &&  is_focusable() ) {
+			disable();
+		}
+	}
+
+	// default comoboboxes are sorted!
+	void set_unsorted() { droplist.set_cmp(NULL); }
 
 	// save selection
 	void rdwr( loadsave_t *file );
