@@ -135,20 +135,6 @@ public:
 		return size;
 	}
 
-	/**
-	 * Set this component's width.
-	 */
-	virtual void set_width(scr_coord_val width_par) {
-		set_size(scr_size(width_par,size.h));
-	}
-
-	/**
-	 * Set this component's height.
-	 */
-	virtual void set_height(scr_coord_val height_par) {
-		set_size(scr_size(size.w,height_par));
-	}
-
 	/**
 	 * Get this component's maximal bounding box size.
 	 * If this is larger than get_min_size(), then the element will be enlarged if possible
@@ -283,7 +269,7 @@ class gui_margin_t : public gui_component_t
 public:
 	gui_margin_t(uint margin_x = D_H_SPACE, uint margin_y = D_V_SPACE) : width(margin_x), height(margin_y) {}
 
-	void draw(scr_coord) { }
+	void draw(scr_coord) OVERRIDE { }
 
 	scr_size get_min_size() const OVERRIDE { return scr_size(width, height); }
 	scr_size get_max_size() const OVERRIDE { return scr_size(width, height); }
