@@ -69,7 +69,7 @@ gui_scrolled_list_t::gui_scrolled_list_t(enum type type, item_compare_func cmp)
 	item_list(container.get_components())
 {
 	container.set_table_layout(1,0);
-	container.set_margin( scr_size( D_H_SPACE, 0 ), scr_size( D_H_SPACE, 0 ) );
+	container.set_margin( scr_size( D_H_SPACE, D_V_SPACE ), scr_size( D_H_SPACE, D_V_SPACE ) );
 	container.set_spacing( scr_size( D_H_SPACE, 0 ) );
 
 	set_component(&container);
@@ -95,6 +95,7 @@ void gui_scrolled_list_t::show_selection(int sel)
 void gui_scrolled_list_t::set_selection(int s)
 {
 	if (s<0  ||  ((uint32)s)>=item_list.get_count()) {
+		container.set_focus(NULL);
 		return;
 	}
 	gui_component_t* new_focus = item_list[s];
@@ -146,6 +147,7 @@ void gui_scrolled_list_t::sort( int offset )
 	cleanup_elements();
 
 	if (compare == 0  ||  item_list.get_count() <= 1) {
+		reset_container_size();
 		return;
 	}
 
@@ -198,11 +200,11 @@ bool gui_scrolled_list_t::infowin_event(const event_t *ev)
 	// translate key up/down to tab/shift-tab
 	if(  ev->ev_class==EVENT_KEYBOARD  && ev->ev_code == SIM_KEY_UP  &&  get_selection()>0) {
 		ev2.ev_code = SIM_KEY_TAB;
-		ev2.ev_key_mod |= 1;
+		ev2.ev_key_mod |= SIM_MOD_SHIFT;
 	}
 	if(  ev->ev_class==EVENT_KEYBOARD  && ev->ev_code == SIM_KEY_DOWN  &&  (uint32)(get_selection()+1) < item_list.get_count()) {
 		ev2.ev_code = SIM_KEY_TAB;
-		ev2.ev_key_mod &= ~1;
+		ev2.ev_key_mod &= ~SIM_MOD_SHIFT;
 	}
 
 	bool swallowed = gui_scrollpane_t::infowin_event(&ev2);
@@ -301,6 +303,9 @@ void gui_scrolled_list_t::draw(scr_coord offset)
 			case listskin:
 				display_img_stretch( gui_theme_t::listbox, rect);
 				break;
+			case transparent:
+				break;
+
 		}
 	}
 
