@@ -1,10 +1,11 @@
 /*
- * A class for distribution of tabs through the gui_component_t component.
- * @author Hj. Malthaner
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
  */
 
-#ifndef gui_tab_panel_h
-#define gui_tab_panel_h
+#ifndef GUI_COMPONENTS_GUI_TAB_PANEL_H
+#define GUI_COMPONENTS_GUI_TAB_PANEL_H
+
 
 #include "../../display/simimg.h"
 
@@ -17,6 +18,9 @@
 class image_t;
 class loadsave_t;
 
+/**
+ * A class for distribution of tabs through the gui_component_t component.
+ */
 class gui_tab_panel_t :
 	public gui_action_creator_t,
 	public action_listener_t,
@@ -50,13 +54,11 @@ public:
 	 * Add new tab to tab bar
 	 * @param c is tab component
 	 * @param name is name for tab component
-	 * @author Hj. Malthaner
 	 */
 	void add_tab(gui_component_t *c, const char *name, const skin_desc_t *b=NULL, const char *tooltip=NULL );
 
 	/**
 	 * Get the active component/active tab
-	 * @author Hj. Malthaner
 	 */
 	gui_component_t* get_aktives_tab() const { return get_tab(active_tab); }
 
@@ -69,28 +71,21 @@ public:
 
 	/**
 	 * Draw tabs
-	 * @author Hj. Malthaner
 	 */
 	void draw(scr_coord offset) OVERRIDE;
 
 	/**
 	 * Resizing must be propagated!
-	 * @author Volker Meyer
-	 * @date  18.06.2003
 	 */
 	void set_size(scr_size size) OVERRIDE;
 
-	/*
+	/**
 	 * Remove all tabs.
-	 * @author Gerd Wachsmuth
-	 * @date  08.05.2009
 	 */
 	void clear();
 
-	/*
+	/**
 	 * How many tabs we have?
-	 * @author Gerd Wachsmuth
-	 * @date  08.05.2009
 	 */
 	uint32 get_count () const { return tabs.get_count(); }
 
@@ -98,7 +93,6 @@ public:
 
 	/**
 	 * Returns true if the hosted component of the active tab is focusable
-	 * @author Knightly
 	 */
 	bool is_focusable() OVERRIDE { return get_aktives_tab()->is_focusable(); }
 
@@ -107,7 +101,6 @@ public:
 	/**
 	 * Get the relative position of the focused component.
 	 * Used for auto-scrolling inside a scroll pane.
-	 * @author Knightly
 	 */
 	scr_coord get_focus_pos() OVERRIDE { return pos + get_aktives_tab()->get_focus_pos(); }
 
