@@ -5,7 +5,6 @@
 
 #include <string.h>
 
-#include "../gui_frame.h"
 #include "gui_textinput.h"
 #include "../simwin.h"
 #include "../../dataobj/translator.h"
@@ -33,13 +32,13 @@ gui_textinput_t::gui_textinput_t() :
 
 scr_size gui_textinput_t::get_min_size() const
 {
-	return scr_size( 16*LINESPACE, ::max(LINESPACE+4,D_BUTTON_HEIGHT) );
+	return scr_size(4*LINESPACE, ::max(LINESPACE+4, D_EDIT_HEIGHT) );
 }
 
 
 scr_size gui_textinput_t::get_max_size() const
 {
-	return scr_size( scr_size::inf.w, ::max(LINESPACE+4,D_BUTTON_HEIGHT) );
+	return scr_size( scr_size::inf.w, ::max(LINESPACE+4, D_EDIT_HEIGHT) );
 }
 
 
@@ -177,8 +176,8 @@ bool gui_textinput_t::infowin_event(const event_t *ev)
 						// Ctrl key pressed -> skip over to the start of the previous word (as delimited by space(s))
 						if(  IS_CONTROL_PRESSED(ev)  ) {
 							const char* tmp_text = text + head_cursor_pos;
-							uint8 byte_length;
-							uint8 pixel_width;
+							uint8 byte_length = 0;
+							uint8 pixel_width = 0;
 							// first skip over all contiguous space characters to the left
 							while(  head_cursor_pos>0  &&  get_prev_char_with_metrics(tmp_text, text, byte_length, pixel_width)==SIM_KEY_SPACE  ) {
 								head_cursor_pos -= byte_length;
@@ -206,8 +205,8 @@ bool gui_textinput_t::infowin_event(const event_t *ev)
 						// Ctrl key pressed -> skip over to the start of the next word (as delimited by space(s))
 						if(  IS_CONTROL_PRESSED(ev)  ) {
 							const char* tmp_text = text + head_cursor_pos;
-							uint8 byte_length;
-							uint8 pixel_width;
+							uint8 byte_length = 0;
+							uint8 pixel_width = 0;
 							// first skip over all contiguous non-space characters to the right
 							while(  head_cursor_pos<len  &&  get_next_char_with_metrics(tmp_text, byte_length, pixel_width)!=SIM_KEY_SPACE  ) {
 								head_cursor_pos += byte_length;
@@ -283,6 +282,13 @@ bool gui_textinput_t::infowin_event(const event_t *ev)
 						// ignore special keys not handled so far
 						break;
 					}
+					else if (ev->ev_code>=SIM_KEY_NUMPAD_BASE  &&  ev->ev_code<=SIM_KEY_NUMPAD_BASE+9) {
+						// ignore numpad keys if numlock is off
+						// Could also return false here to move the map diagonally but this does not work for 2/4/6/8
+						// (SIM_KEY_LEFT/_RIGHT moves the cursor already)
+						break;
+					}
+
 					// insert letters, numbers, and special characters
 
 					// first check if it is necessary to remove selected text portion
@@ -314,7 +320,7 @@ bool gui_textinput_t::infowin_event(const event_t *ev)
 						letter[1] = 0;
 					}
 
-					size_t num_letter = strlen(letter);
+					const size_t num_letter = strlen(letter);
 
 					if(len+num_letter>=max) {
 						// too many chars ...
@@ -323,8 +329,9 @@ bool gui_textinput_t::infowin_event(const event_t *ev)
 
 					// insert into text?
 					if (head_cursor_pos < len) {
-						for(  sint64 pos=len+num_letter;  pos>=(sint64)head_cursor_pos;  pos--  ) {
-							text[pos] = text[pos-num_letter];
+						// copy the trailing '\0' too
+						for(  sint64 pos=len;  pos>=(sint64)head_cursor_pos;  pos--  ) {
+							text[pos+num_letter] = text[pos];
 						}
 						memcpy( text+head_cursor_pos, letter, num_letter );
 					}
@@ -475,6 +482,11 @@ bool gui_textinput_t::infowin_event(const event_t *ev)
 		}
 		return true;
 	}
+	else if(  ev->ev_class == INFOWIN   &&  ev->ev_code == WIN_CLOSE  &&  focus_received  ) {
+		// release focus on close and close keyboard
+		dr_stop_textinput();
+		focus_received = false;
+	}
 	return false;
 }
 
@@ -523,9 +535,9 @@ void gui_textinput_t::display_with_cursor(scr_coord offset, bool cursor_active,
 
 	if(  text  ) {
 		// recalculate scroll offset
-		const KOORD_VAL text_width = proportional_string_width(text);
-		const KOORD_VAL view_width = size.w - 3;
-		const KOORD_VAL cursor_offset = cursor_active ? proportional_string_len_width(text, head_cursor_pos) : 0;
+		const int text_width = proportional_string_width(text);
+		const scr_coord_val view_width = size.w - 3;
+		const int cursor_offset = cursor_active ? proportional_string_len_width(text, head_cursor_pos) : 0;
 		if(  text_width<=view_width  ) {
 			// case : text is shorter than displayable width of the text input
 			//        -> the only case where left and right alignments differ
@@ -651,7 +663,6 @@ bool gui_hidden_textinput_t::infowin_event(const event_t *ev)
 	else {
 		return gui_textinput_t::infowin_event( ev );
 	}
-	return false;
 }
 
 
