@@ -6,7 +6,7 @@
 #include <stdio.h>
 
 #include "../simdebug.h"
-#include "../vehicle/simvehicle.h"
+#include "../vehicle/vehicle_base.h"
 #include "../simworld.h"
 #include "../simsound.h"
 
@@ -34,12 +34,18 @@ crossing_logic_t::crossing_logic_t( const crossing_desc_t *desc )
 
 
 /**
- * @return string; currently unused but useful for debugging
+ * @param[out] buf string; currently unused but useful for debugging
  */
 void crossing_logic_t::info(cbuffer_t & buf) const
 {
-	static char const* const state_str[4] = { "invalid", "open", "request closing", "closed" };
-	assert(state<4);
+	static char const* const state_str[NUM_CROSSING_STATES] =
+	{
+		"invalid",
+		"open",
+		"request closing",
+		"closed"
+	};
+
 	buf.printf("%s%u%s%u%s%s\n",
 		translator::translate("\nway1 reserved by"), on_way1.get_count(),
 		translator::translate("\nway2 reserved by"), on_way2.get_count(),
@@ -93,7 +99,7 @@ bool crossing_logic_t::request_crossing( const vehicle_base_t *v )
 	}
 	else if(v->get_waytype()==desc->get_waytype(1)) {
 
-		// vehikel from way2 arrives
+		// vehicle from way2 arrives
 		if(on_way1.get_count()) {
 			// sorry, still things on the crossing, but we will prepare
 			set_state( CROSSING_REQUEST_CLOSE );
@@ -232,7 +238,7 @@ DBG_DEBUG( "crossing_logic_t::register_desc()","%s", desc->get_name() );
 
 const crossing_desc_t *crossing_logic_t::get_crossing(const waytype_t ns, const waytype_t ow, sint32 way_0_speed, sint32 way_1_speed, uint16 timeline_year_month)
 {
-	// mark if crossing possible
+	// mark if crossing possiblea
 	const waytype_t way0 = ns <  ow ? ns : ow;
 	const waytype_t way1 = ns >= ow ? ns : ow;
 	const crossing_desc_t *best = NULL;
@@ -244,24 +250,19 @@ const crossing_desc_t *crossing_logic_t::get_crossing(const waytype_t ns, const
 			if(  !i->is_available(timeline_year_month)  ) {
 				continue;
 			}
-			// better matching speed => take this
-			if(  best  ) {
-				// match maxspeed of first way
-				uint8  const way0_nr = (way0 == ow);
-				sint32 const imax0   =    i->get_maxspeed(way0_nr);
-				sint32 const bmax0   = best->get_maxspeed(way0_nr);
-				if(  (imax0 < way_0_speed || bmax0 < imax0)  &&  (way_0_speed < bmax0  ||  imax0 < bmax0)  ) {
-					continue;
-				}
+			// match maxspeed of first way
+			uint8  const way0_nr = (way0 == ow);
+			sint32 const imax0   = i->get_maxspeed(way0_nr);
+			sint32 const bmax0   = best ? best->get_maxspeed(way0_nr) : 9999;
+			if(  imax0 >= way_0_speed   &&  imax0 <= bmax0  ) {
 				// match maxspeed of second way
 				uint8  const way1_nr = (way1 == ow);
-				sint32 const imax1   =    i->get_maxspeed(way1_nr);
-				sint32 const bmax1   = best->get_maxspeed(way1_nr);
-				if(  (imax1 < way_1_speed  ||  bmax1 < imax1)  &&  (way_1_speed < bmax1  ||  imax1 < bmax1)  ) {
-					continue;
+				sint32 const imax1   = i->get_maxspeed(way1_nr);
+				sint32 const bmax1   = best ? best->get_maxspeed(way1_nr) : 9999;
+				if(  imax1 >= way_1_speed  &&  imax1 <= bmax1  ) {
+					best = i;
 				}
 			}
-			best = i;
 		}
 	}
 	return best;
