@@ -14,7 +14,12 @@
 class gebaeude_t;
 
 namespace curiositylist {
-	enum sort_mode_t { by_name=0, by_paxlevel/*, by_maillevel*/, SORT_MODES };
+	enum sort_mode_t {
+		by_name=0,
+		by_paxlevel,
+//		by_maillevel,
+		SORT_MODES
+	};
 };
 
 /**
@@ -38,9 +43,6 @@ public:
 
 	bool infowin_event(event_t const*) OVERRIDE;
 
-	/**
-	* Draw the component
-	*/
 	void draw(scr_coord offset) OVERRIDE;
 };
 
