@@ -58,7 +58,7 @@ enlarge_map_frame_t::enlarge_map_frame_t() :
 		{
 			// map seed number label
 			map_number_label.init();
-			map_number_label.buf().printf(translator::translate("Map number: %d"), welt->get_settings().get_map_number());
+			map_number_label.buf().printf("%s %d", translator::translate("2WORLD_CHOOSE"), welt->get_settings().get_map_number());
 			map_number_label.update();
 			add_component(&map_number_label);
 
