@@ -1,5 +1,11 @@
-#ifndef _EXP_GAME_OBJ_H_
-#define _EXP_GAME_OBJ_H_
+/*
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
+ */
+
+#ifndef SCRIPT_EXPORT_OBJS_H
+#define SCRIPT_EXPORT_OBJS_H
+
 
 #include "../squirrel/squirrel.h"
 
