@@ -17,6 +17,8 @@
 #include "components/gui_fixedwidth_textarea.h"
 #include "components/gui_building.h"
 #include "components/gui_combobox.h"
+#include "components/gui_numberinput.h"
+#include "components/gui_divider.h"
 
 #include "../utils/cbuffer_t.h"
 #include "../simtypes.h"
@@ -35,7 +37,7 @@ private:
 public:
 	enum special_rotations_t {
 		automatic = 254,
-		random = 255
+		random    = 255
 	};
 
 	gui_rotation_item_t(uint8 r);
@@ -45,6 +47,56 @@ public:
 	sint8 get_rotation() const { return rotation; }
 };
 
+/**
+ * Entries for climate selection.
+ */
+class gui_climates_item_t : public gui_scrolled_list_t::const_text_scrollitem_t
+{
+private:
+	const char *text;
+	uint8 climate_;
+
+public:
+	gui_climates_item_t(uint8 r);
+
+	char const* get_text () const OVERRIDE { return text; }
+
+	sint8 get_climate() const { return climate_; }
+};
+
+/**
+ * Entries for sorting selection.
+ */
+class gui_sorting_item_t : public gui_scrolled_list_t::const_text_scrollitem_t
+{
+private:
+	const char *text;
+	uint8 sorted_by;
+
+public:
+	enum sorting_options {
+		BY_NAME_TRANSLATED,
+		BY_NAME_OBJECT,
+		BY_LEVEL_PAX,
+		BY_LEVEL_MAIL,
+		BY_DATE_INTRO,
+		BY_DATE_RETIRE,
+		BY_SIZE,
+		BY_COST,
+		BY_GOODS_NUMBER,
+		BY_REMOVAL
+	};
+
+	gui_sorting_item_t(uint8 r);
+
+	char const* get_text () const OVERRIDE { return text; }
+
+	sint8 get_sortedby() const { return sorted_by; }
+};
+
+
+
+
 /**
  * Base class map editor dialogues to select object to place on map.
  */
@@ -54,27 +106,33 @@ class extend_edit_gui_t :
 {
 protected:
 	player_t *player;
-	/// cont_left: left column, right: between obsolete-button and text-area
+	/// cont_left: left column, cont_right: right column
 	gui_aligned_container_t cont_left, cont_right;
+	/// cont_filter: Settings about the content of the list (above list)
+	/// cont_timeline: timeline-related filter settings
+	/// cont_options: Settings about the active object (eg. rotation)
+	/// cont_scrolly: the scrollable container (image + desc)
+	gui_aligned_container_t cont_filter, cont_options, cont_timeline, cont_scrolly;
+
+
 
 	cbuffer_t buf;
 	gui_fixedwidth_textarea_t info_text;
+	//container for object description
 	gui_scrollpane_t scrolly;
 	gui_scrolled_list_t scl;
-	gui_tab_panel_t tabs;
 
 	//image
 	gui_building_t building_image;
 
-	button_t bt_obsolete, bt_timeline, bt_climates;
+	button_t bt_obsolete, bt_timeline, bt_climates, bt_timeline_custom, sort_order;
 
 	// we make this available for child classes
-	gui_combobox_t cb_rotation;
+	gui_combobox_t cb_rotation, cb_climates, cb_sortedby;
 
-	/// show translated names
-	bool is_show_trans_name;
+	gui_numberinput_t ni_timeline_year, ni_timeline_month;
 
-	virtual void fill_list( bool /* translate */ ) {}
+	virtual void fill_list() {}
 
 	virtual void change_item_info( sint32 /*entry, -1= none */ ) {}
 
@@ -84,14 +142,19 @@ protected:
 	 * defaults to zero.
 	 */
 	uint8 get_rotation() const;
-public:
-	extend_edit_gui_t(const char *name, player_t* player_);
 
 	/**
-	* Does this window need a min size button in the title bar?
-	* @return true if such a button is needed
-	*/
-	bool has_min_sizer() const OVERRIDE {return true;}
+	 * @returns selected climate of cb_climates.
+	 */
+	uint8 get_climate() const;
+
+	/**
+	 * @returns selected sorting method.
+	 */
+	uint8 get_sortedby() const;
+
+public:
+	extend_edit_gui_t(const char *name, player_t* player_);
 
 	void set_windowsize( scr_size s ) OVERRIDE;
 
