@@ -21,7 +21,12 @@ class karte_ptr_t;
 class freight_list_sorter_t
 {
 public:
-	enum sort_mode_t { by_name=0, by_via=1, by_via_sum=2, by_amount=3};
+	enum sort_mode_t {
+		by_name    = 0,
+		by_via     = 1,
+		by_via_sum = 2,
+		by_amount  = 3
+	};
 
 	static void sort_freight(vector_tpl<ware_t> const& warray, cbuffer_t& buf, sort_mode_t sort_mode, const slist_tpl<ware_t>* full_list, const char* what_doing);
 
