@@ -16,20 +16,19 @@
 class fundament_t : public grund_t
 {
 protected:
-	/**
-	* The foundation always have the same image.
-	*/
+	/// The foundation always has the same image.
 	void calc_image_internal(const bool calc_only_snowline_change) OVERRIDE;
 
 public:
-	fundament_t(loadsave_t *file, koord pos );
+	fundament_t(loadsave_t *file, koord pos);
 	fundament_t(koord3d pos, slope_t::type hang);
 
-	const char *get_name() const OVERRIDE {return "Fundament";}
+public:
+	/// @copydoc grund_t::get_name
+	const char *get_name() const OVERRIDE { return "Fundament"; }
 
+	/// @copydoc grund_t::get_typ
 	typ get_typ() const OVERRIDE { return fundament; }
-
-	bool set_slope(slope_t::type) { slope = 0; return false; }
 };
 
 #endif
