@@ -16,7 +16,7 @@ static pthread_mutex_t add_to_city_mutex = PTHREAD_MUTEX_INITIALIZER;
 #include "../bauer/hausbauer.h"
 #include "../gui/headquarter_info.h"
 #include "../simworld.h"
-#include "../simobj.h"
+#include "simobj.h"
 #include "../simfab.h"
 #include "../display/simimg.h"
 #include "../display/simgraph.h"
@@ -529,14 +529,40 @@ bool gebaeude_t::is_city_building() const
 }
 
 
+uint32 gebaeude_t::get_tile_list( vector_tpl<grund_t *> &list ) const
+{
+	koord size = get_tile()->get_desc()->get_size( get_tile()->get_layout() );
+	const koord3d pos0 = get_pos() - get_tile()->get_offset(); // get origin
+	koord k;
+
+	list.clear();
+	// add all tiles
+	for( k.y = 0; k.y < size.y; k.y++ ) {
+		for( k.x = 0; k.x < size.x; k.x++ ) {
+			if( grund_t* gr = welt->lookup( pos0+k ) ) {
+				if( gebaeude_t* const add_gb = gr->find<gebaeude_t>() ) {
+					if( is_same_building( add_gb ) ) {
+						list.append( gr );
+					}
+				}
+			}
+		}
+	}
+	return list.get_count();
+}
+
+
+
+
 void gebaeude_t::show_info()
 {
 	if(get_fabrik()) {
 		ptr.fab->open_info_window();
 		return;
 	}
-	int old_count = win_get_open_count();
-	bool special = is_headquarter() || is_townhall();
+
+	const uint32 old_count = win_get_open_count();
+	const bool special = is_headquarter() || is_townhall();
 
 	if(is_headquarter()) {
 		create_win( new headquarter_info_t(get_owner()), w_info, magic_headquarter+get_owner()->get_player_nr() );
@@ -548,28 +574,22 @@ void gebaeude_t::show_info()
 	if(!tile->get_desc()->no_info_window()) {
 		if(!special  ||  (env_t::townhall_info  &&  old_count==win_get_open_count()) ) {
 			// iterate over all places to check if there is already an open window
-			const building_desc_t* const building_desc = tile->get_desc();
-			const uint8 layout = tile->get_layout();
-			koord k;
-			for (k.x = 0; k.x<building_desc->get_x(layout); k.x++) {
-				for (k.y = 0; k.y<building_desc->get_y(layout); k.y++) {
-					const building_tile_desc_t *tile = building_desc->get_tile(layout, k.x, k.y);
-					if (tile == NULL || !tile->has_image()) {
-						continue;
-					}
-					if (grund_t *gr = welt->lookup(get_pos() - get_tile()->get_offset() + k)) {
-						gebaeude_t *gb = gr->find<gebaeude_t>();
-						if (gb  &&  gb->get_tile() == tile) {
-							if (win_get_magic((ptrdiff_t)gb)) {
-								// already open
-								return;
-							}
-						}
-					}
+			gebaeude_t * first_tile = NULL;
+			static vector_tpl<grund_t *> gb_tiles;
+			get_tile_list( gb_tiles );
+			FOR( vector_tpl<grund_t*>, gr, gb_tiles ) {
+				// no need for check, we jsut did before ...
+				gebaeude_t* gb = gr->find<gebaeude_t>();
+				if( win_get_magic( (ptrdiff_t)gb ) ) {
+					// already open
+					return;
+				}
+				if( first_tile==0 ) {
+					first_tile = gb;
 				}
 			}
 			// open info window for the first tile of our building (not relying on presence of (0,0) tile)
-			get_first_tile()->obj_t::show_info();
+			first_tile->obj_t::show_info();
 		}
 	}
 }
@@ -587,24 +607,16 @@ bool gebaeude_t::is_within_players_network(const player_t* player) const
 	}
 
 	// normal building: iterate over all tiles
-	const building_desc_t* const building_desc = tile->get_desc();
-	const uint8 layout = tile->get_layout();
-	koord k;
-	for (k.x = 0; k.x<building_desc->get_x(layout); k.x++) {
-		for (k.y = 0; k.y<building_desc->get_y(layout); k.y++) {
-			// check for hole in the building ...
-			const building_tile_desc_t *tile = building_desc->get_tile(layout, k.x, k.y);
-			if (tile == NULL || !tile->has_image()) {
-				continue;
-			}
-			// now search for stops serving this tile
-			if(  const planquadrat_t *plan = welt->access( get_pos().get_2d() - get_tile()->get_offset() + k )  ) {
-				if(  plan->get_haltlist_count() > 0   ) {
-					const halthandle_t *const halt_list = plan->get_haltlist();
-					for(  int h = 0;  h < plan->get_haltlist_count();  h++  ) {
-						if(  halt_list[h].is_bound()  &&  (halt_list[h]->get_pax_enabled()  || halt_list[h]->get_mail_enabled() )  &&  halt_list[h]->has_available_network(player)  ) {
-							return true;
-						}
+	vector_tpl<grund_t*> gb_tiles;
+	get_tile_list( gb_tiles );
+	FOR( vector_tpl<grund_t*>, gr, gb_tiles ) {
+		// no need for check, we jsut did before ...
+		if( const planquadrat_t* plan = welt->access( gr->get_pos().get_2d()) ) {
+			if( plan->get_haltlist_count() > 0 ) {
+				const halthandle_t* const halt_list = plan->get_haltlist();
+				for( int h = 0; h < plan->get_haltlist_count(); h++ ) {
+					if( halt_list[h].is_bound()  &&  (halt_list[h]->get_pax_enabled()  || halt_list[h]->get_mail_enabled())  &&  halt_list[h]->has_available_network( player ) ) {
+						return true;
 					}
 				}
 			}
@@ -632,19 +644,18 @@ bool gebaeude_t::is_same_building(const gebaeude_t* other) const
 
 gebaeude_t* gebaeude_t::get_first_tile()
 {
-	const building_desc_t* const building_desc = tile->get_desc();
-	const uint8 layout = tile->get_layout();
+	koord size = get_tile()->get_desc()->get_size( get_tile()->get_layout() );
+	const koord3d pos0 = get_pos() - get_tile()->get_offset(); // get origin
 	koord k;
-	for(k.x=0; k.x<building_desc->get_x(layout); k.x++) {
-		for(k.y=0; k.y<building_desc->get_y(layout); k.y++) {
-			const building_tile_desc_t *tile = building_desc->get_tile(layout, k.x, k.y);
-			if (tile==NULL  ||  !tile->has_image()) {
-				continue;
-			}
-			if (grund_t *gr = welt->lookup( get_pos() - get_tile()->get_offset() + k)) {
-				gebaeude_t *gb = gr->find<gebaeude_t>();
-				if (gb  &&  gb->get_tile() == tile) {
-					return gb;
+
+	// add all tiles
+	for( k.y = 0; k.y < size.y; k.y++ ) {
+		for( k.x = 0; k.x < size.x; k.x++ ) {
+			if( grund_t* gr = welt->lookup( pos0+k ) ) {
+				if( gebaeude_t* const add_gb = obj_cast<gebaeude_t>(gr->first_obj()) ) {
+					if( is_same_building( add_gb ) ) {
+						return add_gb;
+					}
 				}
 			}
 		}
@@ -737,7 +748,7 @@ void gebaeude_t::info(cbuffer_t & buf) const
 		buf.append("\n");
 		if(get_owner()==NULL) {
 			const sint32 v = (sint32)( -welt->get_settings().cst_multiply_remove_haus * (tile->get_desc()->get_level() + 1) / 100 );
-			buf.printf("\n%s: %ld$\n", translator::translate("Wert"), v);
+			buf.printf("\n%s: %d$\n", translator::translate("Wert"), v);
 		}
 
 		if (char const* const maker = tile->get_desc()->get_copyright()) {
