@@ -59,6 +59,7 @@ PIXVAL gui_theme_t::gui_shadow_color;
 PIXVAL gui_theme_t::gui_color_loadingbar_inner;
 PIXVAL gui_theme_t::gui_color_loadingbar_progress;
 PIXVAL gui_theme_t::gui_color_obsolete;
+PIXVAL gui_theme_t::gui_color_chat_window_network_transparency;
 PIXVAL gui_theme_t::gui_color_empty;
 
 /**
@@ -82,21 +83,22 @@ scr_size gui_theme_t::gui_min_scrollbar_size;
 scr_size gui_theme_t::gui_label_size;
 scr_size gui_theme_t::gui_edit_size;
 scr_size gui_theme_t::gui_gadget_size;
+scr_size gui_theme_t::gui_dragger_size;
 scr_size gui_theme_t::gui_indicator_size;
-KOORD_VAL gui_theme_t::gui_waitingbar_width;
+scr_coord_val gui_theme_t::gui_waitingbar_width;
 
 scr_coord gui_theme_t::gui_focus_offset;
 scr_coord gui_theme_t::gui_button_text_offset_right;
 scr_coord gui_theme_t::gui_color_button_text_offset_right;
 
-KOORD_VAL gui_theme_t::gui_titlebar_height;
-KOORD_VAL gui_theme_t::gui_frame_left;
-KOORD_VAL gui_theme_t::gui_frame_top;
-KOORD_VAL gui_theme_t::gui_frame_right;
-KOORD_VAL gui_theme_t::gui_frame_bottom;
-KOORD_VAL gui_theme_t::gui_hspace;
-KOORD_VAL gui_theme_t::gui_vspace;
-KOORD_VAL gui_theme_t::gui_filelist_vspace;
+scr_coord_val gui_theme_t::gui_titlebar_height;
+scr_coord_val gui_theme_t::gui_frame_left;
+scr_coord_val gui_theme_t::gui_frame_top;
+scr_coord_val gui_theme_t::gui_frame_right;
+scr_coord_val gui_theme_t::gui_frame_bottom;
+scr_coord_val gui_theme_t::gui_hspace;
+scr_coord_val gui_theme_t::gui_vspace;
+scr_coord_val gui_theme_t::gui_filelist_vspace;
 
 /* those are the 3x3 images which are used for stretching
  * also 1x3 and 3x1 subsets are possible
@@ -214,6 +216,8 @@ void gui_theme_t::init_gui_defaults()
 	gui_divider_size.h   = D_V_SPACE*2;
 
 	gui_drop_shadows     = false;
+
+	gui_color_chat_window_network_transparency = color_idx_to_rgb(COL_WHITE);
 }
 
 
@@ -258,7 +262,7 @@ void gui_theme_t::init_gui_from_images()
 			button_tiles[i][j%3][j/3] = skinverwaltung_t::button->get_image_id( i*9+j );
 		}
 	}
-	image_id has_second_mask;
+	image_id has_second_mask = 0xFFFF;
 	for(  int i=0;  i<2;  i++  ) {
 		has_second_mask = 0xFFFF;
 		for(  int j=0;  j<9;  j++  ) {
@@ -360,7 +364,10 @@ void gui_theme_t::init_gui_from_images()
 	}
 
 	// gadgets
-	init_size_from_image( skinverwaltung_t::gadget->get_image( SKIN_GADGET_CLOSE ), gui_gadget_size );
+	gui_dragger_size = gui_scrollbar_size;
+	if (skinverwaltung_t::gadget) {
+		init_size_from_image( skinverwaltung_t::gadget->get_image( SKIN_GADGET_CLOSE ), gui_gadget_size );
+	}
 }
 
 
@@ -461,23 +468,28 @@ bool gui_theme_t::themes_init(const char *file_name, bool init_fonts, bool init_
 	gui_theme_t::gui_scrollbar_size.w = max( gui_min_scrollbar_size.w, (uint32)contents.get_int("gui_scrollbar_width",  gui_theme_t::gui_scrollbar_size.w ) );
 	gui_theme_t::gui_scrollbar_size.h = max( gui_min_scrollbar_size.h, (uint32)contents.get_int("gui_scrollbar_height", gui_theme_t::gui_scrollbar_size.h ) );
 
+	// dragger size must be as large as scrollbar size
+	if (skinverwaltung_t::gadget) {
+		init_size_from_image( skinverwaltung_t::gadget->get_image( SKIN_WINDOW_RESIZE), gui_dragger_size );
+		gui_dragger_size.clip_lefttop(scr_coord(gui_scrollbar_size.w, gui_scrollbar_size.h));
+	}
+
 	// in practice, posbutton min height better is LINESPACE
 	gui_theme_t::gui_pos_button_size.w = (uint32)contents.get_int("gui_posbutton_width",  gui_theme_t::gui_pos_button_size.w );
 	gui_theme_t::gui_pos_button_size.h = (uint32)contents.get_int("gui_posbutton_height", gui_theme_t::gui_pos_button_size.h );
 
 	// read ../dataobj/tabfile.h for clarification of this area
-	int *color_button_text_offsets = contents.get_ints("gui_color_button_text_offset");
-	int *button_text_offsets = contents.get_ints("gui_button_text_offset");
-	if(  color_button_text_offsets[0] > 2  ) {
-		gui_theme_t::gui_color_button_text_offset = scr_size(color_button_text_offsets[1], color_button_text_offsets[2]);
-		gui_theme_t::gui_color_button_text_offset_right = scr_coord(color_button_text_offsets[3], 0);
+	vector_tpl<int> color_button_text_offsets = contents.get_ints("gui_color_button_text_offset");
+	if(  color_button_text_offsets.get_count() > 2  ) {
+		gui_theme_t::gui_color_button_text_offset = scr_size(color_button_text_offsets[0], color_button_text_offsets[1]);
+		gui_theme_t::gui_color_button_text_offset_right = scr_coord(color_button_text_offsets[2], 0);
 	}
-	if(  button_text_offsets[0] > 2  ) {
-		gui_theme_t::gui_button_text_offset = scr_size(button_text_offsets[1], button_text_offsets[2]);
-		gui_theme_t::gui_button_text_offset_right = scr_coord(button_text_offsets[3], 0);
+
+	vector_tpl<int> button_text_offsets = contents.get_ints("gui_button_text_offset");
+	if(  button_text_offsets.get_count() > 2  ) {
+		gui_theme_t::gui_button_text_offset = scr_size(button_text_offsets[0], button_text_offsets[1]);
+		gui_theme_t::gui_button_text_offset_right = scr_coord(button_text_offsets[2], 0);
 	}
-	delete [] color_button_text_offsets;
-	delete [] button_text_offsets;
 
 	// default iconsize (square for now)
 	env_t::iconsize.h = env_t::iconsize.w = contents.get_int("icon_width",env_t::iconsize.w );
@@ -522,6 +534,7 @@ bool gui_theme_t::themes_init(const char *file_name, bool init_fonts, bool init_
 	gui_theme_t::gui_color_loadingbar_progress          = (PIXVAL)contents.get_color("gui_color_loadingbar_progress", SYSCOL_LOADINGBAR_PROGRESS);
 	gui_theme_t::gui_color_obsolete                     = (PIXVAL)contents.get_color("gui_color_obsolete", SYSCOL_OBSOLETE);
 	gui_theme_t::gui_color_empty                        = (PIXVAL)contents.get_color("gui_color_empty", SYSCOL_EMPTY);
+	gui_theme_t::gui_color_chat_window_network_transparency = (PIXVAL)contents.get_color("gui_color_chat_window_network_transparency", gui_color_chat_window_network_transparency);
 
 	gui_theme_t::gui_waitingbar_width = (uint32)contents.get_int("gui_waitingbar_width", gui_theme_t::gui_waitingbar_width);
 
@@ -539,7 +552,7 @@ bool gui_theme_t::themes_init(const char *file_name, bool init_fonts, bool init_
 	env_t::window_snap_distance =      contents.get_int("window_snap_distance",      env_t::window_snap_distance );
 	gui_theme_t::gui_drop_shadows =    contents.get_int("gui_drop_shadows",          gui_theme_t::gui_drop_shadows );
 	env_t::bottom_window_darkness =    contents.get_int("bottom_window_darkness",    env_t::bottom_window_darkness );
-
+	env_t::menupos                   = contents.get_int("menubar_position",          env_t::menupos);
 	env_t::gui_player_color_bright =   contents.get_int("gui_player_color_bright",   env_t::gui_player_color_bright );
 	env_t::gui_player_color_dark =     contents.get_int("gui_player_color_dark",     env_t::gui_player_color_dark );
 
@@ -556,6 +569,8 @@ bool gui_theme_t::themes_init(const char *file_name, bool init_fonts, bool init_
 	env_t::toolbar_max_width =    contents.get_int("toolbar_max_width",          env_t::toolbar_max_width );
 	env_t::toolbar_max_height =   contents.get_int("toolbar_max_height",         env_t::toolbar_max_height );
 
+	env_t::chat_window_transparency =   100 - contents.get_int("gui_chat_window_network_transparency", 100 - env_t::chat_window_transparency);
+
 	if(  toolbar_last_used_t::last_used_tools  &&  init_tools  ) {
 		// only re-init if already inited
 		tool_t::update_toolbars();
