@@ -29,7 +29,7 @@
 
 #include "../player/simplay.h"
 
-#include "../vehicle/simvehicle.h"
+#include "../vehicle/vehicle.h"
 
 #include "../utils/simstring.h"
 
@@ -62,6 +62,8 @@ class gui_departure_board_t : public gui_aligned_container_t
 	vector_tpl<dest_info_t> destinations;
 	vector_tpl<dest_info_t> origins;
 
+	static button_t absolute_times;
+
 	uint32 calc_ticks_until_arrival( convoihandle_t cnv );
 
 	void insert_image(convoihandle_t cnv);
@@ -75,6 +77,8 @@ public:
 	{
 		next_refresh = -1;
 		set_table_layout(3,0);
+		add_component( &absolute_times );
+		absolute_times.init( button_t::square_automatic, "Absolute times" );
 	}
 
 	void update_departures(halthandle_t halt);
@@ -82,6 +86,9 @@ public:
 	scr_size get_max_size() const OVERRIDE { return get_min_size(); }
 };
 
+button_t gui_departure_board_t::absolute_times;
+
+
 // all connections
 class gui_halt_detail_t : public gui_aligned_container_t
 {
@@ -104,7 +111,7 @@ class gui_halt_detail_t : public gui_aligned_container_t
 		{
 			player_t *player = welt->get_active_player();
 			if(  player == line->get_owner()  ) {
-				player->simlinemgmt.show_lineinfo(player, line);
+				player->simlinemgmt.show_lineinfo(player, line, 3);
 			}
 			return true;
 		}
@@ -759,15 +766,33 @@ void gui_departure_board_t::update_departures(halthandle_t halt)
 	last_ticks = cur_ticks;
 
 	// iterate over all convoys stopping here
-	FOR(  slist_tpl<convoihandle_t>, cnv, halt->get_loading_convois() ) {
-		if( !cnv.is_bound()) {
+	FOR(  vector_tpl<convoihandle_t>, cnv, halt->get_loading_convois() ) {
+		if( !cnv.is_bound()  ||  cnv->get_state()!=convoi_t::LOADING  ) {
 			continue;
 		}
 		halthandle_t next_halt = cnv->get_schedule()->get_next_halt(cnv->get_owner(),halt);
+
 		if(  next_halt.is_bound()  ) {
-			dest_info_t next( next_halt, 0, cnv );
+			uint32 delta_ticks = 0;
+			if(  cnv->get_schedule()->get_current_entry().get_absolute_departures()  ) {
+				// absolute schedule
+				delta_ticks = cnv->get_departure_ticks();
+			}
+			else if(  cnv->get_schedule()->get_current_entry().waiting_time > 0  ) {
+				// waiting for load with max time
+				delta_ticks = cnv->get_arrival_ticks() + cnv->get_schedule()->get_current_entry().get_waiting_ticks();
+			}
+			// avoid overflow when departure time has passed but convoi is still loading etc.
+			uint32 ct = welt->get_ticks();
+			if (ct > delta_ticks) {
+				delta_ticks = 0;
+			}
+			else {
+				delta_ticks -= ct;
+			}
+			dest_info_t next( next_halt, delta_ticks, cnv );
 			destinations.append_unique( next );
-			if(  grund_t *gr = welt->lookup( cnv->get_vehikel(0)->last_stop_pos )  ) {
+			if(  grund_t *gr = welt->lookup( cnv->get_vehicle(0)->last_stop_pos )  ) {
 				if(  gr->get_halt().is_bound()  &&  gr->get_halt() != halt  ) {
 					dest_info_t prev( gr->get_halt(), 0, cnv );
 					origins.append_unique( prev );
@@ -782,7 +807,7 @@ void gui_departure_board_t::update_departures(halthandle_t halt)
 			convoihandle_t cnv = line->get_convoy(j);
 			if(  cnv.is_bound()  &&  ( cnv->get_state() == convoi_t::DRIVING  ||  cnv->is_waiting() )  &&  haltestelle_t::get_halt( cnv->get_schedule()->get_current_entry().pos, cnv->get_owner() ) == halt  ) {
 				halthandle_t prev_halt = haltestelle_t::get_halt( cnv->front()->last_stop_pos, cnv->get_owner() );
-				sint32 delta_t = cur_ticks + calc_ticks_until_arrival( cnv );
+				sint32 delta_t = calc_ticks_until_arrival( cnv );
 				if(  prev_halt.is_bound()  ) {
 					dest_info_t prev( prev_halt, delta_t, cnv );
 					// smooth times a little
@@ -797,6 +822,16 @@ void gui_departure_board_t::update_departures(halthandle_t halt)
 				}
 				halthandle_t next_halt = cnv->get_schedule()->get_next_halt(cnv->get_owner(),halt);
 				if(  next_halt.is_bound()  ) {
+					if( cnv->get_schedule()->get_current_entry().get_absolute_departures() ) {
+						delta_t = cnv->get_departure_ticks( welt->get_ticks()+delta_t )-welt->get_ticks();
+					}
+					else if( cnv->get_schedule()->get_current_entry().waiting_time > 0 ) {
+						// waiting for load with max time
+						delta_t += cnv->get_schedule()->get_current_entry().get_waiting_ticks();
+					}
+					else {
+						delta_t += 2000;
+					}
 					dest_info_t next( next_halt, delta_t+2000, cnv );
 					destinations.insert_ordered( next, compare_hi );
 				}
@@ -830,6 +865,7 @@ void gui_departure_board_t::update_departures(halthandle_t halt)
 
 	// fill the board
 	remove_all();
+	add_component( &absolute_times,3 );
 	slist_tpl<halthandle_t> exclude;
 	if(  destinations.get_count()>0  ) {
 		new_component_span<gui_label_t>("Departures to\n", 3);
@@ -837,9 +873,18 @@ void gui_departure_board_t::update_departures(halthandle_t halt)
 		FOR( vector_tpl<dest_info_t>, hi, destinations ) {
 			if(  freight_list_sorter_t::by_via_sum != env_t::default_sortmode  ||  !exclude.is_contained( hi.halt )  ) {
 				gui_label_buf_t *lb = new_component<gui_label_buf_t>(SYSCOL_TEXT, gui_label_t::right);
-				lb->buf().printf("%s", tick_to_string( hi.delta_ticks, false ) );
+				if( hi.delta_ticks == 0 ) {
+					lb->buf().append( translator::translate( "now" ) );
+				}
+				else {
+					if( absolute_times.pressed ) {
+						lb->buf().printf( "%s", tick_to_string( welt->get_ticks()+hi.delta_ticks, true ) );
+					}
+					else {
+						lb->buf().printf( "%s", difftick_to_string( hi.delta_ticks, true ) );
+					}
+				}
 				lb->update();
-
 				insert_image(hi.cnv);
 
 				new_component<gui_label_t>(hi.halt->get_name() );
@@ -854,7 +899,17 @@ void gui_departure_board_t::update_departures(halthandle_t halt)
 		FOR( vector_tpl<dest_info_t>, hi, origins ) {
 			if(  freight_list_sorter_t::by_via_sum != env_t::default_sortmode  ||  !exclude.is_contained( hi.halt )  ) {
 				gui_label_buf_t *lb = new_component<gui_label_buf_t>(SYSCOL_TEXT, gui_label_t::right);
-				lb->buf().printf("%s", tick_to_string( hi.delta_ticks, false ) );
+				if( hi.delta_ticks == 0 ) {
+					lb->buf().append( translator::translate( "now" ) );
+				}
+				else {
+					if( absolute_times.pressed ) {
+						lb->buf().printf( "%s", tick_to_string( welt->get_ticks()+hi.delta_ticks, true ) );
+					}
+					else {
+						lb->buf().printf( "%s", difftick_to_string( hi.delta_ticks, true ) );
+					}
+				}
 				lb->update();
 
 				insert_image(hi.cnv);
