@@ -16,6 +16,7 @@
 #include "../utils/simstring.h"
 #include "../dataobj/environment.h"
 #include "../dataobj/translator.h"
+#include "../unicode.h"
 #include "../player/simplay.h"
 #include "tool_selector.h"
 
@@ -48,6 +49,7 @@ help_frame_t::help_frame_t(char const* const filename) :
 {
 	set_table_layout(2,0);
 	set_alignment(ALIGN_TOP | ALIGN_LEFT);
+	set_margin(scr_size(0,D_MARGIN_TOP), scr_size(0,0));
 
 	add_component(&generaltext);
 	generaltext.add_listener(this);
@@ -84,7 +86,7 @@ help_frame_t::help_frame_t(char const* const filename) :
 		if(  strstart(iter->get_tool_selector()->get_help_filename(),"list.txt" )  ) {
 			continue;
 		}
-		add_helpfile( toolbars, iter->get_tool_selector()->get_name(), iter->get_tool_selector()->get_help_filename(), false, 0 );
+		add_helpfile( toolbars, translator::translate(iter->get_tool_selector()->get_internal_name()), iter->get_tool_selector()->get_help_filename(), false, 0 );
 		if(  strstart(iter->get_tool_selector()->get_help_filename(),"railtools.txt" )  ) {
 			add_helpfile( toolbars, NULL, "bridges.txt", true, 1 );
 			add_helpfile( toolbars, NULL, "signals.txt", true, 1 );
@@ -180,7 +182,7 @@ static char *load_text(char const* const filename )
 {
 	std::string file_prefix= std::string("text") + PATH_SEPARATOR;
 	std::string fullname = file_prefix + translator::get_lang()->iso + PATH_SEPARATOR + filename;
-	dr_chdir(env_t::program_dir);
+	dr_chdir(env_t::data_dir);
 
 	FILE* file = dr_fopen(fullname.c_str(), "rb");
 	if (!file) {
@@ -211,6 +213,18 @@ static char *load_text(char const* const filename )
 			if(  !is_latin  &&  translator::get_lang()->is_latin2_based  ) {
 				is_latin |= strchr( buf, 0xF8 )!=NULL; // "o-umlaut, is forbidden for unicode
 			}
+			if(  !is_latin  &&  translator::get_lang()->is_latin2_based  ) {
+				is_latin |= strchr( buf, 0xFE )!=NULL; // "o-umlaut, is forbidden for unicode
+			}
+			if(  !is_latin  &&  translator::get_lang()->is_latin2_based  ) {
+				is_latin |= strchr( buf, 0xFA )!=NULL; // "o-umlaut, is forbidden for unicode
+			}
+			if(  !is_latin  &&  translator::get_lang()->is_latin2_based  ) {
+				is_latin |= strchr( buf, 0xF3 )!=NULL; // "o-umlaut, is forbidden for unicode
+			}
+			if(  !is_latin  &&  translator::get_lang()->is_latin2_based  ) {
+				is_latin |= strchr( buf, 0xF1 )!=NULL; // "o-umlaut, is forbidden for unicode
+			}
 			if(  is_latin  ) {
 				// we need to translate charwise ...
 				utf8 *buf2 = MALLOCN(utf8, len*2 + 1); //assume the worst
@@ -310,32 +324,42 @@ void help_frame_t::set_helpfile(const char *filename, bool resize_frame )
 		player_t *player = welt->get_active_player();
 		const char *trad_str = translator::translate( "<em>%s</em> - %s<br>\n" );
 		FOR(vector_tpl<tool_t*>, const i, tool_t::char_to_tool) {
-			char const* c = NULL;
+			cbuffer_t c;
 			char str[16];
+			if(  i->command_flags & SIM_MOD_CTRL  ) {
+				c.append( translator::translate( "[CTRL]" ) );
+				c.append( " + " );
+			}
+			if(  i->command_flags & SIM_MOD_SHIFT  ) {
+				c.append( translator::translate( "[SHIFT]" ) );
+				c.append( " + " );
+			}
 			switch (uint16 const key = i->command_key) {
-				case '<': c = "&lt;"; break;
-				case '>': c = "&gt;"; break;
-				case 27:  c = "ESC"; break;
-				case SIM_KEY_HOME: c = translator::translate( "[HOME]" ); break;
-				case SIM_KEY_END:  c = translator::translate( "[END]" ); break;
+				case '<': c.append( "&lt;" ); break;
+				case '>': c.append( "&gt;" ); break;
+				case 27:  c.append( translator::translate( "[ESCAPE]" ) ); break;
+				case 127: c.append( translator::translate( "[DELETE]" ) ); break;
+				case SIM_KEY_HOME: c.append( translator::translate( "[HOME]" ) ); break;
+				case SIM_KEY_END:  c.append( translator::translate( "[END]" ) ); break;
+				case SIM_KEY_SCROLLLOCK: c.append( translator::translate( "[SCROLLLOCK]" ) ); break;
 				default:
-					if (key < 32) {
-						sprintf(str, "%s + %c", translator::translate("[CTRL]"), '@' + key);
+					if (key <= 26) {
+						c.printf("%c", '@' + key);
 					}
 					else if (key < 256) {
-						sprintf(str, "%c", key);
+						c.printf("%c", key);
 					}
 					else if (key < SIM_KEY_F15) {
-						sprintf(str, "F%i", key - SIM_KEY_F1 + 1);
+						c.printf("F%i", key - SIM_KEY_F1 + 1);
 					}
 					else {
 						// try unicode
 						str[utf16_to_utf8(key, (utf8*)str)] = '\0';
+						c.append( str );
 					}
-					c = str;
 					break;
 			}
-			buf.printf(trad_str, c, i->get_tooltip(player));
+			buf.printf(trad_str, c.get_str(), i->get_tooltip(player));
 		}
 		set_text( buf, resize_frame );
 	}
@@ -373,7 +397,7 @@ FILE *help_frame_t::has_helpfile( char const* const filename, int &mode )
 	mode = native;
 	std::string file_prefix = std::string("text") + PATH_SEPARATOR;
 	std::string fullname = file_prefix + translator::get_lang()->iso + PATH_SEPARATOR + filename;
-	dr_chdir(env_t::program_dir);
+	dr_chdir(env_t::data_dir);
 
 	FILE* file = dr_fopen(fullname.c_str(), "rb");
 	if(  !file  &&  strcmp(translator::get_lang()->iso,translator::get_lang()->iso_base)  ) {
@@ -400,6 +424,7 @@ std::string help_frame_t::extract_title( const char *htmllines )
 {
 	const uint8 *start = (const uint8 *)strstr( htmllines, "<title>" );
 	const uint8 *end = (const uint8 *)strstr( htmllines, "</title>" );
+	bool convert_to_utf = false;
 	uint8 title_form_html[1024];
 	if(  start  &&  end  &&  (size_t)(end-start)<lengthof(title_form_html)  ) {
 		uint8 *dest = title_form_html;
@@ -412,7 +437,27 @@ std::string help_frame_t::extract_title( const char *htmllines )
 			}
 			// skip tabs and newlines
 			if(  *c>=32  ) {
-				*dest++ = *c++;
+				// convert to UTF if needed
+				if(  !convert_to_utf  &&  *c >= 0x80  ) {
+					size_t len;
+					utf8_decoder_t::decode(c, len);
+					convert_to_utf = (len <= 1);
+				}
+				if (convert_to_utf) {
+					if (translator::get_lang()->is_latin2_based) {
+						dest += utf16_to_utf8(latin2_to_unicode(*c), dest);
+					}
+					else {
+						dest += utf16_to_utf8(*c, dest);
+					}
+					c++;
+				}
+				else {
+					size_t len;
+					utf32 cc = utf8_decoder_t::decode(c, len);
+					dest += utf16_to_utf8(cc, dest);
+					c += len;
+				}
 			}
 			else {
 				// avoid double spaces
@@ -444,14 +489,18 @@ void help_frame_t::add_helpfile( cbuffer_t &section, const char *titlename, cons
 	if(  titlename == NULL  &&  file  ) {
 		// get the title from the helpfile
 		char htmlline[1024];
-		fread( htmlline, lengthof(htmlline)-1, 1, file );
-		filetitle = extract_title( htmlline );
-		if(  filetitle.empty()  ) {
-			// no idea how to generate the right name ...
-			titlename = filename;
+		if (fread( htmlline, lengthof(htmlline)-1, 1, file ) == 1) {
+			filetitle = extract_title( htmlline );
+			if(  filetitle.empty()  ) {
+				// no idea how to generate the right name ...
+				titlename = filename;
+			}
+			else {
+				titlename = filetitle.c_str();
+			}
 		}
 		else {
-			titlename = filetitle.c_str();
+			titlename = filename;
 		}
 	}
 	else {
@@ -475,7 +524,7 @@ void help_frame_t::add_helpfile( cbuffer_t &section, const char *titlename, cons
 
 /**
  * Called upon link activation
- * @param the hyper ref of the link
+ * @param extra the name of the help file
  */
 bool help_frame_t::action_triggered( gui_action_creator_t *, value_t extra)
 {
@@ -499,5 +548,5 @@ void help_frame_t::resize(const scr_coord delta)
 		helptext.set_pos( generaltext.get_pos() + scr_size( generalwidth, 0 ) );
 	}
 
-	helptext.set_size( get_client_windowsize() - scr_size( generalwidth, 0) -scr_size(D_MARGIN_RIGHT,D_MARGIN_BOTTOM) );
+	helptext.set_size( get_client_windowsize() - scr_size( generalwidth, 0) -scr_size(0,D_MARGIN_BOTTOM) );
 }
