@@ -7,9 +7,12 @@
 #define GUI_LABELLIST_FRAME_T_H
 
 
+#include "simwin.h"
 #include "gui_frame.h"
 #include "components/gui_button.h"
+#include "components/gui_combobox.h"
 #include "components/gui_scrolled_list.h"
+#include "components/gui_textinput.h"
 
 
 /**
@@ -18,12 +21,18 @@
 class labellist_frame_t : public gui_frame_t, private action_listener_t
 {
 private:
-	button_t sortedby;
+	gui_combobox_t sortedby;
 	button_t sorteddir;
 	button_t filter;
 
 	gui_scrolled_list_t scrolly;
 
+	static char name_filter[256];
+	char last_name_filter[256];
+	gui_textinput_t name_filter_input;
+
+	uint32 label_count;
+
 public:
 	labellist_frame_t();
 
@@ -38,6 +47,10 @@ public:
 	void fill_list();
 
 	void map_rotate90( sint16 ) OVERRIDE { fill_list(); }
+
+	void rdwr(loadsave_t* file) OVERRIDE;
+
+	uint32 get_rdwr_id() OVERRIDE { return magic_labellist; }
 };
 
 #endif
