@@ -1,8 +1,6 @@
 /*
- * Copyright (c) 1997 - 2003 Hansjrg Malthaner
- *
- * This file is part of the Simutrans project under the artistic licence.
- * (see licence.txt)
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
  */
 
 #include "labellist_stats_t.h"
@@ -14,6 +12,8 @@
 #include "../utils/simstring.h"
 #include "../utils/cbuffer_t.h"
 
+#include "../dataobj/environment.h"
+
 
 labellist::sort_mode_t labellist_stats_t::sortby = labellist::by_name;
 bool labellist_stats_t::sortreverse = false;
@@ -76,7 +76,7 @@ labellist_stats_t::labellist_stats_t(koord label_pos)
 	label.update();
 
 	if (const label_t *lb = get_label()) {
-		label.set_color(PLAYER_FLAG | color_idx_to_rgb(lb->get_owner()->get_player_color1()));
+		label.set_color(PLAYER_FLAG | color_idx_to_rgb(lb->get_owner()->get_player_color1()+env_t::gui_player_color_dark));
 	}
 }
 
@@ -114,7 +114,6 @@ const char* labellist_stats_t::get_text() const
 /**
  * Events werden hiermit an die GUI-Komponenten
  * gemeldet
- * @author Hj. Malthaner
  */
 bool labellist_stats_t::infowin_event(const event_t * ev)
 {
@@ -134,7 +133,6 @@ bool labellist_stats_t::infowin_event(const event_t * ev)
 
 /**
  * Draw the component
- * @author Hj. Malthaner
  */
 void labellist_stats_t::draw(scr_coord offset)
 {
