@@ -13,7 +13,12 @@
 
 
 namespace labellist {
-	enum sort_mode_t { by_name=0, by_koord, by_player, SORT_MODES };
+	enum sort_mode_t {
+		by_name = 0,
+		by_koord,
+		by_player,
+		SORT_MODES
+	};
 };
 
 class label_t;
