@@ -12,8 +12,6 @@
 #include <syslog.h>
 #endif
 
-#define NO_LOG_EXTERNALS
-
 #include "log.h"
 #include "../simdebug.h"
 #include "../sys/simsys.h"
@@ -39,12 +37,18 @@
 #endif
 #endif
 
+#ifdef __ANDROID__
+#include <android/log.h>
+#include "cbuffer_t.h"
+#define  LOG_TAG    "com.simutrans"
+#endif
+
 /**
  * writes a debug message into the log.
  */
 void log_t::debug(const char *who, const char *format, ...)
 {
-	if(log_debug  &&  debuglevel>=4) {
+	if(log_debug  &&  debuglevel >= log_t::LEVEL_DEBUG) {
 		va_list argptr;
 		va_start(argptr, format);
 
@@ -77,6 +81,14 @@ void log_t::debug(const char *who, const char *format, ...)
 		}
 		va_end( argptr );
 #endif
+
+#ifdef __ANDROID__
+		va_start(argptr, format);
+		cbuffer_t buffer;
+		buffer.printf("Debug: %s\t%s", who, format);
+		__android_log_vprint(ANDROID_LOG_DEBUG, LOG_TAG, buffer, argptr);
+		va_end( argptr );
+#endif
 	}
 }
 
@@ -86,7 +98,7 @@ void log_t::debug(const char *who, const char *format, ...)
  */
 void log_t::message(const char *who, const char *format, ...)
 {
-	if(debuglevel>=3) {
+	if(debuglevel >= log_t::LEVEL_MSG) {
 		va_list argptr;
 		va_start(argptr, format);
 
@@ -119,6 +131,14 @@ void log_t::message(const char *who, const char *format, ...)
 		}
 		va_end( argptr );
 #endif
+
+#ifdef __ANDROID__
+		va_start(argptr, format);
+		cbuffer_t buffer;
+		buffer.printf("Message: %s\t%s", who, format);
+		__android_log_vprint(ANDROID_LOG_INFO, LOG_TAG, buffer, argptr);
+		va_end( argptr );
+#endif
 	}
 }
 
@@ -128,7 +148,7 @@ void log_t::message(const char *who, const char *format, ...)
  */
 void log_t::warning(const char *who, const char *format, ...)
 {
-	if(debuglevel>=2) {
+	if(debuglevel >= log_t::LEVEL_WARN) {
 		va_list argptr;
 		va_start(argptr, format);
 
@@ -161,6 +181,14 @@ void log_t::warning(const char *who, const char *format, ...)
 		}
 		va_end( argptr );
 #endif
+
+#ifdef __ANDROID__
+		va_start(argptr, format);
+		cbuffer_t buffer;
+		buffer.printf("Debug: %s\t%s", who, format);
+		__android_log_vprint(ANDROID_LOG_WARN, LOG_TAG, buffer, argptr);
+		va_end( argptr );
+#endif
 	}
 }
 
@@ -170,7 +198,7 @@ void log_t::warning(const char *who, const char *format, ...)
  */
 void log_t::error(const char *who, const char *format, ...)
 {
-	if(debuglevel>=1) {
+	if(debuglevel >= log_t::LEVEL_ERROR) {
 		va_list argptr;
 		va_start(argptr, format);
 
@@ -184,7 +212,7 @@ void log_t::error(const char *who, const char *format, ...)
 			}
 
 			fprintf(log ,"For help with this error or to file a bug report please see the Simutrans forum:\n");
-			fprintf(log ,"http://forum.simutrans.com\n");
+			fprintf(log ,"https://forum.simutrans.com\n");
 		}
 		va_end(argptr);
 
@@ -195,7 +223,7 @@ void log_t::error(const char *who, const char *format, ...)
 			fprintf(tee,"\n");
 
 			fprintf(tee ,"For help with this error or to file a bug report please see the Simutrans forum:\n");
-			fprintf(tee ,"http://forum.simutrans.com\n");
+			fprintf(tee ,"https://forum.simutrans.com\n");
 		}
 		va_end(argptr);
 
@@ -210,6 +238,14 @@ void log_t::error(const char *who, const char *format, ...)
 		}
 		va_end( argptr );
 #endif
+
+#ifdef __ANDROID__
+		va_start(argptr, format);
+		cbuffer_t buffer;
+		buffer.printf("ERROR: %s\t%s", who, format);
+		__android_log_vprint(ANDROID_LOG_ERROR, LOG_TAG, buffer, argptr);
+		va_end( argptr );
+#endif
 	}
 }
 
@@ -220,7 +256,7 @@ void log_t::error(const char *who, const char *format, ...)
  */
 void log_t::doubled(const char *what, const char *name )
 {
-	if(debuglevel>=2) {
+	if(debuglevel >= log_t::LEVEL_WARN) {
 
 		if( log ) {                             /* only log when a log */
 			fprintf(log ,"Warning: object %s::%s is overlaid!\n",what,name); /* is already open */
@@ -247,17 +283,31 @@ void log_t::doubled(const char *what, const char *name )
 /**
  * writes an error into the log, aborts the program.
  */
-void log_t::fatal(const char *who, const char *format, ...)
+void log_t::fatal(const char* who, const char* format, ...)
 {
 	va_list argptr;
 	va_start(argptr, format);
 
 	static char formatbuffer[512];
-	sprintf( formatbuffer, "FATAL ERROR: %s - %s\nAborting program execution ...\n\nFor help with this error or to file a bug report please see the Simutrans forum at\nhttp://forum.simutrans.com\n", who, format );
+	sprintf(formatbuffer,
+		"FATAL ERROR: %s - %s\n"
+		"Aborting program execution ...\n"
+		"\n"
+		"For help with this error or to file a bug report please see the Simutrans forum at\n"
+		"https://forum.simutrans.com\n",
+		who, format);
 
 	static char buffer[8192];
-	int n = vsprintf( buffer, formatbuffer, argptr );
+	vsprintf(buffer, formatbuffer, argptr);
+	va_end(argptr);
 
+	custom_fatal(buffer);
+}
+
+
+
+void log_t::custom_fatal(char *buffer)
+{
 	if(  log  ) {
 		fputs( buffer, log );
 		if (  force_flush  ) {
@@ -279,23 +329,21 @@ void log_t::fatal(const char *who, const char *format, ...)
 		fputs( buffer, stderr );
 	}
 
-	va_end(argptr);
-
 #if defined MAKEOBJ
-	exit(1);
+	exit(EXIT_FAILURE);
 #elif defined NETTOOL
 	// no display available
 	puts( buffer );
+	abort();
 #else
-#  ifdef MSG_LEVEL
-	int old_level = env_t::verbose_debug;
-#  endif
-	env_t::verbose_debug = 0; // no more window concerning messages
+
+	env_t::verbose_debug = log_t::LEVEL_FATAL; // no more window concerning messages
+
 	if(is_display_init()) {
 		// show notification
 		destroy_all_win( true );
 
-		strcpy( buffer+n+1, "PRESS ANY KEY\n" );
+		strcat( buffer, "PRESS ANY KEY\n" );
 		fatal_news* sel = new fatal_news(buffer);
 
 		scr_coord xy( display_get_width()/2 - sel->get_windowsize().w/2, display_get_height()/2 - sel->get_windowsize().h/2 );
@@ -322,23 +370,15 @@ void log_t::fatal(const char *who, const char *format, ...)
 		dr_fatal_notify(buffer);
 	}
 
-#ifdef DEBUG
-	if (old_level > 4) {
-		// generate a division be zero error, if the user request it
-		static int make_this_a_division_by_zero = 0;
-		printf("%i", 15 / make_this_a_division_by_zero);
-		make_this_a_division_by_zero &= 0xFF;
-	}
-#endif
-#endif
 	abort();
+#endif
 }
 
 
 
 void log_t::vmessage(const char *what, const char *who, const char *format, va_list args )
 {
-	if(debuglevel>=1) {
+	if(debuglevel >= LEVEL_ERROR) {
 		va_list args2;
 
 #if defined(va_copy)
@@ -371,14 +411,16 @@ void log_t::vmessage(const char *what, const char *who, const char *format, va_l
 
 
 // create a logfile for log_debug=true
-log_t::log_t( const char *logfilename, bool force_flush, bool log_debug, bool log_console, const char *greeting, const char* syslogtag )
+log_t::log_t( const char *logfilename, bool force_flush, bool log_debug, bool log_console, const char *greeting, const char* syslogtag ) :
+	log(NULL),
+	tee(NULL),
+	force_flush(force_flush), // if true will always flush when an entry is written to the log
+	log_debug(log_debug),
+	tag(NULL)
+#ifdef SYSLOG
+	, syslog(false)
+#endif
 {
-	log = NULL;
-	syslog = false;
-	this->force_flush = force_flush; /* if true will always flush when */
-	                                 /* an entry is written to the log */
-	this->log_debug = log_debug;
-
 	if(logfilename == NULL) {
 		log = NULL;                       /* not a log */
 		tee = NULL;
