@@ -7,7 +7,9 @@
 #include <stdio.h>
 #include <string.h>
 
-int debuglevel = 2;
+#include "../utils/log.h"
+
+log_t::level_t debuglevel = log_t::LEVEL_WARN;
 
 #include "../simdebug.h"
 #include "../simtypes.h"
@@ -27,46 +29,46 @@ uint32 dr_time(void)
 
 int main(int argc, char* argv[])
 {
-	argv++, argc--;
+	argv++; argc--;
 
-	init_logging("stderr", true, true, "Makeobj version " MAKEOBJ_VERSION " for Simutrans " VERSION_NUMBER " and higher\n", "makeobj");
-	debuglevel = 2; // only warnings and errorsS
+	init_logging("stderr", true, true, "", "makeobj");
+	debuglevel = log_t::LEVEL_WARN; // only warnings and errors
 
 	while(  argc  &&  (  !STRICMP(argv[0], "quiet")  ||  !STRICMP(argv[0], "verbose")  ||  !STRICMP(argv[0], "debug")  )  ) {
 
 		if (argc && !STRICMP(argv[0], "debug")) {
-			argv++, argc--;
-			debuglevel = 4; // everything
+			argv++; argc--;
+			debuglevel = log_t::LEVEL_DEBUG; // everything
 		}
 		else if (argc && !STRICMP(argv[0], "verbose")) {
-			argv++, argc--;
-			debuglevel = 3; // only messages errors
+			argv++; argc--;
+			debuglevel = log_t::LEVEL_MSG; // only messages errors
 		}
 		else if (argc && !STRICMP(argv[0], "quiet")) {
-			argv++, argc--;
-			debuglevel = 1; // only fatal errors
+			argv++; argc--;
+			debuglevel = log_t::LEVEL_ERROR; // only fatal errors
 		}
 	}
 
-	if(  debuglevel>1  ) {
-		puts( "\nMakeobj version " MAKEOBJ_VERSION " for Simutrans " VERSION_NUMBER " and higher\n" );
+	if(  debuglevel>=log_t::LEVEL_WARN  ) {
+		puts( "Makeobj version " MAKEOBJ_VERSION " for Simutrans " VERSION_NUMBER " and higher" );
 		puts( "(c) 2002-2012 V. Meyer, Hj. Malthaner, M. Pristovsek & Simutrans development team\n" );
 	}
 
 	if (argc && !STRICMP(argv[0], "capabilities")) {
-		argv++, argc--;
+		argv++; argc--;
 		root_writer_t::instance()->capabilites();
 		return 0;
 	}
 
 	if (argc && !STRICMP(argv[0], "pak")) {
-		argv++, argc--;
+		argv++; argc--;
 
 		try {
 			const char* dest;
 			if (argc) {
 				dest = argv[0];
-				argv++, argc--;
+				argv++; argc--;
 			}
 			else {
 				dest = "./";
@@ -81,20 +83,20 @@ int main(int argc, char* argv[])
 	}
 
 	if (argc && STRNICMP(argv[0], "pak", 3) == 0) {
-		int img_size = atoi(argv[0] + 3);
+		const int img_size = atoi(argv[0] + 3);
 
 		if (img_size >= 16 && img_size < 32766) {
 			dbg->message( "Image size", "Now set to %dx%d", img_size, img_size );
 
 			obj_writer_t::set_img_size(img_size);
 
-			argv++, argc--;
+			argv++; argc--;
 
 			try {
 				const char* dest;
 				if (argc) {
 					dest = argv[0];
-					argv++, argc--;
+					argv++; argc--;
 				}
 				else {
 					dest = "./";
@@ -106,20 +108,19 @@ int main(int argc, char* argv[])
 				return 1;
 			}
 
-			// image_writer_t::dump_special_histogramm();
 			return 0;
 		}
 	}
 
 	if (argc && !STRICMP(argv[0], "expand")) {
-		argv++, argc--;
+		argv++; argc--;
 
 		try {
 			const char* dest;
 
 			if (argc) {
 				dest = argv[0];
-				argv++, argc--;
+				argv++; argc--;
 			}
 			else {
 				dest = "./";
@@ -137,25 +138,25 @@ int main(int argc, char* argv[])
 
 	if (argc > 1) {
 		if (!STRICMP(argv[0], "dump")) {
-			argv++, argc--;
+			argv++; argc--;
 			root_writer_t::instance()->dump(argc, argv);
 			return 0;
 		}
 		if (!STRICMP(argv[0], "list")) {
-			argv++, argc--;
+			argv++; argc--;
 			root_writer_t::instance()->list(argc, argv);
 			return 0;
 		}
 		if (!STRICMP(argv[0], "extract")) {
-			argv++, argc--;
+			argv++; argc--;
 			root_writer_t::instance()->uncopy(argv[0]);
 			return 0;
 		}
 		if (!STRICMP(argv[0], "merge")) {
-			argv++, argc--;
+			argv++; argc--;
 			try {
 				const char* dest = argv[0];
-				argv++, argc--;
+				argv++; argc--;
 				root_writer_t::instance()->copy(dest, argc, argv);
 			}
 			catch (const obj_pak_exception_t& e) {
@@ -167,7 +168,7 @@ int main(int argc, char* argv[])
 	}
 
 	puts(
-		"\n   Usage: MakeObj [QUIET] [DEBUG] <Command> <params>\n"
+		"\n   Usage: MakeObj [QUIET|VERBOSE|DEBUG] <Command> <params>\n"
 		"\n"
 		"      MakeObj CAPABILITIES\n"
 		"         Gives the list of objects, this program can read\n"
@@ -190,10 +191,10 @@ int main(int argc, char* argv[])
 		"      with a trailing slash a directory is searched rather than a file\n"
 		"      default for PAK is PAK ./ ./\n"
 		"\n"
-		"      with QUIET as first arg copyright message will be omitted\n"
+		"      with QUIET as first arg status and copyright messages are omitted\n"
 		"\n"
 		"      with VERBOSE as first arg also unused lines\n"
-		"      and unassinged entrys are printed\n"
+		"      and unassigned entries are printed\n"
 		"\n"
 		"      DEBUG dumps extended information about the pak process.\n"
 		"          Source: interpreted line from .dat file\n"
