@@ -1,5 +1,11 @@
-#ifndef _NETWORK_ADDRESS_H_
-#define _NETWORK_ADDRESS_H_
+/*
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
+ */
+
+#ifndef NETWORK_NETWORK_ADDRESS_H
+#define NETWORK_NETWORK_ADDRESS_H
+
 
 #include "../simtypes.h"
 #include "../tpl/vector_tpl.h"
@@ -42,7 +48,6 @@ public:
 
 	/**
 	 * Return human readable representation of this IP address
-	 * @author Timothy Baldock <tb@entropy.me.uk>
 	 */
 	const char* get_str () const;
 
