@@ -56,7 +56,7 @@ void network_command_t::rdwr()
 		ready = true;
 	}
 	packet->rdwr_long(our_client_id);
-	dbg->message("network_command_t::rdwr", "%s packet_id=%d, client_id=%ld", packet->is_saving() ? "write" : "read", id, our_client_id);
+	dbg->message("network_command_t::rdwr", "%s packet_id=%s, client_id=%u", packet->is_saving() ? "write" : "read", get_name(), our_client_id);
 }
 
 
@@ -75,7 +75,7 @@ bool network_command_t::send(SOCKET s)
 	packet->send(s, true);
 	bool ok = packet->is_ready();
 	if (!ok) {
-		dbg->warning("network_command_t::send", "send packet_id=%d to [%d] failed", id, s);
+		dbg->warning("network_command_t::send", "Sending %s to [%d] failed", get_name(), s);
 	}
 	return ok;
 }
@@ -150,3 +150,31 @@ void nwc_service_t::rdwr()
 		default: ;
 	}
 }
+
+
+const char *network_command_t::id_to_string(uint16 id)
+{
+#define CASE_TO_STRING(c) case c: return #c
+
+	switch (id) {
+	CASE_TO_STRING(NWC_INVALID);
+	CASE_TO_STRING(NWC_GAMEINFO);
+	CASE_TO_STRING(NWC_NICK);
+	CASE_TO_STRING(NWC_CHAT);
+	CASE_TO_STRING(NWC_JOIN);
+	CASE_TO_STRING(NWC_SYNC);
+	CASE_TO_STRING(NWC_GAME);
+	CASE_TO_STRING(NWC_READY);
+	CASE_TO_STRING(NWC_TOOL);
+	CASE_TO_STRING(NWC_CHECK);
+	CASE_TO_STRING(NWC_PAKSETINFO);
+	CASE_TO_STRING(NWC_SERVICE);
+	CASE_TO_STRING(NWC_AUTH_PLAYER);
+	CASE_TO_STRING(NWC_CHG_PLAYER);
+	CASE_TO_STRING(NWC_SCENARIO);
+	CASE_TO_STRING(NWC_SCENARIO_RULES);
+	CASE_TO_STRING(NWC_STEP);
+	}
+
+	return "<unknown network command>";
+}
