@@ -1,22 +1,18 @@
 /*
- *  Copyright (c) 1997 - 2002 by Volker Meyer & Hansjrg Malthaner
- *
- * This file is part of the Simutrans project under the artistic licence.
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
  */
 
-#ifndef __OBJ_DESC_H
-#define __OBJ_DESC_H
+#ifndef DESCRIPTOR_OBJ_DESC_H
+#define DESCRIPTOR_OBJ_DESC_H
+
 
 #include <cstddef>
 #include "../simtypes.h"
 
-/*
- *  Author:
- *      Volker Meyer
- *
- *  Description:
- *      Basis of all desc_t classes, which are loaded from the .pak files.
- *	No virtual methods are allowed!
+/**
+ * Basis of all desc_t classes, which are loaded from the .pak files.
+ * No virtual methods are allowed!
  */
 class obj_desc_t {
 public:
