@@ -5,10 +5,12 @@
 
 #include <string.h>
 #include "../simdebug.h"
-#include "../simtool.h"
+#include "../simmenu.h"
 #include "simwin.h"
 #include "../simworld.h"
+#include "../player/simplay.h"
 
+#include "../dataobj/environment.h"
 #include "../dataobj/translator.h"
 #include "../network/network_cmd_ingame.h"
 
@@ -28,7 +30,7 @@ password_frame_t::password_frame_t( player_t *player ) :
 
 	this->player = player;
 
-	if(  !player->is_locked()  ||  (welt->get_active_player_nr()==1  &&  !welt->get_public_player()->is_locked())   ) {
+	if(  !player->is_locked()  ||  (welt->get_active_player_nr()==PUBLIC_PLAYER_NR  &&  !welt->get_public_player()->is_locked())   ) {
 		// allow to change name name
 		tstrncpy( player_name_str, player->get_name(), lengthof(player_name_str) );
 		player_name.set_text(player_name_str, lengthof(player_name_str));
@@ -68,14 +70,16 @@ bool password_frame_t::action_triggered( gui_action_creator_t *comp, value_t p )
 		}
 		// Enter-Key pressed
 		// test for matching password to unlock
-		SHA1 sha1;
 		size_t len = strlen( password.get_text() );
-		sha1.Input( password.get_text(), len );
+
 		pwd_hash_t hash;
 		// remove hash to re-open slot if password is empty
 		if(len>0) {
-			hash.set(sha1);
+			SHA1 sha1;
+			sha1.Input( password.get_text(), len );
+			sha1.Result(hash);
 		}
+
 		// store the hash
 		welt->store_player_password_hash( player->get_player_nr(), hash );
 
@@ -89,7 +93,7 @@ bool password_frame_t::action_triggered( gui_action_creator_t *comp, value_t p )
 			/* if current active player is player 1 and this is unlocked, he may reset passwords
 			 * otherwise you need the valid previous password
 			 */
-			if(  !player->is_locked()  ||  (welt->get_active_player_nr()==1  &&  !welt->get_public_player()->is_locked())   ) {
+			if(  !player->is_locked()  ||  (welt->get_active_player_nr()==PUBLIC_PLAYER_NR  &&  !welt->get_public_player()->is_locked())   ) {
 				// set password
 				player->access_password_hash() = hash;
 				player->unlock(true, false);
