@@ -9,7 +9,6 @@
 #include "../simcolor.h"
 #include "../simworld.h"
 #include "../simmenu.h"
-#include "../simtool.h"
 #include "../network/network_cmd_ingame.h"
 #include "../dataobj/environment.h"
 #include "../dataobj/scenario.h"
@@ -54,7 +53,7 @@ ki_kontroll_t::ki_kontroll_t() :
 			player_active[i-2].init(button_t::square_state, "");
 			player_active[i-2].add_listener(this);
 			player_active[i-2].set_rigid(true);
-			add_component( player_active+i-2 );
+			add_component( player_active+(i-2) );
 		}
 		else {
 			new_component<gui_empty_t>();
@@ -109,7 +108,6 @@ ki_kontroll_t::ki_kontroll_t() :
 	freeplay.pressed = welt->get_settings().is_freeplay();
 	add_component( &freeplay, 5 );
 
-	update_income();
 	update_data(); // calls reset_min_windowsize
 
 	set_windowsize(get_min_windowsize());
@@ -137,7 +135,7 @@ bool ki_kontroll_t::action_triggered( gui_action_creator_t *comp,value_t p )
 
 				// if scripted ai without script -> open script selector window
 				ai_scripted_t *ai = dynamic_cast<ai_scripted_t*>(welt->get_player(i));
-				if (ai  &&  !ai->has_script()) {
+				if (ai  &&  !ai->has_script()  &&  (!env_t::networkmode  ||  env_t::server)) {
 					create_win( new ai_selector_t(i), w_info, magic_finances_t + i );
 				}
 			}
@@ -160,7 +158,7 @@ bool ki_kontroll_t::action_triggered( gui_action_creator_t *comp,value_t p )
 			player_get_finances[i].pressed = false;
 			// if scripted ai without script -> open script selector window
 			ai_scripted_t *ai = dynamic_cast<ai_scripted_t*>(welt->get_player(i));
-			if (ai  &&  !ai->has_script()) {
+			if (ai  &&  !ai->has_script()  &&  (!env_t::networkmode  ||  env_t::server)) {
 				create_win( new ai_selector_t(i), w_info, magic_finances_t + i );
 			}
 			else {
@@ -302,6 +300,9 @@ void ki_kontroll_t::update_data()
 			ai_income[i]->set_visible(false);
 		}
 	}
+
+	update_income();
+
 	reset_min_windowsize();
 }
 
@@ -316,6 +317,7 @@ void ki_kontroll_t::update_income()
 			if (i != 1 && !welt->get_settings().is_freeplay() && player->get_finance()->get_history_com_year(0, ATC_NETWEALTH) < 0) {
 				ai_income[i]->set_color( MONEY_MINUS );
 				ai_income[i]->buf().append(translator::translate("Company bankrupt"));
+				ai_income[i]->set_align(gui_label_t::left);
 			}
 			else {
 				double account=player->get_account_balance_as_double();
@@ -323,6 +325,7 @@ void ki_kontroll_t::update_income()
 				money_to_string(str, account );
 				ai_income[i]->buf().append(str);
 				ai_income[i]->set_color( account>=0.0 ? MONEY_PLUS : MONEY_MINUS );
+				ai_income[i]->set_align(gui_label_t::money_right);
 			}
 		}
 		ai_income[i]->update();
