@@ -1,12 +1,11 @@
 /*
- * Copyright (c) 1997 - 2003 Hansjrg Malthaner
- *
- * This file is part of the Simutrans project under the artistic licence.
- * (see licence.txt)
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
  */
 
-#ifndef privatesign_info_t_h
-#define privatesign_info_t_h
+#ifndef GUI_PRIVATESIGN_INFO_H
+#define GUI_PRIVATESIGN_INFO_H
+
 
 #include "../simconst.h"
 #include "obj_info.h"
@@ -18,7 +17,6 @@ class roadsign_t;
 
 /**
  * Info window for factories
- * @author Hj. Malthaner
  */
 class privatesign_info_t : public obj_infowin_t, public action_listener_t
 {
@@ -32,7 +30,6 @@ class privatesign_info_t : public obj_infowin_t, public action_listener_t
 	/**
 	 * Set the window associated helptext
 	 * @return the filename for the helptext, or NULL
-	 * @author Hj. Malthaner
 	 */
 	const char *get_help_filename() const OVERRIDE {return "privatesign_info.txt";}
 
