@@ -13,6 +13,7 @@
 #include "bridge_reader.h"
 #include "../obj_node_info.h"
 #include "../../network/pakset_info.h"
+#include "../../tpl/array_tpl.h"
 
 
 void bridge_reader_t::register_obj(obj_desc_t *&data)
@@ -27,25 +28,21 @@ void bridge_reader_t::register_obj(obj_desc_t *&data)
 }
 
 
-obj_desc_t * bridge_reader_t::read_node(FILE *fp, obj_node_info_t &node)
+obj_desc_t *bridge_reader_t::read_node(FILE *fp, obj_node_info_t &node)
 {
-	// DBG_DEBUG("bridge_reader_t::read_node()", "called");
-	ALLOCA(char, desc_buf, node.size);
-
-	bridge_desc_t *desc = new bridge_desc_t();
-
-	// Read data
-	fread(desc_buf, node.size, 1, fp);
-
-	char * p = desc_buf;
+	array_tpl<char> desc_buf(node.size);
+	if (fread(desc_buf.begin(), node.size, 1, fp) != 1) {
+		return NULL;
+	}
+	char *p = desc_buf.begin();
 
 	// old versions of PAK files have no version stamp.
 	// But we know, the higher most bit was always cleared.
-
 	const uint16 v = decode_uint16(p);
 	const int version = v & 0x8000 ? v & 0x7FFF : 0;
 
 	// some defaults
+	bridge_desc_t *desc = new bridge_desc_t();
 	desc->maintenance = 800;
 	desc->pillars_every = 0;
 	desc->pillars_asymmetric = false;
