@@ -11,6 +11,7 @@
 #include "../obj_node_info.h"
 #include "../goods_desc.h"
 #include "../../network/pakset_info.h"
+#include "../../tpl/array_tpl.h"
 
 
 void goods_reader_t::register_obj(obj_desc_t *&data)
@@ -36,26 +37,23 @@ bool goods_reader_t::successfully_loaded() const
 
 obj_desc_t * goods_reader_t::read_node(FILE *fp, obj_node_info_t &node)
 {
-	ALLOCA(char, desc_buf, node.size);
-
-	goods_desc_t *desc = new goods_desc_t();
-
-	// some defaults
-	desc->speed_bonus = 0;
-	desc->weight_per_unit = 100;
-	desc->color = 255;
-
-	// Read data
-	fread(desc_buf, node.size, 1, fp);
-
-	char * p = desc_buf;
+	array_tpl<char> desc_buf(node.size);
+	if (fread(desc_buf.begin(), node.size, 1, fp) != 1) {
+		return NULL;
+	}
+	char *p = desc_buf.begin();
 
 	// old versions of PAK files have no version stamp.
 	// But we know, the higher most bit was always cleared.
-
 	const uint16 v = decode_uint16(p);
 	const int version = v & 0x8000 ? v & 0x7FFF : 0;
 
+	// some defaults
+	goods_desc_t *desc = new goods_desc_t();
+	desc->speed_bonus = 0;
+	desc->weight_per_unit = 100;
+	desc->color = 255;
+
 	if(version == 1) {
 		// Versioned node, version 1
 		desc->base_value = decode_uint16(p);
