@@ -5,13 +5,14 @@
 
 #include <stdio.h>
 
-#include "../../vehicle/simpeople.h"
+#include "../../vehicle/pedestrian.h"
 #include "../pedestrian_desc.h"
 #include "../obj_node_info.h"
 #include "../intro_dates.h"
 
 #include "pedestrian_reader.h"
 #include "../../network/pakset_info.h"
+#include "../../tpl/array_tpl.h"
 
 
 void pedestrian_reader_t::register_obj(obj_desc_t *&data)
@@ -38,20 +39,18 @@ bool pedestrian_reader_t::successfully_loaded() const
  */
 obj_desc_t * pedestrian_reader_t::read_node(FILE *fp, obj_node_info_t &node)
 {
-	ALLOCA(char, desc_buf, node.size);
-
-	pedestrian_desc_t *desc = new pedestrian_desc_t();
-
-	// Read data
-	fread(desc_buf, node.size, 1, fp);
-	char * p = desc_buf;
+	array_tpl<char> desc_buf(node.size);
+	if (fread(desc_buf.begin(), node.size, 1, fp) != 1) {
+		return NULL;
+	}
+	char *p = desc_buf.begin();
 
 	// old versions of PAK files have no version stamp.
 	// But we know, the higher most bit was always cleared.
-
 	const uint16 v = decode_uint16(p);
 	const int version = v & 0x8000 ? v & 0x7FFF : 0;
 
+	pedestrian_desc_t *desc = new pedestrian_desc_t();
 	desc->steps_per_frame = 0;
 	desc->offset          = 20;
 
