@@ -200,12 +200,13 @@ bool route_t::find_route(karte_t *welt, const koord3d start, test_driver_t *tdri
 		const ribi_t::ribi ribi =  tdriver->get_ribi(gr)  &  ( ~ribi_t::reverse_single(tmp->ribi_from) );
 		for(  int r=0;  r<4;  r++  ) {
 			// a way goes here, and it is not marked (i.e. in the closed list)
-			grund_t* to;
-			if(  (ribi & ribi_t::nsew[r] )!=0 // do not go backwards
-			    && koord_distance(start, gr->get_pos() + koord::nsew[r])<max_depth // not too far away
-			    && gr->get_neighbour(to, wegtyp, ribi_t::nsew[r])  // is connected
+			grund_t* to = NULL;
+			if(  (ribi & ribi_t::nesw[r] )!=0 // do not go backwards
+			    && koord_distance(start, gr->get_pos() + koord::nesw[r])<max_depth // not too far away
+			    && gr->get_neighbour(to, wegtyp, ribi_t::nesw[r])  // is connected
 			    && !marker.is_marked(to) // not already tested
 			    && tdriver->check_next_tile(to) // can be driven on
+				&& step < MAX_STEP // do not overrun nodes[]
 			) {
 				// not in there or taken out => add new
 				ANode* k = &nodes[step++];
@@ -214,10 +215,10 @@ bool route_t::find_route(karte_t *welt, const koord3d start, test_driver_t *tdri
 				k->gr = to;
 				k->count = tmp->count+1;
 				k->f = 0;
-				k->g = tmp->g + tdriver->get_cost(to, to->get_weg(wegtyp), max_khm, ribi_t::nsew[r]);
-				k->ribi_from = ribi_t::nsew[r];
+				k->g = tmp->g + tdriver->get_cost(to, to->get_weg(wegtyp), max_khm, ribi_t::nesw[r]);
+				k->ribi_from = ribi_t::nesw[r];
 
-				uint8 current_dir = ribi_t::nsew[r];
+				uint8 current_dir = ribi_t::nesw[r];
 				if(tmp->parent!=NULL) {
 					current_dir |= tmp->ribi_from;
 					if(tmp->dir!=current_dir) {
@@ -315,7 +316,7 @@ bool route_t::intern_calc_route(karte_t *welt, const koord3d ziel, const koord3d
 	 * Reference:
 	 *  Harabor D. and Grastien A. 2011. Online Graph Pruning for Pathfinding on Grid Maps.
 	 *  In Proceedings of the 25th National Conference on Artificial Intelligence (AAAI), San Francisco, USA.
-	 *  http://users.cecs.anu.edu.au/~dharabor/data/papers/harabor-grastien-aaai11.pdf
+	 *  https://users.cecs.anu.edu.au/~dharabor/data/papers/harabor-grastien-aaai11.pdf
 	 */
 	const bool use_jps     = tdriver->get_waytype()==water_wt;
 
@@ -473,9 +474,12 @@ bool route_t::intern_calc_route(karte_t *welt, const koord3d ziel, const koord3d
 
 				const uint32 new_f = new_g + dist + turns * 3 + costup;
 
+				if (step >= MAX_STEP) {
+					break; // Do not overrun nodes[]
+				}
+
 				// add new
-				ANode* k = &nodes[step];
-				step ++;
+				ANode* k = &nodes[step++];
 
 				k->parent = tmp;
 				k->gr = to;
