@@ -48,7 +48,15 @@ protected:
 
 public:
 	enum schedule_type {
-		schedule = 0, truck_schedule = 1, train_schedule = 2, ship_schedule = 3, airplane_schedule = 4, monorail_schedule = 5, tram_schedule = 6, maglev_schedule = 7, narrowgauge_schedule = 8,
+		schedule             = 0,
+		truck_schedule       = 1,
+		train_schedule       = 2,
+		ship_schedule        = 3,
+		airplane_schedule    = 4,
+		monorail_schedule    = 5,
+		tram_schedule        = 6,
+		maglev_schedule      = 7,
+		narrowgauge_schedule = 8
 	};
 
 	minivec_tpl<schedule_entry_t> entries;
@@ -72,6 +80,17 @@ public:
 
 	virtual waytype_t get_waytype() const = 0;
 
+	// remove this entry
+	void remove_entry( uint8 entry );
+
+	// move the entry to front (and wrap)
+	// you must use this function so all groups of departue entries are moved together
+	void move_entry_forward( uint8 entry );
+
+	// move the entry to back (and wrap)
+	// you must use this function so all groups of departue entries are moved together
+	void move_entry_backward( uint8 entry );
+
 	/**
 	 * Get current stop of the schedule.
 	 */
@@ -91,8 +110,19 @@ public:
 
 	/// advance current_stop by one
 	void advance() {
-		if(  !entries.empty()  ) {
-			current_stop = (current_stop+1)%entries.get_count();
+		if( !entries.empty() ) {
+			if( entries[ current_stop ].minimum_loading > 100 ) {
+				// skip the whole departure group
+				for( uint8 next_stop = (current_stop + 1) % entries.get_count(); next_stop != current_stop; next_stop = (next_stop + 1) % entries.get_count() ) {
+					if( entries[ next_stop ].pos != entries[ current_stop ].pos ) {
+						current_stop = next_stop;
+						break;
+					}
+				}
+			}
+			else {
+				current_stop = (current_stop+1)%entries.get_count();
+			}
 		}
 	}
 
@@ -115,17 +145,24 @@ public:
 	/**
 	 * Inserts a coordinate at current_stop into the schedule.
 	 */
-	bool insert(const grund_t* gr, uint8 minimum_loading = 0, uint8 waiting_time_shift = 0);
+	bool insert(const grund_t* gr, uint8 minimum_loading = 0, uint16 waiting_time = 0);
 
 	/**
 	 * Appends a coordinate to the schedule.
 	 */
-	bool append(const grund_t* gr, uint8 minimum_loading = 0, uint8 waiting_time_shift = 0);
+	bool append(const grund_t* gr, uint8 minimum_loading = 0, uint16 waiting_time = 0);
 
 	/**
-	 * Cleanup a schedule, removes double entries.
+	 * Makes schedule valid for driving:
+	 * - remove double entries
+	 * - clear schedule if it contains just one entry
+	 * - call make_current_stop_valid
 	 */
-	void cleanup();
+	void make_valid();
+	/**
+	 * Remove double entries.
+	 */
+	void remove_double_entries();
 
 	/**
 	 * Remove current_stop entry from the schedule.
@@ -142,15 +179,16 @@ public:
 	bool matches(karte_t *welt, const schedule_t *schedule);
 
 	/**
-	 * Compare this schedule with another, ignoring order and exact positions and waypoints.
+	 * Compare this schedule with another, ignoring order and exact positions and waypoints, wazting/scheduling.
 	 */
 	bool similar( const schedule_t *schedule, const player_t *player );
 
 	/**
 	 * Calculates a return way for this schedule.
-	 * Will add elements 1 to end in reverse order to schedule.
+	 * Will add elements 1 to end in reverse order to schedule if ture
+	 * Or just mirror order if false
 	 */
-	void add_return_way();
+	void add_return_way(bool);
 
 	virtual schedule_t* copy() = 0;//{ return new schedule_t(this); }
 
@@ -160,7 +198,11 @@ public:
 	// fills the given buffer with a schedule
 	void sprintf_schedule( cbuffer_t &buf ) const;
 
-	// converts this string into a schedule
+	/**
+	 * Converts this string into a schedule.
+	 * Ensure valid schedule.
+	 * @returns true reading worked and schedule is non-empty
+	 */
 	bool sscanf_schedule( const char * );
 
 	/**
