@@ -1,9 +1,10 @@
 /*
- * sound with SDL_mixer.dll (not changing the volume of other programs)
- *
- * This file is part of the Simutrans project under the artistic license.
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
  */
 
+// Sound with SDL_mixer.dll (not changing the volume of other programs)
+
 #include <SDL.h>
 #include <SDL_mixer.h>
 #include <string.h>
@@ -12,7 +13,7 @@
 
 
 /*
- * Hajo: flag if sound module should be used
+ * flag if sound module should be used
  */
 static int use_sound = 0;
 
@@ -32,7 +33,7 @@ bool dr_init_sound()
 {
 	int sound_ok = 0;
 	if(use_sound!=0) {
-		return true;	// avoid init twice
+		return true; // avoid init twice
 	}
 	use_sound = 1;
 
@@ -61,7 +62,7 @@ bool dr_init_sound()
 
 			}
 			else {
-				dbg->important("Open audio channel doesn't meet requirements. Muting");
+				dbg->error("dr_init_sound()","Open audio channel doesn't meet requirements. Muting");
 				Mix_CloseAudio();
 				SDL_QuitSubSystem(SDL_INIT_AUDIO);
 			}
@@ -69,12 +70,12 @@ bool dr_init_sound()
 
 		}
 		else {
-			dbg->important("Could not open required audio channel. Muting");
+			dbg->error("dr_init_sound()","Could not open required audio channel. Muting");
 			SDL_QuitSubSystem(SDL_INIT_AUDIO);
 		}
 	}
 	else {
-		dbg->important("Could not initialize sound system. Muting");
+		dbg->error("dr_init_sound()","Could not initialize sound system. Muting");
 	}
 
 	use_sound = sound_ok ? 1: -1;
@@ -86,7 +87,6 @@ bool dr_init_sound()
 /**
  * loads a sample
  * @return a handle for that sample or -1 on failure
- * @author Hj. Malthaner
  */
 int dr_load_sample(const char *filename)
 {
@@ -113,7 +113,6 @@ int dr_load_sample(const char *filename)
 /**
  * plays a sample
  * @param key the key for the sample to be played
- * @author Hj. Malthaner
  */
 void dr_play_sample(int sample_number, int volume)
 {
