@@ -10,7 +10,7 @@
 #include "../dataobj/environment.h"
 #include "../dataobj/translator.h"
 #include "../player/finance.h" // MAX_PLAYER_HISTORY_YEARS
-#include "../vehicle/simvehicle.h"
+#include "../vehicle/vehicle_base.h"
 #include "settings_stats.h"
 #include "components/gui_divider.h"
 
@@ -42,7 +42,8 @@ static char const* const version[] =
 	"0.120.2",
 	"0.120.3",
 	"0.120.4",
-	"0.120.5"
+	"0.120.5",
+	"122.0"
 };
 
 bool settings_general_stats_t::action_triggered(gui_action_creator_t *comp, value_t v)
@@ -63,6 +64,7 @@ void settings_general_stats_t::init(settings_t const* const sets)
 	INIT_INIT
 
 	// combobox for savegame version
+	savegame.clear_elements();
 	for(  uint32 i=0;  i<lengthof(version);  i++  ) {
 		savegame.new_component<gui_scrolled_list_t::const_text_scrollitem_t>( version[i]+2, SYSCOL_TEXT ) ;
 		if(  strcmp(version[i],env_t::savegame_version_str)==0  ) {
@@ -219,8 +221,8 @@ void settings_routing_stats_t::init(settings_t const* const sets)
 	INIT_NUM( "station_coverage", sets->get_station_coverage(), 1, 8, gui_numberinput_t::AUTOLINEAR, false );
 	INIT_NUM( "allow_merge_distant_halt", sets->get_allow_merge_distant_halt(), 0, 0x7FFFFFFFul, gui_numberinput_t::POWER2, false );
 	SEPERATOR
-	INIT_NUM( "max_route_steps", sets->get_max_route_steps(), 0, 0x7FFFFFFFul, gui_numberinput_t::POWER2, false );
-	INIT_NUM( "max_choose_route_steps", sets->get_max_choose_route_steps(), 0, 0x7FFFFFFFul, gui_numberinput_t::POWER2, false );
+	INIT_NUM( "max_route_steps", sets->get_max_route_steps(), 1, 0x7FFFFFFFul, gui_numberinput_t::POWER2, false );
+	INIT_NUM( "max_choose_route_steps", sets->get_max_choose_route_steps(), 1, 0x7FFFFFFFul, gui_numberinput_t::POWER2, false );
 	INIT_NUM( "max_hops", sets->get_max_hops(), 100, 65000, gui_numberinput_t::POWER2, false );
 	INIT_NUM( "max_transfers", sets->get_max_transfers(), 1, 100, gui_numberinput_t::AUTOLINEAR, false );
 	SEPERATOR
@@ -232,6 +234,8 @@ void settings_routing_stats_t::init(settings_t const* const sets)
 	INIT_NUM( "way_tunnel", sets->way_count_tunnel, 1, 1000, gui_numberinput_t::AUTOLINEAR, false );
 	INIT_NUM( "way_max_bridge_len", sets->way_max_bridge_len, 1, 1000, gui_numberinput_t::AUTOLINEAR, false );
 	INIT_NUM( "way_leaving_road", sets->way_count_leaving_road, 1, 1000, gui_numberinput_t::AUTOLINEAR, false );
+	SEPERATOR
+	INIT_BOOL( "stop_halt_as_scheduled", sets->get_stop_halt_as_scheduled() );
 
 	INIT_END
 }
@@ -258,6 +262,8 @@ void settings_routing_stats_t::read(settings_t* const sets)
 	READ_NUM_VALUE( sets->way_count_tunnel );
 	READ_NUM_VALUE( sets->way_max_bridge_len );
 	READ_NUM_VALUE( sets->way_count_leaving_road );
+
+	READ_BOOL_VALUE( sets->stop_halt_as_scheduled );
 }
 
 
@@ -510,7 +516,9 @@ void settings_climates_stats_t::init(settings_t* const sets)
 	INIT_NUM_NEW( "Map roughness", mountain_roughness_start, 0, min(10, 11-((mountain_height_start+99)/100)), gui_numberinput_t::AUTOLINEAR, false );
 
 	SEPERATOR
+	INIT_NUM_NEW( "Wind direction", sets->wind_direction, 0, 3, 1, true );
 	// combobox for climate generator
+	climate_generate.clear_elements();
 	for(  uint32 i=0;  i<lengthof(climate_generate_string);  i++  ) {
 		climate_generate.new_component<gui_scrolled_list_t::const_text_scrollitem_t>( climate_generate_string[i], SYSCOL_TEXT ) ;
 	}
@@ -530,6 +538,8 @@ void settings_climates_stats_t::init(settings_t* const sets)
 		}
 	}
 	end_table();
+	new_component<gui_empty_t>();
+
 	INIT_NUM_NEW( "climate area percentage", sets->get_patch_size_percentage(), 0, 100, gui_numberinput_t::AUTOLINEAR, false );
 
 	SEPERATOR
@@ -544,12 +554,13 @@ void settings_climates_stats_t::init(settings_t* const sets)
 	// the following are independent and thus need no listener
 	SEPERATOR
 	// combobox for trees generator
+	tree_generate.clear_elements();
 	for(  uint32 i=0;  i<lengthof(tree_generate_string);  i++  ) {
 		tree_generate.new_component<gui_scrolled_list_t::const_text_scrollitem_t>( tree_generate_string[i], SYSCOL_TEXT ) ;
 	}
-	tree_generate.set_selection( sets->get_tree() );
+	tree_generate.set_selection( sets->get_tree_distribution() );
 	tree_generate.set_focusable( false );
-	add_component( &tree_generate );
+	add_component( &tree_generate, 2);
 	INIT_NUM_NEW( "forest_base_size", sets->get_forest_base_size(), 10, 255, 1, false );
 	INIT_NUM_NEW( "forest_map_size_divisor", sets->get_forest_map_size_divisor(), 2, 255, 1, false );
 	INIT_NUM_NEW( "forest_count_divisor", sets->get_forest_count_divisor(), 2, 255, 1, false );
@@ -565,11 +576,12 @@ void settings_climates_stats_t::init(settings_t* const sets)
 void settings_climates_stats_t::read(settings_t* const sets)
 {
 	sets->climate_generator = (settings_t::climate_generate_t)max( 0, climate_generate.get_selection() );
-	sets->tree = max( 0, tree_generate.get_selection() );
+	sets->tree_distribution = ::clamp(tree_generate.get_selection(), (int)settings_t::TREE_DIST_NONE, (int)settings_t::TREE_DIST_COUNT-1 );
 	READ_INIT
 	READ_NUM_VALUE_NEW( env_t::pak_height_conversion_factor );
 	READ_NUM_VALUE_NEW( sets->groundwater );
 	READ_NUM_VALUE_NEW( sets->max_mountain_height );
+	READ_NUM_VALUE_NEW( sets->wind_direction );
 	double n = 0;
 	READ_NUM_VALUE_NEW( n );
 	if(  new_world  ) {
