@@ -9,7 +9,7 @@
 
 #include "roadsign.h"
 
-#include "../simobj.h"
+#include "simobj.h"
 
 
 /**
@@ -22,7 +22,7 @@ class signal_t : public roadsign_t
 {
 public:
 	signal_t(loadsave_t *file);
-	signal_t(player_t *player, koord3d pos, ribi_t::ribi dir,const roadsign_desc_t *desc, bool preview = false) : roadsign_t(player,pos,dir,desc,preview) { state = rot;}
+	signal_t(player_t *player, koord3d pos, ribi_t::ribi dir,const roadsign_desc_t *desc, bool preview = false) : roadsign_t(player,pos,dir,desc,preview) { state = STATE_RED;}
 
 	/// @copydoc obj_t::info
 	void info(cbuffer_t & buf) const OVERRIDE;
