@@ -52,9 +52,10 @@ public:
 	};
 
 	/** Constants */
-	enum { default_vehicle_length=4};
+	enum { default_vehicle_length = 4 };
 
-	enum states {INITIAL,
+	enum states {
+		INITIAL,
 		EDIT_SCHEDULE,
 		ROUTING_1,
 		DUMMY4,
@@ -89,6 +90,12 @@ private:
 	 */
 	sint32 wait_lock;
 
+	/**
+	 * The convoi is gradually loaded for each vehicle, i.e. there is a constant loadin speed.
+	 * Hence the tick value
+	 */
+	uint32 last_load_tick;
+
 	states state;
 	// 32 bytes (state is int is 4 byte)
 
@@ -129,7 +136,10 @@ private:
 	 * convois will slow down before it, if this is not a waypoint or the cannot pass
 	 * The slowdown is done by the vehicle routines
 	 */
-	uint16 next_stop_index;
+	route_t::index_t next_stop_index;
+
+	// if state == LOADING, this is true while unloading
+	bool unloading_state;
 
 	sint32 speed_limit;
 	// needed for speed control/calculation
@@ -159,7 +169,7 @@ private:
 	 * Number of vehicles in this convoi.
 	 */
 	// TODO number of vehicles is stored in array_tpl too!
-	uint8 anz_vehikel;
+	uint8 vehicle_count;
 
 	uint32 next_wolke; // time to next smoke
 
@@ -253,7 +263,7 @@ private:
 	 * this give the index until which the route has been reserved. It is used for
 	 * restoring reservations after loading a game.
 	 */
-	uint16 next_reservation_index;
+	route_t::index_t next_reservation_index;
 
 	/**
 	 * Time when convoi arrived at the current stop
@@ -327,7 +337,7 @@ private:
 	*/
 	void set_erstes_letztes();
 
-	// returns the index of the vehikel at position length (16=1 tile)
+	// returns the index of the vehicle at position length (16=1 tile)
 	int get_vehicle_at_length(uint16);
 
 	/**
@@ -370,9 +380,15 @@ private:
 	 */
 	void unregister_stops();
 
-	uint32 move_to(uint16 start_index);
+	uint32 move_to(route_t::index_t start_index);
 
 public:
+	uint32 get_arrival_ticks() const { return arrived_time; }
+
+	uint32 get_departure_ticks(uint32) const;
+
+	uint32 get_departure_ticks() const { return get_departure_ticks(arrived_time); }
+
 	/**
 	* Convoi haelt an Haltestelle und setzt quote fuer Fracht
 	*/
@@ -423,6 +439,8 @@ public:
 	*/
 	bool is_waiting() { return (state>=WAITING_FOR_CLEARANCE  &&  state<=CAN_START_TWO_MONTHS)  &&  state!=SELF_DESTRUCT; }
 
+	bool is_unloading() { return state==LOADING  &&  unloading_state; }
+
 	/**
 	* reset state to no error message
 	*/
@@ -585,26 +603,26 @@ public:
 	/**
 	* @return Vehicle count
 	*/
-	uint8 get_vehicle_count() const { return anz_vehikel; }
+	uint8 get_vehicle_count() const { return vehicle_count; }
 
 	/**
 	 * @return Vehicle at position i
 	 */
-	vehicle_t* get_vehikel(uint16 i) const { return fahr[i]; }
+	vehicle_t* get_vehicle(uint16 i) const { return fahr[i]; }
 
 	vehicle_t* front() const { return fahr[0]; }
 
-	vehicle_t* back() const { return fahr[anz_vehikel - 1]; }
+	vehicle_t* back() const { return fahr[vehicle_count - 1]; }
 
 	/**
 	* Adds a vehicle at the start or end of the convoi.
 	*/
-	bool add_vehikel(vehicle_t *v, bool infront = false);
+	bool add_vehicle(vehicle_t *v, bool infront = false);
 
 	/**
 	* Removes vehicles at position i
 	*/
-	vehicle_t * remove_vehikel_bei(unsigned short i);
+	vehicle_t * remove_vehicle_at(unsigned short i);
 
 	const minivec_tpl<uint8> &get_goods_catg_index() const { return goods_catg_index; }
 
@@ -638,15 +656,14 @@ public:
 	void open_info_window();
 
 	/**
-	* @return a description string for the object, der z.B. in einem
+	* @param[out] buf a description string for the object, der z.B. in einem
 	* Beobachtungsfenster angezeigt wird.
 	* @see simwin
 	*/
 	void info(cbuffer_t & buf) const;
 
 	/**
-	* @param buf the buffer to fill
-	* @return Freight description text (buf)
+	* @param[out] buf Filled with freight description
 	*/
 	void get_freight_info(cbuffer_t & buf);
 	void set_sortby(uint8 order);
@@ -757,19 +774,19 @@ public:
 	 * convois will slow down before it, if this is not a waypoint or the cannot pass
 	 * The slowdown is done by the vehicle routines
 	 */
-	uint16 get_next_stop_index() const {return next_stop_index;}
-	void set_next_stop_index(uint16 n);
+	route_t::index_t get_next_stop_index() const { return next_stop_index; }
+	void set_next_stop_index(route_t::index_t n);
 
 	/* including this route_index, the route was reserved the last time
 	 * currently only used for tracks
 	 */
-	uint16 get_next_reservation_index() const {return next_reservation_index;}
-	void set_next_reservation_index(uint16 n);
+	route_t::index_t get_next_reservation_index() { return next_reservation_index; }
+	void set_next_reservation_index(route_t::index_t n);
 
 	/* the current state of the convoi */
 	PIXVAL get_status_color() const;
 
-	// returns tiles needed for this convoi
+	// returns station tiles needed for this convoi
 	uint16 get_tile_length() const;
 
 	bool has_obsolete_vehicles() const { return has_obsolete; }
