@@ -4,7 +4,7 @@
  */
 
 #include "simdebug.h"
-#include "simobj.h"
+#include "obj/simobj.h"
 #include "simfab.h"
 #include "display/simgraph.h"
 #include "simmenu.h"
@@ -265,7 +265,7 @@ void planquadrat_t::rdwr(loadsave_t *file, koord pos )
 				case grund_t::brueckenboden: gr = new brueckenboden_t(file, pos); break;
 				case grund_t::monorailboden: gr = new monorailboden_t(file, pos); break;
 				default:
-					gr = 0; // keep compiler happy, fatal() never returns
+					gr = NULL; // keep compiler happy, fatal() never returns
 					dbg->fatal("planquadrat_t::rdwr()","Error while loading game: Unknown ground type '%d'",gtyp);
 			}
 
@@ -274,18 +274,22 @@ void planquadrat_t::rdwr(loadsave_t *file, koord pos )
 				koord3d pos = gr->get_pos();
 				// show normal ground here
 				grund_t *neu = new boden_t(pos, 0);
+
 				if(gr->get_flag(grund_t::has_text)) {
 					neu->set_flag(grund_t::has_text);
 					gr->clear_flag(grund_t::has_text);
 				}
+
 				// transfer all objects
 				while(  gr->get_top()>0  ) {
 					neu->obj_add( gr->obj_remove_top() );
 				}
+
 				delete gr;
 				gr = neu;
 //DBG_MESSAGE("planquadrat_t::rwdr", "unknown building (or prepare for factory) at %d,%d replaced by normal ground!", pos.x,pos.y);
 			}
+
 			// we should also check for ground below factories
 			if(gr) {
 				if(ground_size==0) {
@@ -300,7 +304,12 @@ void planquadrat_t::rdwr(loadsave_t *file, koord pos )
 					welt->set_grid_hgt( pos, hgt );
 				}
 			}
-		} while(gr != 0);
+		} while(gr != NULL);
+
+		// we must always have a kartenboden!
+		if (get_kartenboden() == NULL) {
+			dbg->fatal("planquadrat_t::rdwr", "No kartenboden found for tile at (%s)", pos.get_str());
+		}
 	}
 }
 
@@ -356,10 +365,10 @@ void planquadrat_t::abgesenkt()
 {
 	grund_t *gr = get_kartenboden();
 	if(gr) {
-		const uint8 slope = gr->get_grund_hang();
+		const slope_t::type slope = gr->get_grund_hang();
 
 		gr->obj_loesche_alle(NULL);
-		sint8 max_hgt = gr->get_hoehe() + (slope ? 1 : 0);		// only matters that not flat
+		sint8 max_hgt = gr->get_hoehe() + (slope!=slope_t::flat ? 1 : 0);		// only matters that not flat
 
 		koord k(gr->get_pos().get_2d());
 		if(  max_hgt <= welt->get_water_hgt( k )  &&  gr->get_typ() != grund_t::wasser  ) {
@@ -367,7 +376,7 @@ void planquadrat_t::abgesenkt()
 			kartenboden_setzen( gr );
 			// recalc water ribis of neighbors
 			for(int r=0; r<4; r++) {
-				grund_t *gr2 = welt->lookup_kartenboden(k + koord::nsew[r]);
+				grund_t *gr2 = welt->lookup_kartenboden(k + koord::nesw[r]);
 				if (gr2  &&  gr2->is_water()) {
 					gr2->calc_image();
 				}
@@ -396,7 +405,7 @@ void planquadrat_t::angehoben()
 			kartenboden_setzen( gr );
 			// recalc water ribis
 			for(int r=0; r<4; r++) {
-				grund_t *gr2 = welt->lookup_kartenboden(k + koord::nsew[r]);
+				grund_t *gr2 = welt->lookup_kartenboden(k + koord::nesw[r]);
 				if(  gr2  &&  gr2->is_water()  ) {
 					gr2->calc_image();
 				}
@@ -408,7 +417,7 @@ void planquadrat_t::angehoben()
 			kartenboden_setzen( gr );
 			// recalc water ribis
 			for(int r=0; r<4; r++) {
-				grund_t *gr2 = welt->lookup_kartenboden(k + koord::nsew[r]);
+				grund_t *gr2 = welt->lookup_kartenboden(k + koord::nesw[r]);
 				if(  gr2  &&  gr2->is_water()  ) {
 					gr2->calc_image();
 				}
@@ -435,8 +444,7 @@ void planquadrat_t::display_obj(const sint16 xpos, const sint16 ypos, const sint
 		for(  ;  i < ground_size;  i++  ) {
 			const grund_t* gr = data.some[i];
 			const sint8 h = gr->get_hoehe();
-			const slope_t::type slope = gr->get_grund_hang();
-			const sint8 htop = h + max(max(corner_sw(slope), corner_se(slope)),max(corner_ne(slope), corner_nw(slope)));
+			const sint8 htop = h + slope_t::max_diff( gr->get_grund_hang() );
 			// above ground
 			if(  h > h0  ) {
 				break;
@@ -468,7 +476,6 @@ void planquadrat_t::display_obj(const sint16 xpos, const sint16 ypos, const sint
 			for(  uint8 j = i;  j < ground_size;  j++  ) {
 				const sint8 h = data.some[j]->get_hoehe();
 				const sint8 htop = h + slope_t::max_diff(data.some[j]->get_grund_hang());
-
 				// still underground
 				if(  h < h0  ) {
 					continue;
@@ -480,7 +487,7 @@ void planquadrat_t::display_obj(const sint16 xpos, const sint16 ypos, const sint
 				// not too low?
 				if(  htop >= hmin  ) {
 					// something on top: clip horizontally to prevent trees etc shining trough bridges
-					const sint16 yh = ypos - tile_raster_scale_y( (h - h0) * TILE_HEIGHT_STEP, raster_tile_width ) + ((3 * raster_tile_width) >> 2);
+					const sint16 yh = ypos - tile_raster_scale_y( (h + corner_nw(data.some[j]->get_grund_hang()) - h0) * TILE_HEIGHT_STEP, raster_tile_width ) + ((3 * raster_tile_width) >> 2);
 					if(  yh >= p_cr.y  ) {
 						display_push_clip_wh(p_cr.x, yh, p_cr.w, p_cr.h + p_cr.y - yh  CLIP_NUM_PAR  );
 					}
@@ -495,15 +502,21 @@ void planquadrat_t::display_obj(const sint16 xpos, const sint16 ypos, const sint
 		}
 	}
 	// above ground drawing height
-	for(  ;  i < ground_size;  i++  ) {
+	for( ; i < ground_size; i++ ) {
 		const grund_t* gr = data.some[i];
 		const sint8 h = gr->get_hoehe();
-		const slope_t::type slope = gr->get_grund_hang();
-		const sint8 htop = h + max(max(corner_sw(slope), corner_se(slope)),max(corner_ne(slope), corner_nw(slope)));
+		const sint8 htop = h + slope_t::max_diff( gr->get_grund_hang() );
 
 		// still underground
-		if(  h < h0  ) {
-			continue;
+		if( h < h0 ) {
+			if(  grund_t::underground_mode != grund_t::ugm_level  ) {
+				continue;
+			}
+			// in level underground mode we show also the underground slope tiles one level down
+			if(  htop < h0   ||  data.some[0]->get_hoehe() == h0 ) {
+				// but only if there is not just ground above and they would sine through
+				continue;
+			}
 		}
 		// too high?
 		if(  h > hmax  ) {
