@@ -49,7 +49,7 @@
 #include "../utils/cbuffer_t.h"
 #include "../utils/simstring.h"
 
-#include "../vehicle/simvehicle.h"
+#include "../vehicle/air_vehicle.h"
 
 #include "simplay.h"
 #include "finance.h"
@@ -62,19 +62,19 @@ static pthread_mutex_t load_mutex = PTHREAD_MUTEX_INITIALIZER;
 #endif
 
 player_t::player_t(uint8 nr) :
-	simlinemgmt()
+	finance(new finance_t(this, welt)),
+	player_age(0),
+	player_color_1(0),
+	player_color_2(0),
+	player_nr(nr),
+	active(false),
+	locked(false),
+	unlock_pending(false),
+	simlinemgmt(),
+	undo_type(invalid_wt),
+	headquarter_level(0),
+	headquarter_pos(koord::invalid)
 {
-	finance = new finance_t(this, welt);
-	player_nr = nr;
-	player_age = 0;
-	active = false; // Don't start as an AI player
-	locked = false; // allowed to change anything
-	unlock_pending = false;
-
-	headquarter_pos = koord::invalid;
-	headquarter_level = 0;
-
-
 	welt->get_settings().set_player_color_to_default(this);
 
 	// we have different AI, try to find out our type:
@@ -106,13 +106,12 @@ void player_t::book_construction_costs(player_t * const player, const sint64 amo
 
 sint64 player_t::add_maintenance(sint64 change, waytype_t const wt)
 {
-	int tmp = 0;
 #ifdef MULTI_THREAD
-		pthread_mutex_lock( &load_mutex  );
+	pthread_mutex_lock( &load_mutex );
 #endif
-	tmp = finance->book_maintenance(change, wt);
+	const sint64 tmp = finance->book_maintenance(change, wt);
 #ifdef MULTI_THREAD
-		pthread_mutex_unlock( &load_mutex  );
+	pthread_mutex_unlock( &load_mutex );
 #endif
 	return tmp;
 }
@@ -221,7 +220,7 @@ void player_t::display_messages()
 
 	FOR(slist_tpl<income_message_t*>, const m, messages) {
 
-		const scr_coord scr_pos = vp->get_screen_coord(koord3d(m->pos,welt->lookup_hgt(m->pos)),koord(0,m->alter >> 4));
+		const scr_coord scr_pos = vp->get_screen_coord(koord3d(m->pos,welt->lookup_hgt(m->pos)),koord(0,m->alter >> 4)) + scr_coord((get_tile_raster_width()-display_calc_proportional_string_len_width(m->str, 0x7FFF))/2,0);
 
 		display_shadow_proportional_rgb( scr_pos.x, scr_pos.y, PLAYER_FLAG|color_idx_to_rgb(player_color_1+3), color_idx_to_rgb(COL_BLACK), m->str, true);
 		if(  m->pos.x < 3  ||  m->pos.y < 3  ) {
@@ -409,9 +408,9 @@ void player_t::calc_assets()
 		}
 	}
 
-	// all vehikels stored in depot not part of a convoi
+	// all vehicles stored in depot not part of a convoi
 	FOR(slist_tpl<depot_t*>, const depot, depot_t::get_depot_list()) {
-		if(  depot->get_player_nr() == player_nr  ) {
+		if(  depot->get_owner_nr() == player_nr  ) {
 			FOR(slist_tpl<vehicle_t*>, const veh, depot->get_vehicle_list()) {
 				sint64 restwert = veh->calc_sale_value();
 				assets[TT_ALL] += restwert;
@@ -578,6 +577,7 @@ void player_t::ai_bankrupt()
 								break;
 							case obj_t::gebaeude:
 								hausbauer_t::remove( this, (gebaeude_t *)obj );
+								gr = plan->get_boden_bei(b); // fundament has now been replaced by normal ground
 								break;
 							case obj_t::way:
 							{
@@ -959,5 +959,5 @@ bool player_t::can_afford(sint64 cost) const
 
 bool player_t::is_public_service() const
 {
-	return get_player_nr() == 1;
+	return get_player_nr() == PUBLIC_PLAYER_NR;
 }
