@@ -7,7 +7,7 @@
 #define PLAYER_SIMPLAY_H
 
 
-#include "../network/pwd_hash.h"
+#include "../utils/sha1_hash.h"
 #include "../simtypes.h"
 #include "../simlinemgmt.h"
 
@@ -27,13 +27,25 @@ class tool_t;
 class finance_t;
 
 
+#define HUMAN_PLAYER_NR  (0)
+#define PUBLIC_PLAYER_NR (1)
+
+
 /**
- * Class to hold informations about one player/company. AI players are derived from this class.
+ * Class to hold information about one player/company. AI players are derived from this class.
  */
 class player_t
 {
 public:
-	enum { EMPTY=0, HUMAN=1, AI_GOODS=2, AI_PASSENGER=3, AI_SCRIPTED=4, MAX_AI, PASSWORD_PROTECTED=128 };
+	enum {
+		EMPTY        = 0,
+		HUMAN        = 1,
+		AI_GOODS     = 2,
+		AI_PASSENGER = 3,
+		AI_SCRIPTED  = 4,
+		MAX_AI,
+		PASSWORD_PROTECTED = 128
+	};
 
 protected:
 	char player_name_buf[256];
@@ -65,7 +77,7 @@ protected:
 		void operator delete(void *p);
 	};
 
-	slist_tpl<income_message_t *>messages;
+	slist_tpl<income_message_t *> messages;
 
 	/**
 	 * Creates new income message entry or merges with existing one if the
@@ -246,7 +258,7 @@ public:
 
 	virtual ~player_t();
 
-	static sint32 add_maintenance(player_t *player, sint32 const change, waytype_t const wt=ignore_wt)
+	static inline sint64 add_maintenance(player_t *player, sint64 const change, waytype_t const wt=ignore_wt)
 	{
 		if(player) {
 			return player->add_maintenance(change, wt);
