@@ -14,6 +14,8 @@
 #include "../simconvoi.h"
 
 #include "simroadtraffic.h"
+#include "vehicle.h"
+
 #ifdef DESTINATION_CITYCARS
 // for final citycar destinations
 #include "simpeople.h"
@@ -32,9 +34,11 @@
 #include "../descriptor/citycar_desc.h"
 #include "../descriptor/roadsign_desc.h"
 
-
 #include "../utils/cbuffer_t.h"
 
+#include "road_vehicle.h"
+
+
 /**********************************************************************************************************************/
 /* Road users (private cars and pedestrians) basis class from here on */
 
@@ -67,11 +71,11 @@ road_user_t::road_user_t(grund_t* bd, uint16 random) :
 
 	// randomized offset
 	uint8 offset = random & 3;
-	direction = ribi_t::nsew[offset];
+	direction = ribi_t::nesw[offset];
 
 	grund_t *to = NULL;
 	for(uint8 r = 0; r < 4; r++) {
-		ribi_t::ribi ribi = ribi_t::nsew[ (r + offset) &3];
+		ribi_t::ribi ribi = ribi_t::nesw[ (r + offset) &3];
 		if( (ribi & road_ribi)!=0  &&  bd->get_neighbour(to, road_wt, ribi)) {
 			direction = ribi;
 			break;
@@ -461,7 +465,7 @@ void private_car_t::rdwr(loadsave_t *file)
 }
 
 
-bool private_car_t::ist_weg_frei(grund_t *gr)
+bool private_car_t::can_enter_tile(grund_t *gr)
 {
 	if(gr->get_top()>200) {
 		// already too many things here
@@ -531,7 +535,7 @@ bool private_car_t::ist_weg_frei(grund_t *gr)
 								// otherwise the overtaken car would stop for us ...
 								if(  road_vehicle_t const* const car = obj_cast<road_vehicle_t>(dt)  ) {
 									convoi_t* const ocnv = car->get_convoi();
-									if(  ocnv==NULL  ||  !can_overtake( ocnv, (ocnv->get_state()==convoi_t::LOADING ? 0 : over->get_max_power_speed()), ocnv->get_length_in_steps()+ocnv->get_vehikel(0)->get_steps())  ) {
+									if(  ocnv==NULL  ||  !can_overtake( ocnv, (ocnv->get_state()==convoi_t::LOADING ? 0 : over->get_max_power_speed()), ocnv->get_length_in_steps()+ocnv->get_vehicle(0)->get_steps())  ) {
 										frei = false;
 									}
 								} else if(  private_car_t* const caut = obj_cast<private_car_t>(dt)  ) {
@@ -681,7 +685,7 @@ grund_t* private_car_t::hop_check()
 		// cul de sac: return
 		if(ribi==0) {
 			pos_next_next = get_pos();
-			return ist_weg_frei(from) ? from : NULL;
+			return can_enter_tile(from) ? from : NULL;
 		}
 
 #ifdef DESTINATION_CITYCARS
@@ -689,7 +693,7 @@ grund_t* private_car_t::hop_check()
 		posliste.clear();
 		const uint8 offset = ribi_t::is_single(ribi) ? 0 : simrand(4);
 		for(uint8 r = 0; r < 4; r++) {
-			if(  get_pos().get_2d()==koord::nsew[r]+pos_next.get_2d()  ) {
+			if(  get_pos().get_2d()==koord::nesw[r]+pos_next.get_2d()  ) {
 				continue;
 			}
 #else
@@ -697,13 +701,13 @@ grund_t* private_car_t::hop_check()
 		for(uint8 i = 0; i < 4; i++) {
 			const uint8 r = (i+offset)&3;
 #endif
-			if(  (ribi&ribi_t::nsew[r])!=0  ) {
+			if(  (ribi&ribi_t::nesw[r])!=0  ) {
 				grund_t *to;
-				if(  from->get_neighbour(to, road_wt, ribi_t::nsew[r])  ) {
+				if(  from->get_neighbour(to, road_wt, ribi_t::nesw[r])  ) {
 					// check, if this is just a single tile deep after a crossing
 					weg_t *w = to->get_weg(road_wt);
-					if(  ribi_t::is_single(w->get_ribi())  &&  (w->get_ribi()&ribi_t::nsew[r])==0  &&  !ribi_t::is_single(ribi)  ) {
-						ribi &= ~ribi_t::nsew[r];
+					if(  ribi_t::is_single(w->get_ribi())  &&  (w->get_ribi()&ribi_t::nesw[r])==0  &&  !ribi_t::is_single(ribi)  ) {
+						ribi &= ~ribi_t::nesw[r];
 						continue;
 					}
 					// check, if roadsign forbid next step ...
@@ -712,7 +716,7 @@ grund_t* private_car_t::hop_check()
 						const roadsign_desc_t* rs_desc = rs->get_desc();
 						if(rs_desc->get_min_speed()>desc->get_topspeed()  ||  (rs_desc->is_private_way()  &&  (rs->get_player_mask()&2)==0)  ) {
 							// not allowed to go here
-							ribi &= ~ribi_t::nsew[r];
+							ribi &= ~ribi_t::nesw[r];
 							continue;
 						}
 					}
@@ -722,7 +726,7 @@ grund_t* private_car_t::hop_check()
 #else
 					// ok, now check if we are allowed to go here (i.e. no cars blocking)
 					pos_next_next = to->get_pos();
-					if(ist_weg_frei(from)) {
+					if(can_enter_tile(from)) {
 						// ok, this direction is fine!
 						ms_traffic_jam = 0;
 						if(current_speed<48) {
@@ -737,7 +741,7 @@ grund_t* private_car_t::hop_check()
 				}
 				else {
 					// not connected?!? => ribi likely wrong
-					ribi &= ~ribi_t::nsew[r];
+					ribi &= ~ribi_t::nesw[r];
 				}
 			}
 		}
@@ -748,7 +752,7 @@ grund_t* private_car_t::hop_check()
 		else {
 			pos_next_next = get_pos();
 		}
-		if(ist_weg_frei(from)) {
+		if(can_enter_tile(from)) {
 			// ok, this direction is fine!
 			ms_traffic_jam = 0;
 			if(current_speed<48) {
@@ -760,12 +764,12 @@ grund_t* private_car_t::hop_check()
 		// only stumps at single way crossing, all other blocked => turn around
 		if(ribi==0) {
 			pos_next_next = get_pos();
-			return ist_weg_frei(from) ? from : NULL;
+			return can_enter_tile(from) ? from : NULL;
 		}
 #endif
 	}
 	else {
-		if(from  &&  ist_weg_frei(from)) {
+		if(from  &&  can_enter_tile(from)) {
 			// ok, this direction is fine!
 			ms_traffic_jam = 0;
 			if(current_speed<48) {
@@ -1027,10 +1031,10 @@ bool private_car_t::can_overtake( overtaker_t *other_overtaker, sint32 other_spe
 			ribi_t::ribi rib = str->get_ribi();
 			bool found_one = false;
 			for(  int r=0;  r<4;  r++  ) {
-				if(  (rib&ribi_t::nsew[r])==0  ||  check_pos.get_2d()+koord::nsew[r]==pos_prev) {
+				if(  (rib&ribi_t::nesw[r])==0  ||  check_pos.get_2d()+koord::nesw[r]==pos_prev) {
 					continue;
 				}
-				if(gr->get_neighbour(to, road_wt, ribi_t::nsew[r])) {
+				if(gr->get_neighbour(to, road_wt, ribi_t::nesw[r])) {
 					if(found_one) {
 						// two directions to go: unexpected cars may occurs => abort
 						return false;
@@ -1095,10 +1099,10 @@ bool private_car_t::can_overtake( overtaker_t *other_overtaker, sint32 other_spe
 			// check for crossings/bridges, if necessary
 			bool found_one = false;
 			for(  int r=0;  r<4;  r++  ) {
-				if(check_pos.get_2d()+koord::nsew[r]==pos_prev) {
+				if(check_pos.get_2d()+koord::nesw[r]==pos_prev) {
 					continue;
 				}
-				if(gr->get_neighbour(to, road_wt, ribi_t::nsew[r])) {
+				if(gr->get_neighbour(to, road_wt, ribi_t::nesw[r])) {
 					if(found_one) {
 						return false;
 					}
