@@ -7,7 +7,7 @@
 #define VEHICLE_SIMROADTRAFFIC_H
 
 
-#include "simvehicle.h"
+#include "vehicle_base.h"
 #include "overtaker.h"
 
 #include "../tpl/stringhashtable_tpl.h"
@@ -19,7 +19,7 @@ class karte_t;
 /**
  * Base class for traffic participants with random movement
  *
- * Transport vehicles are defined in simvehicle.h, because they greatly
+ * Transport vehicles are defined in vehicle.h, because they greatly
  * differ from the vehicles defined herein for the individual traffic
  * (pedestrians, citycars, movingobj aka flock of sheep).
  */
@@ -92,6 +92,7 @@ private:
 
 	void calc_disp_lane();
 
+	bool can_enter_tile(grund_t *gr);
 protected:
 	void rdwr(loadsave_t *file) OVERRIDE;
 
@@ -116,7 +117,6 @@ public:
 	sync_result sync_step(uint32 delta_t) OVERRIDE;
 
 	void hop(grund_t *gr) OVERRIDE;
-	bool ist_weg_frei(grund_t *gr);
 
 	void enter_tile(grund_t* gr) OVERRIDE;
 
@@ -127,7 +127,7 @@ public:
 	typ get_typ() const OVERRIDE { return road_user; }
 
 	/**
-	 * @return a description string for the object
+	 * @param[out] buf a description string for the object
 	 * e.g. for the observation window/dialog
 	 * @see simwin
 	 */
