@@ -8,6 +8,7 @@
 #include <algorithm>
 
 #include "dataobj/koord.h"
+#include "dataobj/environment.h"
 #include "simdebug.h"
 #include "simticker.h"
 #include "display/simgraph.h"
@@ -22,8 +23,6 @@
 
 uint16 win_get_statusbar_height(); // simwin.h
 
-uint16 TICKER_YPOS_BOTTOM;
-
 struct node {
 	char msg[256];
 	koord pos;
@@ -34,10 +33,10 @@ struct node {
 
 
 static slist_tpl<node> list;
-static koord default_pos = koord::invalid; // world position of newest message
-static bool redraw_all = false;    //< true, if also trigger background need redraw
-static int next_pos;               //< Next x offset of new message. Always greater or equal to display_width
-static int dx_since_last_draw = 0; //< Increased during update(); positive values move messages to the left
+static koord default_pos = koord::invalid; ///< world position of newest message
+static bool redraw_all = false;            ///< true, if also trigger background need redraw
+static int next_pos;                       ///< Next x offset of new message. Always greater or equal to display_width
+static int dx_since_last_draw = 0;         ///< Increased during update(); positive values move messages to the left
 
 
 bool ticker::empty()
@@ -142,33 +141,33 @@ void ticker::update()
 
 void ticker::draw()
 {
+	const int start_y = env_t::menupos == MENU_BOTTOM ? win_get_statusbar_height() : display_get_height() - TICKER_HEIGHT - win_get_statusbar_height();
 	if (redraw_all) {
 		redraw();
 		return;
 	}
 	else if (list.empty()) {
 		// ticker not visible
+
+		// mark everything at the bottom as dirty to clear also tooltips and compass
+		mark_rect_dirty_wc(0, env_t::menupos == MENU_BOTTOM ? 0 : start_y - 128, display_get_width(), start_y + 128 + TICKER_HEIGHT);
 		return;
 	}
 
-	TICKER_YPOS_BOTTOM = TICKER_HEIGHT + win_get_statusbar_height();
-
-	const int start_y=display_get_height()-TICKER_YPOS_BOTTOM;
 	const int width = display_get_width();
-
 	if (width <= 0) {
 		return;
 	}
 
 	// do partial redraw
-	display_scroll_band( start_y+1, dx_since_last_draw, TICKER_HEIGHT-1 );
-	display_fillbox_wh_rgb(width-dx_since_last_draw-6, start_y+1, dx_since_last_draw+6, TICKER_HEIGHT-1, SYSCOL_TICKER_BACKGROUND, true);
+	display_scroll_band( start_y, dx_since_last_draw, TICKER_HEIGHT );
+	display_fillbox_wh_rgb(width-dx_since_last_draw-6, start_y, dx_since_last_draw+6, TICKER_HEIGHT, SYSCOL_TICKER_BACKGROUND, true);
 
 	// ok, ready for the text
-	PUSH_CLIP( 0, start_y + 1, width - 1, TICKER_HEIGHT-1 );
+	PUSH_CLIP( 0, start_y, width - 1, TICKER_HEIGHT );
 	FOR(slist_tpl<node>, & n, list) {
 		if (n.xpos < width) {
-			display_proportional_clip_rgb(n.xpos, start_y + 2, n.msg, ALIGN_LEFT, n.color, true);
+			display_proportional_clip_rgb(n.xpos, start_y + TICKER_V_SPACE, n.msg, ALIGN_LEFT, n.color, true);
 		}
 	}
 	POP_CLIP();
@@ -181,25 +180,21 @@ void ticker::redraw()
 {
 	set_redraw_all(false);
 	dx_since_last_draw = 0;
+	const int start_y = env_t::menupos == MENU_BOTTOM ? win_get_statusbar_height() : display_get_height() - TICKER_HEIGHT - win_get_statusbar_height();
 
 	if (list.empty()) {
-		const int start_y=display_get_height()-TICKER_YPOS_BOTTOM;
-
 		// mark everything at the bottom as dirty to clear also tooltips and compass
-		mark_rect_dirty_wc(0, start_y-128, display_get_width(), start_y + 128 +TICKER_HEIGHT);
+		mark_rect_dirty_wc(0, env_t::menupos == MENU_BOTTOM ? 0 : start_y - 128, display_get_width(), start_y + 128 + TICKER_HEIGHT);
 		return;
 	}
 
-	TICKER_YPOS_BOTTOM = TICKER_HEIGHT + win_get_statusbar_height();
-
-	const int start_y=display_get_height()-TICKER_YPOS_BOTTOM;
 	const int width = display_get_width();
 
 	// just draw the ticker in its colour ... (to be sure ... )
-	display_fillbox_wh_rgb(0, start_y+1, width, TICKER_HEIGHT-1, SYSCOL_TICKER_BACKGROUND, true);
+	display_fillbox_wh_rgb(0, start_y, width, TICKER_HEIGHT, SYSCOL_TICKER_BACKGROUND, true);
 	FOR(slist_tpl<node>, & n, list) {
 		if (n.xpos < width) {
-			display_proportional_clip_rgb(n.xpos, start_y + 2, n.msg, ALIGN_LEFT, n.color, true);
+			display_proportional_clip_rgb(n.xpos, start_y + TICKER_V_SPACE, n.msg, ALIGN_LEFT, n.color, true);
 		}
 	}
 }
