@@ -1,28 +1,24 @@
 /*
- *  Copyright (c) 1997 - 2002 by Volker Meyer & Hansjrg Malthaner
- *
- * This file is part of the Simutrans project under the artistic licence.
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
  */
 
-#ifndef __SKIN_DESC_H
-#define __SKIN_DESC_H
+#ifndef DESCRIPTOR_SKIN_DESC_H
+#define DESCRIPTOR_SKIN_DESC_H
+
 
 #include "../display/simimg.h"
 #include "obj_base_desc.h"
 #include "image_array.h"
 
 
-/*
- *  Author:
- *      Volker Meyer
+/**
+ * An image list, with name and author attributes. Mostly used for gui purposes.
  *
- *  Description:
- *      An image list, with name and author attributes. Mostly used for gui purposes.
- *
- *  Child nodes:
- *	0   Name
- *	1   Copyright
- *	2   Image list
+ * Child nodes:
+ *  0   Name
+ *  1   Copyright
+ *  2   Image list
  */
 class skin_desc_t : public obj_named_desc_t {
 public:
