@@ -30,6 +30,9 @@ private:
 	button_t next_song_button;
 	button_t previous_song_button;
 	button_t shuffle_song_button;
+#ifdef USE_FLUIDSYNTH_MIDI
+	button_t soundfont_button;
+#endif
 	gui_label_buf_t song_name_label;
 
 	void update_song_name();
