@@ -156,7 +156,14 @@ static SQInteger base_getstackinfos(HSQUIRRELVM v)
 static SQInteger base_assert(HSQUIRRELVM v)
 {
 	if(SQVM::IsFalse(stack_get(v,2))){
-		return sq_throwerror(v,_SC("assertion failed"));
+		SQInteger top = sq_gettop(v);
+		if (top>2 && SQ_SUCCEEDED(sq_tostring(v,3))) {
+			const SQChar *str = 0;
+			if (SQ_SUCCEEDED(sq_getstring(v,-1,&str))) {
+				return sq_throwerror(v, str);
+			}
+		}
+		return sq_throwerror(v, _SC("assertion failed"));
 	}
 	return 0;
 }
@@ -169,7 +176,7 @@ static SQInteger get_slice_params(HSQUIRRELVM v,SQInteger &sidx,SQInteger &eidx,
 	o=stack_get(v,1);
 	if(top>1){
 		SQObjectPtr &start=stack_get(v,2);
-		if(sqtype(start)!=OT_NULL && sq_isnumeric(start)){
+		if(sq_type(start)!=OT_NULL && sq_isnumeric(start)){
 			sidx=tointeger(start);
 		}
 	}
@@ -283,7 +290,7 @@ static const SQRegFunction base_funcs[]={
 	{_SC("setroottable"),base_setroottable,2, NULL},
 	{_SC("getconsttable"),base_getconsttable,1, NULL},
 	{_SC("setconsttable"),base_setconsttable,2, NULL},
-	{_SC("assert"),base_assert,2, NULL},
+	{_SC("assert"),base_assert,-2, NULL},
 	{_SC("print"),base_print,2, NULL},
 	{_SC("error"),base_error,2, NULL},
 	{_SC("compilestring"),base_compilestring,-2, _SC(".ss")},
@@ -340,7 +347,7 @@ static SQInteger default_delegate_len(HSQUIRRELVM v)
 static SQInteger default_delegate_tofloat(HSQUIRRELVM v)
 {
 	SQObjectPtr &o=stack_get(v,1);
-	switch(sqtype(o)){
+	switch(sq_type(o)){
 	case OT_STRING:{
 		SQObjectPtr res;
 		if(str2num(_stringval(o),res,10)){
@@ -369,7 +376,7 @@ static SQInteger default_delegate_tointeger(HSQUIRRELVM v)
 	if(sq_gettop(v) > 1) {
 		sq_getinteger(v,2,&base);
 	}
-	switch(sqtype(o)){
+	switch(sq_type(o)){
 	case OT_STRING:{
 		SQObjectPtr res;
 		if(str2num(_stringval(o),res,base)){
@@ -406,7 +413,7 @@ static SQInteger obj_delegate_weakref(HSQUIRRELVM v)
 
 static SQInteger obj_clear(HSQUIRRELVM v)
 {
-	return sq_clear(v,-1);
+	return SQ_SUCCEEDED(sq_clear(v,-1)) ? 1 : SQ_ERROR;
 }
 
 
@@ -443,7 +450,7 @@ static SQInteger container_rawexists(HSQUIRRELVM v)
 
 static SQInteger container_rawset(HSQUIRRELVM v)
 {
-	return sq_rawset(v,-3);
+	return SQ_SUCCEEDED(sq_rawset(v,-3)) ? 1 : SQ_ERROR;
 }
 
 
@@ -465,6 +472,58 @@ static SQInteger table_getdelegate(HSQUIRRELVM v)
 	return SQ_SUCCEEDED(sq_getdelegate(v,-1))?1:SQ_ERROR;
 }
 
+static SQInteger table_filter(HSQUIRRELVM v)
+{
+	SQObject &o = stack_get(v,1);
+	SQTable *tbl = _table(o);
+	SQObjectPtr ret = SQTable::Create(_ss(v),0);
+
+	SQObjectPtr itr, key, val;
+	SQInteger nitr;
+	while((nitr = tbl->Next(false, itr, key, val)) != -1) {
+		itr = (SQInteger)nitr;
+
+		v->Push(o);
+		v->Push(key);
+		v->Push(val);
+		if(SQ_FAILED(sq_call(v,3,SQTrue,SQFalse))) {
+			return SQ_ERROR;
+		}
+		if(!SQVM::IsFalse(v->GetUp(-1))) {
+			_table(ret)->NewSlot(key, val);
+		}
+		v->Pop();
+	}
+
+	v->Push(ret);
+	return 1;
+}
+
+#define TABLE_TO_ARRAY_FUNC(_funcname_,_valname_) static SQInteger _funcname_(HSQUIRRELVM v) \
+{ \
+	SQObject &o = stack_get(v, 1); \
+	SQTable *t = _table(o); \
+	SQObjectPtr itr, key, val; \
+	SQObjectPtr _null; \
+	SQInteger nitr, n = 0; \
+	SQInteger nitems = t->CountUsed(); \
+	SQArray *a = SQArray::Create(_ss(v), nitems); \
+	a->Resize(nitems, _null); \
+	if (nitems) { \
+		while ((nitr = t->Next(false, itr, key, val)) != -1) { \
+			itr = (SQInteger)nitr; \
+			a->Set(n, _valname_); \
+			n++; \
+		} \
+	} \
+	v->Push(a); \
+	return 1; \
+}
+
+TABLE_TO_ARRAY_FUNC(table_keys, key)
+TABLE_TO_ARRAY_FUNC(table_values, val)
+
+
 const SQRegFunction SQSharedState::_table_default_delegate_funcz[]={
 	{_SC("len"),default_delegate_len,1, _SC("t")},
 	{_SC("rawget"),container_rawget,2, _SC("t")},
@@ -476,6 +535,9 @@ const SQRegFunction SQSharedState::_table_default_delegate_funcz[]={
 	{_SC("clear"),obj_clear,1, _SC(".")},
 	{_SC("setdelegate"),table_setdelegate,2, _SC(".t|o")},
 	{_SC("getdelegate"),table_getdelegate,1, _SC(".")},
+	{_SC("filter"),table_filter,2, _SC("tc")},
+	{_SC("keys"),table_keys,1, _SC("t") },
+	{_SC("values"),table_values,1, _SC("t") },
 	{NULL,(SQFUNCTION)0,0,NULL}
 };
 
@@ -483,18 +545,19 @@ const SQRegFunction SQSharedState::_table_default_delegate_funcz[]={
 
 static SQInteger array_append(HSQUIRRELVM v)
 {
-	return sq_arrayappend(v,-2);
+	return SQ_SUCCEEDED(sq_arrayappend(v,-2)) ? 1 : SQ_ERROR;
 }
 
 static SQInteger array_extend(HSQUIRRELVM v)
 {
 	_array(stack_get(v,1))->Extend(_array(stack_get(v,2)));
-	return 0;
+	sq_pop(v,1);
+	return 1;
 }
 
 static SQInteger array_reverse(HSQUIRRELVM v)
 {
-	return sq_arrayreverse(v,-1);
+	return SQ_SUCCEEDED(sq_arrayreverse(v,-1)) ? 1 : SQ_ERROR;
 }
 
 static SQInteger array_pop(HSQUIRRELVM v)
@@ -519,7 +582,8 @@ static SQInteger array_insert(HSQUIRRELVM v)
 	SQObject &val=stack_get(v,3);
 	if(!_array(o)->Insert(tointeger(idx),val))
 		return sq_throwerror(v,_SC("index out of range"));
-	return 0;
+	sq_pop(v,2);
+	return 1;
 }
 
 static SQInteger array_remove(HSQUIRRELVM v)
@@ -542,10 +606,15 @@ static SQInteger array_resize(HSQUIRRELVM v)
 	SQObject &nsize = stack_get(v, 2);
 	SQObjectPtr fill;
 	if(sq_isnumeric(nsize)) {
+		SQInteger sz = tointeger(nsize);
+		if (sz<0)
+		  return sq_throwerror(v, _SC("resizing to negative length"));
+
 		if(sq_gettop(v) > 2)
 			fill = stack_get(v, 3);
-		_array(o)->Resize(tointeger(nsize),fill);
-		return 0;
+		_array(o)->Resize(sz,fill);
+		sq_settop(v, 1);
+		return 1;
 	}
 	return sq_throwerror(v, _SC("size must be a number"));
 }
@@ -553,16 +622,36 @@ static SQInteger array_resize(HSQUIRRELVM v)
 static SQInteger __map_array(SQArray *dest,SQArray *src,HSQUIRRELVM v) {
 	SQObjectPtr temp;
 	SQInteger size = src->Size();
+	SQObject &closure = stack_get(v, 2);
+	v->Push(closure);
+
+	SQInteger nArgs = 0;
+	if(sq_type(closure) == OT_CLOSURE) {
+		nArgs = _closure(closure)->_function->_nparameters;
+	}
+	else if (sq_type(closure) == OT_NATIVECLOSURE) {
+		SQInteger nParamsCheck = _nativeclosure(closure)->_nparamscheck;
+		if (nParamsCheck > 0)
+			nArgs = nParamsCheck;
+		else // push all params when there is no check or only minimal count set
+			nArgs = 4;
+	}
+
 	for(SQInteger n = 0; n < size; n++) {
 		src->Get(n,temp);
 		v->Push(src);
 		v->Push(temp);
-		if(SQ_FAILED(sq_call(v,2,SQTrue,SQFalse))) {
+		if (nArgs >= 3)
+			v->Push(SQObjectPtr(n));
+		if (nArgs >= 4)
+			v->Push(src);
+		if(SQ_FAILED(sq_call(v,nArgs,SQTrue,SQFalse))) {
 			return SQ_ERROR;
 		}
 		dest->Set(n,v->GetUp(-1));
 		v->Pop();
 	}
+	v->Pop();
 	return 0;
 }
 
@@ -582,7 +671,8 @@ static SQInteger array_apply(HSQUIRRELVM v)
 	SQObject &o = stack_get(v,1);
 	if(SQ_FAILED(__map_array(_array(o),_array(o),v)))
 		return SQ_ERROR;
-	return 0;
+	sq_pop(v,1);
+	return 1;
 }
 
 static SQInteger array_reduce(HSQUIRRELVM v)
@@ -590,14 +680,21 @@ static SQInteger array_reduce(HSQUIRRELVM v)
 	SQObject &o = stack_get(v,1);
 	SQArray *a = _array(o);
 	SQInteger size = a->Size();
-	if(size == 0) {
-		return 0;
-	}
 	SQObjectPtr res;
+	SQInteger iterStart;
+	if (sq_gettop(v)>2) {
+		res = stack_get(v,3);
+		iterStart = 0;
+	} else if (size==0) {
+		return 0;
+	} else {
 	a->Get(0,res);
-	if(size > 1) {
+		iterStart = 1;
+	}
+	if (size > iterStart) {
 		SQObjectPtr other;
-		for(SQInteger n = 1; n < size; n++) {
+		v->Push(stack_get(v,2));
+		for (SQInteger n = iterStart; n < size; n++) {
 			a->Get(n,other);
 			v->Push(o);
 			v->Push(res);
@@ -608,6 +705,7 @@ static SQInteger array_reduce(HSQUIRRELVM v)
 			res = v->GetUp(-1);
 			v->Pop();
 		}
+		v->Pop();
 	}
 	v->Push(res);
 	return 1;
@@ -656,7 +754,7 @@ static SQInteger array_find(HSQUIRRELVM v)
 }
 
 
-static bool _sort_compare(HSQUIRRELVM v,SQObjectPtr &a,SQObjectPtr &b,SQInteger func,SQInteger &ret)
+static bool _sort_compare(HSQUIRRELVM v, SQArray *arr, SQObjectPtr &a,SQObjectPtr &b,SQInteger func,SQInteger &ret)
 {
 	if(func < 0) {
 		if(!v->ObjCmp(a,b,ret)) return false;
@@ -667,6 +765,8 @@ static bool _sort_compare(HSQUIRRELVM v,SQObjectPtr &a,SQObjectPtr &b,SQInteger
 		sq_pushroottable(v);
 		v->Push(a);
 		v->Push(b);
+		SQObjectPtr *valptr = arr->_values._vals;
+		SQUnsignedInteger precallsize = arr->_values.size();
 		if(SQ_FAILED(sq_call(v, 3, SQTrue, SQFalse))) {
 			if(!sq_isstring( v->_lasterror))
 				v->Raise_Error(_SC("compare func failed"));
@@ -676,6 +776,10 @@ static bool _sort_compare(HSQUIRRELVM v,SQObjectPtr &a,SQObjectPtr &b,SQInteger
 			v->Raise_Error(_SC("numeric value expected as return value of the compare function"));
 			return false;
 		}
+		if (precallsize != arr->_values.size() || valptr != arr->_values._vals) {
+			v->Raise_Error(_SC("array resized during sort operation"));
+			return false;
+		}
 		sq_settop(v, top);
 		return true;
 	}
@@ -694,7 +798,7 @@ static bool _hsort_sift_down(HSQUIRRELVM v,SQArray *arr, SQInteger root, SQInteg
 			maxChild = root2;
 		}
 		else {
-			if(!_sort_compare(v,arr->_values[root2],arr->_values[root2 + 1],func,ret))
+			if(!_sort_compare(v,arr,arr->_values[root2],arr->_values[root2 + 1],func,ret))
 				return false;
 			if (ret > 0) {
 				maxChild = root2;
@@ -704,7 +808,7 @@ static bool _hsort_sift_down(HSQUIRRELVM v,SQArray *arr, SQInteger root, SQInteg
 			}
 		}
 
-		if(!_sort_compare(v,arr->_values[root],arr->_values[maxChild],func,ret))
+		if(!_sort_compare(v,arr,arr->_values[root],arr->_values[maxChild],func,ret))
 			return false;
 		if (ret < 0) {
 			if (root == maxChild) {
@@ -749,7 +853,8 @@ static SQInteger array_sort(HSQUIRRELVM v)
 			return SQ_ERROR;
 
 	}
-	return 0;
+	sq_settop(v,1);
+	return 1;
 }
 
 static SQInteger array_slice(HSQUIRRELVM v)
@@ -792,7 +897,7 @@ const SQRegFunction SQSharedState::_array_default_delegate_funcz[]={
 	{_SC("clear"),obj_clear,1, _SC(".")},
 	{_SC("map"),array_map,2, _SC("ac")},
 	{_SC("apply"),array_apply,2, _SC("ac")},
-	{_SC("reduce"),array_reduce,2, _SC("ac")},
+	{_SC("reduce"),array_reduce,-2, _SC("ac.")},
 	{_SC("filter"),array_filter,2, _SC("ac")},
 	{_SC("find"),array_find,2, _SC("a.")},
 	{NULL,(SQFUNCTION)0,0,NULL}
@@ -852,7 +957,7 @@ static SQInteger string_find(HSQUIRRELVM v)
 
 static char toalnum(char c)
 {
-	return isalnum(c) ? c : '_';
+	return isalnum(c)  &&  c >=0  ? c : '_';
 }
 
 STRING_TOFUNCZ(tolower)
@@ -891,7 +996,14 @@ static SQInteger closure_pcall(HSQUIRRELVM v)
 
 static SQInteger closure_call(HSQUIRRELVM v)
 {
-	return SQ_SUCCEEDED(sq_call(v,sq_gettop(v)-1,SQTrue,SQTrue))?1:SQ_ERROR;
+	/* has to wait until sq_tailcall is enabled
+	SQObjectPtr &c = stack_get(v, -1);
+	if (sq_type(c) == OT_CLOSURE && (_closure(c)->_function->_bgenerator == false))
+	{
+		return sq_tailcall(v, sq_gettop(v) - 1);
+	}
+	*/
+	return SQ_SUCCEEDED(sq_call(v, sq_gettop(v) - 1, SQTrue, SQTrue)) ? 1 : SQ_ERROR;
 }
 
 static SQInteger _closure_acall(HSQUIRRELVM v,SQBool raiseerror)
@@ -937,7 +1049,7 @@ static SQInteger closure_setroot(HSQUIRRELVM v)
 static SQInteger closure_getinfos(HSQUIRRELVM v) {
 	SQObject o = stack_get(v,1);
 	SQTable *res = SQTable::Create(_ss(v),4);
-	if(sqtype(o) == OT_CLOSURE) {
+	if(sq_type(o) == OT_CLOSURE) {
 		SQFunctionProto *f = _closure(o)->_function;
 		SQInteger nparams = f->_nparameters + (f->_varparams?1:0);
 		SQObjectPtr params = SQArray::Create(_ss(v),nparams);
@@ -1016,7 +1128,7 @@ const SQRegFunction SQSharedState::_generator_default_delegate_funcz[]={
 static SQInteger thread_call(HSQUIRRELVM v)
 {
 	SQObjectPtr o = stack_get(v,1);
-	if(sqtype(o) == OT_THREAD) {
+	if(sq_type(o) == OT_THREAD) {
 		SQInteger nparams = sq_gettop(v);
 		_thread(o)->Push(_thread(o)->_roottable);
 		for(SQInteger i = 2; i<(nparams+1); i++)
@@ -1035,7 +1147,7 @@ static SQInteger thread_call(HSQUIRRELVM v)
 static SQInteger thread_wakeup(HSQUIRRELVM v)
 {
 	SQObjectPtr o = stack_get(v,1);
-	if(sqtype(o) == OT_THREAD) {
+	if(sq_type(o) == OT_THREAD) {
 		SQVM *thread = _thread(o);
 		SQInteger state = sq_getvmstate(thread);
 		if(state != SQ_VMSTATE_SUSPENDED) {
@@ -1071,7 +1183,7 @@ static SQInteger thread_wakeup(HSQUIRRELVM v)
 static SQInteger thread_wakeupthrow(HSQUIRRELVM v)
 {
 	SQObjectPtr o = stack_get(v,1);
-	if(sqtype(o) == OT_THREAD) {
+	if(sq_type(o) == OT_THREAD) {
 		SQVM *thread = _thread(o);
 		SQInteger state = sq_getvmstate(thread);
 		if(state != SQ_VMSTATE_SUSPENDED) {
@@ -1131,7 +1243,7 @@ static SQInteger thread_getstatus(HSQUIRRELVM v)
 static SQInteger thread_getstackinfos(HSQUIRRELVM v)
 {
 	SQObjectPtr o = stack_get(v,1);
-	if(sqtype(o) == OT_THREAD) {
+	if(sq_type(o) == OT_THREAD) {
 		SQVM *thread = _thread(o);
 		SQInteger threadtop = sq_gettop(thread);
 		SQInteger level;
@@ -1140,7 +1252,7 @@ static SQInteger thread_getstackinfos(HSQUIRRELVM v)
 		if(SQ_FAILED(res))
 		{
 			sq_settop(thread,threadtop);
-			if(sqtype(thread->_lasterror) == OT_STRING) {
+			if(sq_type(thread->_lasterror) == OT_STRING) {
 				sq_throwerror(v,_stringval(thread->_lasterror));
 			}
 			else {
