@@ -53,7 +53,7 @@ SQClass::~SQClass()
 bool SQClass::NewSlot(SQSharedState *ss,const SQObjectPtr &key,const SQObjectPtr &val,bool bstatic)
 {
 	SQObjectPtr temp;
-	bool belongs_to_static_table = sqtype(val) == OT_CLOSURE || sqtype(val) == OT_NATIVECLOSURE || bstatic;
+	bool belongs_to_static_table = sq_type(val) == OT_CLOSURE || sq_type(val) == OT_NATIVECLOSURE || bstatic;
 	if(_locked && !belongs_to_static_table)
 		return false; //the class already has an instance so cannot be modified
 	if(_members->Get(key,temp) && _isfield(temp)) //overrides the default value
@@ -61,20 +61,23 @@ bool SQClass::NewSlot(SQSharedState *ss,const SQObjectPtr &key,const SQObjectPtr
 		_defaultvalues[_member_idx(temp)].val = val;
 		return true;
 	}
+	if (_members->CountUsed() >= MEMBER_MAX_COUNT) {
+		return false;
+	}
 	if(belongs_to_static_table) {
 		SQInteger mmidx;
-		if((sqtype(val) == OT_CLOSURE || sqtype(val) == OT_NATIVECLOSURE) &&
+		if((sq_type(val) == OT_CLOSURE || sq_type(val) == OT_NATIVECLOSURE) &&
 			(mmidx = ss->GetMetaMethodIdxByName(key)) != -1) {
 			_metamethods[mmidx] = val;
 		}
 		else {
 			SQObjectPtr theval = val;
-			if(_base && sqtype(val) == OT_CLOSURE) {
+			if(_base && sq_type(val) == OT_CLOSURE) {
 				theval = _closure(val)->Clone();
 				_closure(theval)->_base = _base;
 				__ObjAddRef(_base); //ref for the closure
 			}
-			if(sqtype(temp) == OT_NULL) {
+			if(sq_type(temp) == OT_NULL) {
 				bool isconstructor;
 				SQVM::IsEqual(ss->_constructoridx, key, isconstructor);
 				if(isconstructor) {
@@ -191,7 +194,7 @@ SQInstance::~SQInstance()
 
 bool SQInstance::GetMetaMethod(SQVM* SQ_UNUSED_ARG(v),SQMetaMethod mm,SQObjectPtr &res)
 {
-	if(sqtype(_class->_metamethods[mm]) != OT_NULL) {
+	if(sq_type(_class->_metamethods[mm]) != OT_NULL) {
 		res = _class->_metamethods[mm];
 		return true;
 	}
