@@ -12,9 +12,9 @@
 
 #define hashptr(p)  ((SQHash)(((SQInteger)p) >> 3))
 
-inline SQHash HashObj(const SQObjectPtr &key)
+inline SQHash HashObj(const SQObject &key)
 {
-	switch(sqtype(key)) {
+	switch(sq_type(key)) {
 		case OT_STRING:		return _string(key)->_hash;
 		case OT_FLOAT:		return (SQHash)((SQInteger)_float(key));
 		case OT_BOOL: case OT_INTEGER:	return (SQHash)((SQInteger)_integer(key));
@@ -67,7 +67,7 @@ public:
 	{
 		_HashNode *n = &_nodes[hash];
 		do{
-			if(_rawval(n->key) == _rawval(key) && sqtype(n->key) == sqtype(key)){
+			if(_rawval(n->key) == _rawval(key) && sq_type(n->key) == sq_type(key)){
 				return n;
 			}
 		}while((n = n->next));
@@ -80,7 +80,7 @@ public:
 		_HashNode *n = &_nodes[hash & (_numofnodes - 1)];
 		_HashNode *res = NULL;
 		do{
-			if(sqtype(n->key) == OT_STRING && (scstrcmp(_stringval(n->key),key) == 0)){
+			if(sq_type(n->key) == OT_STRING && (scstrcmp(_stringval(n->key),key) == 0)){
 				res = n;
 				break;
 			}
