@@ -4,7 +4,6 @@
 #include "sqpcheader.h"
 #include <math.h>
 #include <stdlib.h>
-#include <limits.h>
 #include "sqopcodes.h"
 #include "sqvm.h"
 #include "sqfuncproto.h"
@@ -16,11 +15,13 @@
 #include "sqclass.h"
 
 #define TOP() (_stack._vals[_top-1])
+#define TARGET _stack._vals[_stackbase+arg0]
+#define STK(a) _stack._vals[_stackbase+(a)]
 
 bool SQVM::BW_OP(SQUnsignedInteger op,SQObjectPtr &trg,const SQObjectPtr &o1,const SQObjectPtr &o2)
 {
 	SQInteger res;
-	if((type(o1)|type(o2)) == OT_INTEGER)
+	if((sq_type(o1)| sq_type(o2)) == OT_INTEGER)
 	{
 		SQInteger i1 = _integer(o1), i2 = _integer(o2);
 		switch(op) {
@@ -40,7 +41,7 @@ bool SQVM::BW_OP(SQUnsignedInteger op,SQObjectPtr &trg,const SQObjectPtr &o1,con
 
 #define _ARITH_(op,trg,o1,o2) \
 { \
-	SQInteger tmask = type(o1)|type(o2); \
+	SQInteger tmask = sq_type(o1)|sq_type(o2); \
 	switch(tmask) { \
 		case OT_INTEGER: trg = _integer(o1) op _integer(o2);break; \
 		case (OT_FLOAT|OT_INTEGER): \
@@ -51,7 +52,7 @@ bool SQVM::BW_OP(SQUnsignedInteger op,SQObjectPtr &trg,const SQObjectPtr &o1,con
 
 #define _ARITH_NOZERO(op,trg,o1,o2,err) \
 { \
-	SQInteger tmask = type(o1)|type(o2); \
+	SQInteger tmask = sq_type(o1)|sq_type(o2); \
 	switch(tmask) { \
 		case OT_INTEGER: { SQInteger i2 = _integer(o2); if(i2 == 0) { Raise_Error(err); SQ_THROW(); } trg = _integer(o1) op i2; } break;\
 		case (OT_FLOAT|OT_INTEGER): \
@@ -62,7 +63,7 @@ bool SQVM::BW_OP(SQUnsignedInteger op,SQObjectPtr &trg,const SQObjectPtr &o1,con
 
 bool SQVM::ARITH_OP(SQUnsignedInteger op,SQObjectPtr &trg,const SQObjectPtr &o1,const SQObjectPtr &o2)
 {
-	SQInteger tmask = type(o1)|type(o2);
+	SQInteger tmask = sq_type(o1)| sq_type(o2);
 	switch(tmask) {
 		case OT_INTEGER:{
 			SQInteger res, i1 = _integer(o1), i2 = _integer(o2);
@@ -180,7 +181,7 @@ bool SQVM::ArithMetaMethod(SQInteger op,const SQObjectPtr &o1,const SQObjectPtr
 bool SQVM::NEG_OP(SQObjectPtr &trg,const SQObjectPtr &o)
 {
 
-	switch(type(o)) {
+	switch(sq_type(o)) {
 	case OT_INTEGER:
 		trg = -_integer(o);
 		return true;
@@ -209,7 +210,7 @@ bool SQVM::NEG_OP(SQObjectPtr &trg,const SQObjectPtr &o)
 #define _RET_SUCCEED(exp) { result = (exp); return true; }
 bool SQVM::ObjCmp(const SQObjectPtr &o1,const SQObjectPtr &o2,SQInteger &result)
 {
-	SQObjectType t1 = type(o1), t2 = type(o2);
+	SQObjectType t1 = sq_type(o1), t2 = sq_type(o2);
 	if(t1 == t2) {
 		if(_rawval(o1) == _rawval(o2))_RET_SUCCEED(0);
 		SQObjectPtr res;
@@ -228,7 +229,7 @@ bool SQVM::ObjCmp(const SQObjectPtr &o1,const SQObjectPtr &o2,SQInteger &result)
 				if(_delegable(o1)->GetMetaMethod(this, MT_CMP, closure)) {
 					Push(o1);Push(o2);
 					if(CallMetaMethod(closure,MT_CMP,2,res)) {
-						if(type(res) != OT_INTEGER) {
+						if(sq_type(res) != OT_INTEGER) {
 							Raise_Error(_SC("_cmp must return an integer"));
 							return false;
 						}
@@ -286,7 +287,7 @@ bool SQVM::CMP_OP(CmpOP op, const SQObjectPtr &o1,const SQObjectPtr &o2,SQObject
 
 bool SQVM::ToString(const SQObjectPtr &o,SQObjectPtr &res)
 {
-	switch(type(o)) {
+	switch(sq_type(o)) {
 	case OT_STRING:
 		res = o;
 		return true;
@@ -299,6 +300,9 @@ bool SQVM::ToString(const SQObjectPtr &o,SQObjectPtr &res)
 	case OT_BOOL:
 		scsprintf(_sp(sq_rsl(6)),sq_rsl(6),_integer(o)?_SC("true"):_SC("false"));
 		break;
+	case OT_NULL:
+		scsprintf(_sp(sq_rsl(5)),sq_rsl(5),_SC("null"));
+		break;
 	case OT_TABLE:
 	case OT_USERDATA:
 	case OT_INSTANCE:
@@ -306,8 +310,8 @@ bool SQVM::ToString(const SQObjectPtr &o,SQObjectPtr &res)
 			SQObjectPtr closure;
 			if(_delegable(o)->GetMetaMethod(this, MT_TOSTRING, closure)) {
 				Push(o);
-				if(CallMetaMethod(closure,MT_TOSTRING,1,res)) {;
-					if(type(res) == OT_STRING)
+				if(CallMetaMethod(closure,MT_TOSTRING,1,res)) {
+					if(sq_type(res) == OT_STRING)
 						return true;
 				}
 				else {
@@ -384,8 +388,8 @@ bool SQVM::StartCall(SQClosure *closure,SQInteger target,SQInteger args,SQIntege
 	{
 		paramssize--;
 		if (nargs < paramssize) {
-			const SQChar *src = type(func->_sourcename) == OT_STRING?_stringval(func->_sourcename):NULL;
-			const SQChar *name = type(func->_name) == OT_STRING?_stringval(func->_name):NULL;
+			const SQChar *src = sq_type(func->_sourcename) == OT_STRING?_stringval(func->_sourcename):NULL;
+			const SQChar *name = sq_type(func->_name) == OT_STRING?_stringval(func->_name):NULL;
 			Raise_Error(_SC("wrong number of parameters: %d provided (instead %d) in call to %s:%s"), nargs, paramssize, src, name);
 			return false;
 		}
@@ -412,8 +416,8 @@ bool SQVM::StartCall(SQClosure *closure,SQInteger target,SQInteger args,SQIntege
 			}
 		}
 		else {
-			const SQChar *src = type(func->_sourcename) == OT_STRING?_stringval(func->_sourcename):NULL;
-			const SQChar *name = type(func->_name) == OT_STRING?_stringval(func->_name):NULL;
+			const SQChar *src = sq_type(func->_sourcename) == OT_STRING?_stringval(func->_sourcename):NULL;
+			const SQChar *name = sq_type(func->_name) == OT_STRING?_stringval(func->_name):NULL;
 			Raise_Error(_SC("wrong number of parameters: %d provided (instead %d) in call to %s:%s"), nargs, paramssize, src, name);
 			return false;
 		}
@@ -524,7 +528,7 @@ bool SQVM::FOREACH_OP(SQObjectPtr &o1,SQObjectPtr &o2,SQObjectPtr
 &o3,SQObjectPtr &o4,SQInteger SQ_UNUSED_ARG(arg_2),int exitpos,int &jump)
 {
 	SQInteger nrefidx;
-	switch(type(o1)) {
+	switch(sq_type(o1)) {
 	case OT_TABLE:
 		if((nrefidx = _table(o1)->Next(false,o4, o2, o3)) == -1) _FINISH(exitpos);
 		o4 = (SQInteger)nrefidx; _FINISH(1);
@@ -547,7 +551,7 @@ bool SQVM::FOREACH_OP(SQObjectPtr &o1,SQObjectPtr &o2,SQObjectPtr
 				Push(o4);
 				if(CallMetaMethod(closure, MT_NEXTI, 2, itr)) {
 					o4 = o2 = itr;
-					if(type(itr) == OT_NULL) _FINISH(exitpos);
+					if(sq_type(itr) == OT_NULL) _FINISH(exitpos);
 					if(!Get(o1, itr, o3, 0, DONT_FALL_BACK)) {
 						Raise_Error(_SC("_nexti returned an invalid idx")); // cloud be changed
 						return false;
@@ -566,7 +570,7 @@ bool SQVM::FOREACH_OP(SQObjectPtr &o1,SQObjectPtr &o2,SQObjectPtr
 		if(_generator(o1)->_state == SQGenerator::eDead) _FINISH(exitpos);
 		if(_generator(o1)->_state == SQGenerator::eSuspended) {
 			SQInteger idx = 0;
-			if(type(o4) == OT_INTEGER) {
+			if(sq_type(o4) == OT_INTEGER) {
 				idx = _integer(o4) + 1;
 			}
 			o2 = idx;
@@ -621,14 +625,14 @@ bool SQVM::CLASS_OP(SQObjectPtr &target,SQInteger baseclass,SQInteger attributes
 	SQClass *base = NULL;
 	SQObjectPtr attrs;
 	if(baseclass != -1) {
-		if(type(_stack._vals[_stackbase+baseclass]) != OT_CLASS) { Raise_Error(_SC("trying to inherit from a %s"),GetTypeName(_stack._vals[_stackbase+baseclass])); return false; }
+		if(sq_type(_stack._vals[_stackbase+baseclass]) != OT_CLASS) { Raise_Error(_SC("trying to inherit from a %s"),GetTypeName(_stack._vals[_stackbase+baseclass])); return false; }
 		base = _class(_stack._vals[_stackbase + baseclass]);
 	}
 	if(attributes != MAX_FUNC_STACKSIZE) {
 		attrs = _stack._vals[_stackbase+attributes];
 	}
 	target = SQClass::Create(_ss(this),base);
-	if(type(_class(target)->_metamethods[MT_INHERITED]) != OT_NULL) {
+	if(sq_type(_class(target)->_metamethods[MT_INHERITED]) != OT_NULL) {
 		int nparams = 2;
 		SQObjectPtr ret;
 		Push(target); Push(attrs);
@@ -644,9 +648,15 @@ bool SQVM::CLASS_OP(SQObjectPtr &target,SQInteger baseclass,SQInteger attributes
 
 bool SQVM::IsEqual(const SQObjectPtr &o1,const SQObjectPtr &o2,bool &res)
 {
-	if(type(o1) == type(o2)) {
+	SQObjectType t1 = sq_type(o1), t2 = sq_type(o2);
+	if(t1 == t2) {
+		if (t1 == OT_FLOAT) {
+			res = (_float(o1) == _float(o2));
+		}
+		else {
 		res = (_rawval(o1) == _rawval(o2));
 	}
+	}
 	else {
 		if(sq_isnumeric(o1) && sq_isnumeric(o2)) {
 			res = (tofloat(o1) == tofloat(o2));
@@ -660,19 +670,18 @@ bool SQVM::IsEqual(const SQObjectPtr &o1,const SQObjectPtr &o2,bool &res)
 
 bool SQVM::IsFalse(SQObjectPtr &o)
 {
-	if(((type(o) & SQOBJECT_CANBEFALSE)
-		&& ( ((type(o) == OT_FLOAT) && (_float(o) == SQFloat(0.0))) ))
+	if(((sq_type(o) & SQOBJECT_CANBEFALSE)
+		&& ( ((sq_type(o) == OT_FLOAT) && (_float(o) == SQFloat(0.0))) ))
 #if !defined(SQUSEDOUBLE) || (defined(SQUSEDOUBLE) && defined(_SQ64))
 		|| (_integer(o) == 0) )  //OT_NULL|OT_INTEGER|OT_BOOL
 #else
-		|| (((type(o) != OT_FLOAT) && (_integer(o) == 0))) )  //OT_NULL|OT_INTEGER|OT_BOOL
+		|| (((sq_type(o) != OT_FLOAT) && (_integer(o) == 0))) )  //OT_NULL|OT_INTEGER|OT_BOOL
 #endif
 	{
 		return true;
 	}
 	return false;
 }
-
 extern SQInstructionDesc g_InstrDesc[];
 
 bool SQVM::Execute(SQObjectPtr &closure, SQInteger nargs, SQInteger stackbase,SQObjectPtr &outres, SQBool raiseerror,ExecutionType et, SQBool can_suspend)
@@ -735,7 +744,7 @@ exception_restore:
 
 			const SQInstruction &_i_ = *ci->_ip++;
 			//dumpstack(_stackbase);
-			//scprintf("\n[%d] %s %d %d %d %d\n",ci->_ip-ci->_iv->_vals,g_InstrDesc[_i_.op].name,arg0,arg1,arg2,arg3);
+			//scprintf("\n[%d] %s %d %d %d %d\n",ci->_ip-_closure(ci->_closure)->_function->_instructions,g_InstrDesc[_i_.op].name,arg0,arg1,arg2,arg3);
 			switch(_i_.op)
 			{
 			case _OP_LINE: if (_debughook) CallDebugHook(_SC('l'),arg1); continue;
@@ -754,24 +763,29 @@ exception_restore:
 			case _OP_DLOAD: TARGET = ci->_literals[arg1]; STK(arg2) = ci->_literals[arg3];continue;
 			case _OP_TAILCALL:{
 				SQObjectPtr &t = STK(arg1);
-				if (type(t) == OT_CLOSURE
+				if (sq_type(t) == OT_CLOSURE
 					&& (!_closure(t)->_function->_bgenerator)){
 					SQObjectPtr clo = t;
+					SQInteger last_top = _top;
 					if(_openouters) CloseOuters(&(_stack._vals[_stackbase]));
 					for (SQInteger i = 0; i < arg3; i++) STK(i) = STK(arg2 + i);
 					_GUARD(StartCall(_closure(clo), ci->_target, arg3, _stackbase, true));
+					if (last_top >= _top) {
+						_top = last_top;
+					}
 					continue;
 				}
 							  }
 			case _OP_CALL: {
 					SQObjectPtr clo = STK(arg1);
-					switch (type(clo)) {
+					switch (sq_type(clo)) {
 					case OT_CLOSURE:
 						_GUARD(StartCall(_closure(clo), sarg0, arg3, _stackbase+arg2, false));
 						continue;
 					case OT_NATIVECLOSURE: {
 						bool suspend;
-						_GUARD(CallNative(_nativeclosure(clo), arg3, _stackbase+arg2, clo,suspend));
+						bool tailcall;
+						_GUARD(CallNative(_nativeclosure(clo), arg3, _stackbase+arg2, clo, (SQInt32)sarg0, suspend, tailcall));
 						if(suspend){
 							_suspended = SQTrue;
 							_suspended_target = sarg0;
@@ -780,7 +794,7 @@ exception_restore:
 							outres = clo;
 							return true;
 						}
-						if(sarg0 != -1) {
+						if(sarg0 != -1 && !tailcall) {
 							STK(arg0) = clo;
 						}
 										   }
@@ -792,17 +806,17 @@ exception_restore:
 							STK(arg0) = inst;
 						}
 						SQInteger stkbase;
-						switch(type(clo)) {
+						switch(sq_type(clo)) {
 							case OT_CLOSURE:
 								stkbase = _stackbase+arg2;
 								_stack._vals[stkbase] = inst;
 								_GUARD(StartCall(_closure(clo), -1, arg3, stkbase, false));
 								break;
 							case OT_NATIVECLOSURE:
-								bool suspend;
+								bool dummy;
 								stkbase = _stackbase+arg2;
 								_stack._vals[stkbase] = inst;
-								_GUARD(CallNative(_nativeclosure(clo), arg3, stkbase, clo,suspend));
+								_GUARD(CallNative(_nativeclosure(clo), arg3, stkbase, clo, -1, dummy, dummy));
 								break;
 							default: break; //shutup GCC 4.x
 						}
@@ -890,7 +904,7 @@ exception_restore:
 			case _OP_LOADNULLS:{ for(SQInt32 n=0; n < arg1; n++) STK(arg0+n).Null(); }continue;
 			case _OP_LOADROOT:  {
 				SQWeakRef *w = _closure(ci->_closure)->_root;
-				if(type(w->_obj) != OT_NULL) {
+				if(sq_type(w->_obj) != OT_NULL) {
 					TARGET = w->_obj;
 				} else {
 					TARGET = _roottable; //shoud this be like this? or null
@@ -966,7 +980,7 @@ exception_restore:
 			case _OP_INC: {SQObjectPtr o(sarg3); _GUARD(DerefInc('+',TARGET, STK(arg1), STK(arg2), o, false, arg1));} continue;
 			case _OP_INCL: {
 				SQObjectPtr &a = STK(arg1);
-				if(type(a) == OT_INTEGER) {
+				if(sq_type(a) == OT_INTEGER) {
 					a._unVal.nInteger = _integer(a) + sarg3;
 				}
 				else {
@@ -977,7 +991,7 @@ exception_restore:
 			case _OP_PINC: {SQObjectPtr o(sarg3); _GUARD(DerefInc('+',TARGET, STK(arg1), STK(arg2), o, true, arg1));} continue;
 			case _OP_PINCL: {
 				SQObjectPtr &a = STK(arg1);
-				if(type(a) == OT_INTEGER) {
+				if(sq_type(a) == OT_INTEGER) {
 					TARGET = a;
 					a._unVal.nInteger = _integer(a) + sarg3;
 				}
@@ -989,9 +1003,9 @@ exception_restore:
 			case _OP_CMP:   _GUARD(CMP_OP((CmpOP)arg3,STK(arg2),STK(arg1),TARGET))  continue;
 			case _OP_EXISTS: TARGET = Get(STK(arg1), STK(arg2), temp_reg, GET_FLAG_DO_NOT_RAISE_ERROR | GET_FLAG_RAW, DONT_FALL_BACK) ? true : false; continue;
 			case _OP_INSTANCEOF:
-				if(type(STK(arg1)) != OT_CLASS)
+				if(sq_type(STK(arg1)) != OT_CLASS)
 				{Raise_Error(_SC("cannot apply instanceof between a %s and a %s"),GetTypeName(STK(arg1)),GetTypeName(STK(arg2))); SQ_THROW();}
-				TARGET = (type(STK(arg2)) == OT_INSTANCE) ? (_instance(STK(arg2))->InstanceOf(_class(STK(arg1)))?true:false) : false;
+				TARGET = (sq_type(STK(arg2)) == OT_INSTANCE) ? (_instance(STK(arg2))->InstanceOf(_class(STK(arg1)))?true:false) : false;
 				continue;
 			case _OP_AND:
 				if(IsFalse(STK(arg2))) {
@@ -1008,7 +1022,7 @@ exception_restore:
 			case _OP_NEG: _GUARD(NEG_OP(TARGET,STK(arg1))); continue;
 			case _OP_NOT: TARGET = IsFalse(STK(arg1)); continue;
 			case _OP_BWNOT:
-				if(type(STK(arg1)) == OT_INTEGER) {
+				if(sq_type(STK(arg1)) == OT_INTEGER) {
 					SQInteger t = _integer(STK(arg1));
 					TARGET = SQInteger(~t);
 					continue;
@@ -1024,6 +1038,7 @@ exception_restore:
 			case _OP_YIELD:{
 				if(ci->_generator) {
 					if(sarg1 != MAX_FUNC_STACKSIZE) temp_reg = STK(arg1);
+					if (_openouters) CloseOuters(&_stack._vals[_stackbase]);
 					_GUARD(ci->_generator->Yield(this,arg2));
 					traps -= ci->_etraps;
 					if(sarg1 != MAX_FUNC_STACKSIZE) _Swap(STK(arg1),temp_reg);//STK(arg1) = temp_reg;
@@ -1038,7 +1053,7 @@ exception_restore:
 				}
 				continue;
 			case _OP_RESUME:
-				if(type(STK(arg1)) != OT_GENERATOR){ Raise_Error(_SC("trying to resume a '%s',only genenerator can be resumed"), GetTypeName(STK(arg1))); SQ_THROW();}
+				if(sq_type(STK(arg1)) != OT_GENERATOR){ Raise_Error(_SC("trying to resume a '%s',only genenerator can be resumed"), GetTypeName(STK(arg1))); SQ_THROW();}
 				_GUARD(_generator(STK(arg1))->Resume(this, TARGET));
 				traps += ci->_etraps;
 				continue;
@@ -1047,7 +1062,7 @@ exception_restore:
 				ci->_ip += tojump; }
 				continue;
 			case _OP_POSTFOREACH:
-				assert(type(STK(arg0)) == OT_GENERATOR);
+				assert(sq_type(STK(arg0)) == OT_GENERATOR);
 				if(_generator(STK(arg0))->_state == SQGenerator::eDead)
 					ci->_ip += (sarg1 - 1);
 				continue;
@@ -1137,7 +1152,7 @@ bool SQVM::CreateClassInstance(SQClass *theclass, SQObjectPtr &inst, SQObjectPtr
 
 void SQVM::CallErrorHandler(SQObjectPtr &error)
 {
-	if(type(_errorhandler) != OT_NULL) {
+	if(sq_type(_errorhandler) != OT_NULL) {
 		SQObjectPtr out;
 		Push(_roottable); Push(error);
 		Call(_errorhandler, 2, _top-2, out,SQFalse);
@@ -1151,8 +1166,8 @@ void SQVM::CallDebugHook(SQInteger type,SQInteger forcedline)
 	_debughook = false;
 	SQFunctionProto *func=_closure(ci->_closure)->_function;
 	if(_debughook_native) {
-		const SQChar *src = type(func->_sourcename) == OT_STRING?_stringval(func->_sourcename):NULL;
-		const SQChar *fname = type(func->_name) == OT_STRING?_stringval(func->_name):NULL;
+		const SQChar *src = sq_type(func->_sourcename) == OT_STRING?_stringval(func->_sourcename):NULL;
+		const SQChar *fname = sq_type(func->_name) == OT_STRING?_stringval(func->_name):NULL;
 		SQInteger line = forcedline?forcedline:func->GetLine(ci->_ip);
 		_debughook_native(this,type,src,line,fname);
 	}
@@ -1166,7 +1181,7 @@ void SQVM::CallDebugHook(SQInteger type,SQInteger forcedline)
 	_debughook = true;
 }
 
-bool SQVM::CallNative(SQNativeClosure *nclosure, SQInteger nargs, SQInteger newbase, SQObjectPtr &retval, bool &suspend)
+bool SQVM::CallNative(SQNativeClosure *nclosure, SQInteger nargs, SQInteger newbase, SQObjectPtr &retval, SQInt32 target,bool &suspend, bool &tailcall)
 {
 	SQInteger nparamscheck = nclosure->_nparamscheck;
 	SQInteger newtop = newbase + nargs + nclosure->_noutervalues;
@@ -1179,7 +1194,7 @@ bool SQVM::CallNative(SQNativeClosure *nclosure, SQInteger nargs, SQInteger newb
 	if(nparamscheck && (((nparamscheck > 0) && (nparamscheck != nargs)) ||
 		((nparamscheck < 0) && (nargs < (-nparamscheck)))))
 	{
-		const SQChar *src = type(nclosure->_name) == OT_STRING?_stringval(nclosure->_name):NULL;
+		const SQChar *src = sq_type(nclosure->_name) == OT_STRING?_stringval(nclosure->_name):NULL;
 		Raise_Error(_SC("wrong number of parameters: %d provided (instead %d) in call to %s"), nargs, nparamscheck, src);
 		return false;
 	}
@@ -1188,8 +1203,8 @@ bool SQVM::CallNative(SQNativeClosure *nclosure, SQInteger nargs, SQInteger newb
 	SQIntVec &tc = nclosure->_typecheck;
 	if((tcs = tc.size())) {
 		for(SQInteger i = 0; i < nargs && i < tcs; i++) {
-			if((tc._vals[i] != -1) && !(type(_stack._vals[newbase+i]) & tc._vals[i])) {
-				Raise_ParamTypeError(i,tc._vals[i],type(_stack._vals[newbase+i]));
+			if((tc._vals[i] != -1) && !(sq_type(_stack._vals[newbase+i]) & tc._vals[i])) {
+				Raise_ParamTypeError(i,tc._vals[i], sq_type(_stack._vals[newbase+i]));
 				return false;
 			}
 		}
@@ -1197,6 +1212,7 @@ bool SQVM::CallNative(SQNativeClosure *nclosure, SQInteger nargs, SQInteger newb
 
 	if(!EnterFrame(newbase, newtop, false)) return false;
 	ci->_closure  = nclosure;
+	ci->_target = target;
 
 	SQInteger outers = nclosure->_noutervalues;
 	for (SQInteger i = 0; i < outers; i++) {
@@ -1211,7 +1227,12 @@ bool SQVM::CallNative(SQNativeClosure *nclosure, SQInteger nargs, SQInteger newb
 	_nnativecalls--;
 
 	suspend = false;
-	if (ret == SQ_SUSPEND_FLAG) {
+	tailcall = false;
+	if (ret == SQ_TAILCALL_FLAG) {
+		tailcall = true;
+		return true;
+	}
+	else if (ret == SQ_SUSPEND_FLAG) {
 		suspend = true;
 	}
 	else if (ret < 0) {
@@ -1230,13 +1251,30 @@ bool SQVM::CallNative(SQNativeClosure *nclosure, SQInteger nargs, SQInteger newb
 	return true;
 }
 
+bool SQVM::TailCall(SQClosure *closure, SQInteger parambase,SQInteger nparams)
+{
+	SQInteger last_top = _top;
+	SQObjectPtr clo = closure;
+	if (ci->_root)
+	{
+		Raise_Error("root calls cannot invoke tailcalls");
+		return false;
+	}
+	for (SQInteger i = 0; i < nparams; i++) STK(i) = STK(parambase + i);
+	bool ret = StartCall(closure, ci->_target, nparams, _stackbase, true);
+	if (last_top >= _top) {
+		_top = last_top;
+	}
+	return ret;
+}
+
 #define FALLBACK_OK			0
 #define FALLBACK_NO_MATCH	1
 #define FALLBACK_ERROR		2
 
 bool SQVM::Get(const SQObjectPtr &self, const SQObjectPtr &key, SQObjectPtr &dest, SQUnsignedInteger getflags, SQInteger selfidx)
 {
-	switch(type(self)){
+	switch(sq_type(self)){
 	case OT_TABLE:
 		if(_table(self)->Get(key,dest))return true;
 		break;
@@ -1277,7 +1315,7 @@ bool SQVM::Get(const SQObjectPtr &self, const SQObjectPtr &key, SQObjectPtr &des
 //#ifdef ROOT_FALLBACK
 	if(selfidx == 0) {
 		SQWeakRef *w = _closure(ci->_closure)->_root;
-		if(type(w->_obj) != OT_NULL)
+		if(sq_type(w->_obj) != OT_NULL)
 		{
 			if(Get(*((const SQObjectPtr *)&w->_obj),key,dest,0,DONT_FALL_BACK)) return true;
 		}
@@ -1291,7 +1329,7 @@ bool SQVM::Get(const SQObjectPtr &self, const SQObjectPtr &key, SQObjectPtr &des
 bool SQVM::InvokeDefaultDelegate(const SQObjectPtr &self,const SQObjectPtr &key,SQObjectPtr &dest)
 {
 	SQTable *ddel = NULL;
-	switch(type(self)) {
+	switch(sq_type(self)) {
 		case OT_CLASS: ddel = _class_ddel; break;
 		case OT_TABLE: ddel = _table_ddel; break;
 		case OT_ARRAY: ddel = _array_ddel; break;
@@ -1310,7 +1348,7 @@ bool SQVM::InvokeDefaultDelegate(const SQObjectPtr &self,const SQObjectPtr &key,
 
 SQInteger SQVM::FallBackGet(const SQObjectPtr &self,const SQObjectPtr &key,SQObjectPtr &dest)
 {
-	switch(type(self)){
+	switch(sq_type(self)){
 	case OT_TABLE:
 	case OT_USERDATA:
 		//delegation
@@ -1333,7 +1371,7 @@ SQInteger SQVM::FallBackGet(const SQObjectPtr &self,const SQObjectPtr &key,SQObj
 			}
 			else {
 				Pop(2);
-				if(type(_lasterror) != OT_NULL) { //NULL means "clean failure" (not found)
+				if(sq_type(_lasterror) != OT_NULL) { //NULL means "clean failure" (not found)
 					return FALLBACK_ERROR;
 				}
 			}
@@ -1348,7 +1386,7 @@ SQInteger SQVM::FallBackGet(const SQObjectPtr &self,const SQObjectPtr &key,SQObj
 
 bool SQVM::Set(const SQObjectPtr &self,const SQObjectPtr &key,const SQObjectPtr &val,SQInteger selfidx)
 {
-	switch(type(self)){
+	switch(sq_type(self)){
 	case OT_TABLE:
 		if(_table(self)->Set(key,val)) return true;
 		break;
@@ -1362,6 +1400,7 @@ bool SQVM::Set(const SQObjectPtr &self,const SQObjectPtr &key,const SQObjectPtr
 			return false;
 		}
 		return true;
+	case OT_USERDATA: break; // must fall back
 	default:
 		Raise_Error(_SC("trying to set '%s'"),GetTypeName(self));
 		return false;
@@ -1382,7 +1421,7 @@ bool SQVM::Set(const SQObjectPtr &self,const SQObjectPtr &key,const SQObjectPtr
 
 SQInteger SQVM::FallBackSet(const SQObjectPtr &self,const SQObjectPtr &key,const SQObjectPtr &val)
 {
-	switch(type(self)) {
+	switch(sq_type(self)) {
 	case OT_TABLE:
 		if(_table(self)->_delegate) {
 			if(Set(_table(self)->_delegate,key,val,DONT_FALL_BACK)) return FALLBACK_OK;
@@ -1401,9 +1440,8 @@ SQInteger SQVM::FallBackSet(const SQObjectPtr &self,const SQObjectPtr &key,const
 				return FALLBACK_OK;
 			}
 			else {
-				if(type(_lasterror) != OT_NULL) { //NULL means "clean failure" (not found)
-					//error
 					Pop(3);
+				if(sq_type(_lasterror) != OT_NULL) { //NULL means "clean failure" (not found)
 					return FALLBACK_ERROR;
 				}
 			}
@@ -1420,7 +1458,7 @@ bool SQVM::Clone(const SQObjectPtr &self,SQObjectPtr &target)
 {
 	SQObjectPtr temp_reg;
 	SQObjectPtr newobj;
-	switch(type(self)){
+	switch(sq_type(self)){
 	case OT_TABLE:
 		newobj = _table(self)->Clone();
 		goto cloned_mt;
@@ -1448,14 +1486,14 @@ cloned_mt:
 
 bool SQVM::NewSlotA(const SQObjectPtr &self,const SQObjectPtr &key,const SQObjectPtr &val,const SQObjectPtr &attrs,bool bstatic,bool raw)
 {
-	if(type(self) != OT_CLASS) {
+	if(sq_type(self) != OT_CLASS) {
 		Raise_Error(_SC("object must be a class"));
 		return false;
 	}
 	SQClass *c = _class(self);
 	if(!raw) {
 		SQObjectPtr &mm = c->_metamethods[MT_NEWMEMBER];
-		if(type(mm) != OT_NULL ) {
+		if(sq_type(mm) != OT_NULL ) {
 			Push(self); Push(key); Push(val);
 			Push(attrs);
 			Push(bstatic);
@@ -1464,7 +1502,7 @@ bool SQVM::NewSlotA(const SQObjectPtr &self,const SQObjectPtr &key,const SQObjec
 	}
 	if(!NewSlot(self, key, val,bstatic))
 		return false;
-	if(type(attrs) != OT_NULL) {
+	if(sq_type(attrs) != OT_NULL) {
 		c->SetAttributes(key,attrs);
 	}
 	return true;
@@ -1472,8 +1510,8 @@ bool SQVM::NewSlotA(const SQObjectPtr &self,const SQObjectPtr &key,const SQObjec
 
 bool SQVM::NewSlot(const SQObjectPtr &self,const SQObjectPtr &key,const SQObjectPtr &val,bool bstatic)
 {
-	if(type(key) == OT_NULL) { Raise_Error(_SC("null cannot be used as index")); return false; }
-	switch(type(self)) {
+	if(sq_type(key) == OT_NULL) { Raise_Error(_SC("null cannot be used as index")); return false; }
+	switch(sq_type(self)) {
 	case OT_TABLE: {
 		bool rawcall = true;
 		if(_table(self)->_delegate) {
@@ -1533,7 +1571,7 @@ bool SQVM::NewSlot(const SQObjectPtr &self,const SQObjectPtr &key,const SQObject
 
 bool SQVM::DeleteSlot(const SQObjectPtr &self,const SQObjectPtr &key,SQObjectPtr &res)
 {
-	switch(type(self)) {
+	switch(sq_type(self)) {
 	case OT_TABLE:
 	case OT_INSTANCE:
 	case OT_USERDATA: {
@@ -1545,7 +1583,7 @@ bool SQVM::DeleteSlot(const SQObjectPtr &self,const SQObjectPtr &key,SQObjectPtr
 			return CallMetaMethod(closure,MT_DELSLOT,2,res);
 		}
 		else {
-			if(type(self) == OT_TABLE) {
+			if(sq_type(self) == OT_TABLE) {
 				if(_table(self)->Get(key,t)) {
 					_table(self)->Remove(key);
 				}
@@ -1574,13 +1612,13 @@ bool SQVM::Call(SQObjectPtr &closure,SQInteger nparams,SQInteger stackbase,SQObj
 #ifdef _DEBUG
 SQInteger prevstackbase = _stackbase;
 #endif
-	switch(type(closure)) {
+	switch(sq_type(closure)) {
 	case OT_CLOSURE:
 		return Execute(closure, nparams, stackbase, outres, raiseerror, ET_CALL, can_suspend);
 		break;
 	case OT_NATIVECLOSURE:{
-		bool suspend;
-		return CallNative(_nativeclosure(closure), nparams, stackbase, outres,suspend);
+		bool dummy;
+		return CallNative(_nativeclosure(closure), nparams, stackbase, outres, -1, dummy, dummy);
 
 						  }
 		break;
@@ -1588,7 +1626,7 @@ SQInteger prevstackbase = _stackbase;
 		SQObjectPtr constr;
 		SQObjectPtr temp;
 		CreateClassInstance(_class(closure),outres,constr);
-		SQObjectType ctype = type(constr);
+		SQObjectType ctype = sq_type(constr);
 		if (ctype == OT_NATIVECLOSURE || ctype == OT_CLOSURE) {
 			_stack[stackbase] = outres;
 			return Call(constr,nparams,stackbase,temp,raiseerror);
@@ -1597,6 +1635,7 @@ SQInteger prevstackbase = _stackbase;
 				   }
 		break;
 	default:
+		Raise_Error(_SC("attempt to call '%s'"), GetTypeName(closure));
 		return false;
 	}
 #ifdef _DEBUG
@@ -1750,10 +1789,10 @@ void SQVM::dumpstack(SQInteger stackbase,bool dumpall)
 	for(SQInteger i=0;i<size;i++){
 		SQObjectPtr &obj=_stack[i];
 		if(stackbase==i)scprintf(_SC(">"));else scprintf(_SC(" "));
-		scprintf(_SC("[%d]:"),n);
-		switch(type(obj)){
+		scprintf(_SC("[" _PRINT_INT_FMT "]:"),n);
+		switch(sq_type(obj)){
 		case OT_FLOAT:			scprintf(_SC("FLOAT %.3f"),_float(obj));break;
-		case OT_INTEGER:		scprintf(_SC("INTEGER %d"),_integer(obj));break;
+		case OT_INTEGER:		scprintf(_SC("INTEGER " _PRINT_INT_FMT),_integer(obj));break;
 		case OT_BOOL:			scprintf(_SC("BOOL %s"),_integer(obj)?"true":"false");break;
 		case OT_STRING:			scprintf(_SC("STRING %s"),_stringval(obj));break;
 		case OT_NULL:			scprintf(_SC("NULL"));	break;
@@ -1767,7 +1806,7 @@ void SQVM::dumpstack(SQInteger stackbase,bool dumpall)
 		case OT_USERPOINTER:	scprintf(_SC("USERPOINTER %p"),_userpointer(obj));break;
 		case OT_CLASS:			scprintf(_SC("CLASS %p"),_class(obj));break;
 		case OT_INSTANCE:		scprintf(_SC("INSTANCE %p"),_instance(obj));break;
-		case OT_WEAKREF:		scprintf(_SC("WEAKERF %p"),_weakref(obj));break;
+		case OT_WEAKREF:		scprintf(_SC("WEAKREF %p"),_weakref(obj));break;
 		default:
 			assert(0);
 			break;
