@@ -34,6 +34,8 @@ private:
 	 */
 	static translator single_instance;
 
+	static uint32 guess_highest_unicode(int lang);
+
 	/* Methods related to loading a language file into memory */
 	static void load_language_file(FILE* file);
 	static void load_language_iso(const std::string &iso);
@@ -52,6 +54,7 @@ public:
 		const char *iso;
 		const char *iso_base;
 		bool is_latin2_based;
+		uint32 highest_character;
 		uint8 ellipsis_width;
 	};
 
@@ -96,7 +99,7 @@ public:
 	 * an error message, leaving the language as it is
 	 */
 	static void set_language(int lang);
-	static void set_language(const char* iso);
+	static bool set_language(const char* iso);
 
 	/**
 	 * Returns the number of loaded languages.
@@ -126,7 +129,9 @@ public:
 	// return date in selected format
 	static const char *get_date(uint16 year, uint16 month);
 	static const char *get_date(uint16 year, uint16 month, uint16 day, char const* season);
-	static const char *get_short_date(uint16 year, uint16 month);
+	static const char* get_short_date(uint16 year, uint16 month);
+	static const char* get_month_date(uint16 month, uint16 day);
+	static const char* get_day_date( uint16 day );
 };
 
 #endif
