@@ -4,7 +4,6 @@
  */
 
 #include <algorithm>
-#include "../vehicle/simvehicle.h"
 #include "../player/simplay.h"
 #include "../simdebug.h"
 #include "../utils/simrandom.h"
@@ -21,6 +20,10 @@
 #include "vehikelbauer.h"
 
 #include "../tpl/stringhashtable_tpl.h"
+#include "../vehicle/air_vehicle.h"
+#include "../vehicle/rail_vehicle.h"
+#include "../vehicle/road_vehicle.h"
+#include "../vehicle/water_vehicle.h"
 
 
 const char* vehicle_builder_t::engine_type_names[9] =
@@ -65,7 +68,7 @@ public:
 	bonus_record_t( sint32 y=0, sint32 kmh=0 ) {
 		year = y*12;
 		speed = kmh;
-	};
+	}
 	void rdwr(loadsave_t *file) {
 		file->rdwr_long(year);
 		file->rdwr_long(speed);
@@ -103,17 +106,18 @@ bool vehicle_builder_t::speedbonus_init(const std::string &objfilename)
 	 * must be increasing order!
 	 */
 	for(  int j=0;  j<8;  j++  ) {
-		int *tracks = contents.get_ints(weg_t::waytype_to_string(j==3?air_wt:(waytype_t)(j+1)));
-		if((tracks[0]&1)==1) {
+		vector_tpl<int> tracks = contents.get_ints(weg_t::waytype_to_string(j==3?air_wt:(waytype_t)(j+1)));
+
+		if((tracks.get_count() % 2) != 0) {
 			dbg->warning( "vehicle_builder_t::speedbonus_init()", "Ill formed line in speedbonus.tab\nFormat is year,speed[,year,speed]!" );
-			tracks[0]--;
+			tracks.pop_back();
 		}
-		speedbonus[j].resize( tracks[0]/2 );
-		for(  int i=1;  i<tracks[0];  i+=2  ) {
+
+		speedbonus[j].resize( tracks.get_count()/2 );
+		for(  uint32 i=0;  i<tracks.get_count();  i+=2  ) {
 			bonus_record_t b( tracks[i], tracks[i+1] );
 			speedbonus[j].append( b );
 		}
-		delete [] tracks;
 	}
 
 	return true;
@@ -393,7 +397,7 @@ slist_tpl<vehicle_desc_t const*> const & vehicle_builder_t::get_info(waytype_t c
  * checks also timeline and constraints
  * tries to get best with but adds a little random action
  */
-const vehicle_desc_t *vehicle_builder_t::vehikel_search( waytype_t wt, const uint16 month_now, const uint32 target_weight, const sint32 target_speed, const goods_desc_t * target_freight, bool include_electric, bool not_obsolete )
+const vehicle_desc_t *vehicle_builder_t::vehicle_search( waytype_t wt, const uint16 month_now, const uint32 target_weight, const sint32 target_speed, const goods_desc_t * target_freight, bool include_electric, bool not_obsolete )
 {
 	const vehicle_desc_t *desc = NULL;
 	sint32 desc_index = -100000;
@@ -459,7 +463,7 @@ const vehicle_desc_t *vehicle_builder_t::vehikel_search( waytype_t wt, const uin
 			if(  desc==NULL  ||  difference<(int)simrand(25)    ) {
 				// then we want this vehicle!
 				desc = test_desc;
-				DBG_MESSAGE( "vehicle_builder_t::vehikel_search","Found car %s",desc->get_name());
+				DBG_MESSAGE( "vehicle_builder_t::vehicle_search","Found car %s",desc->get_name());
 			}
 		}
 
@@ -487,13 +491,13 @@ const vehicle_desc_t *vehicle_builder_t::vehikel_search( waytype_t wt, const uin
 				// then we want this vehicle!
 				desc = test_desc;
 				desc_index = current_index;
-				DBG_MESSAGE( "vehicle_builder_t::vehikel_search","Found engine %s",desc->get_name());
+				DBG_MESSAGE( "vehicle_builder_t::vehicle_search","Found engine %s",desc->get_name());
 			}
 		}
 	}
 	// no vehicle found!
 	if(  desc==NULL  ) {
-		DBG_MESSAGE( "vehicle_builder_t::vehikel_search()","could not find a suitable vehicle! (speed %i, weight %i)",target_speed,target_weight);
+		DBG_MESSAGE( "vehicle_builder_t::vehicle_search()","could not find a suitable vehicle! (speed %i, weight %i)",target_speed,target_weight);
 	}
 	return desc;
 }
