@@ -9,7 +9,6 @@
 
 #include "../dataobj/koord3d.h"
 #include "../simtypes.h"
-#include "../gui/depot_frame.h"
 #include <string>
 
 class vehicle_t;
@@ -35,7 +34,8 @@ public:
 		sb_price,
 		sb_cost,
 		sb_cost_per_unit,
-		sb_speed, sb_power,
+		sb_speed,
+		sb_power,
 		sb_weight,
 		sb_intro_date,
 		sb_retire_date,
@@ -62,7 +62,7 @@ public:
 
 	/** extended search for vehicles for AI
 	*/
-	static const vehicle_desc_t *vehikel_search(waytype_t typ,const uint16 month_now,const uint32 target_power,const sint32 target_speed, const goods_desc_t * target_freight, bool include_electric, bool not_obsolete );
+	static const vehicle_desc_t *vehicle_search(waytype_t typ,const uint16 month_now,const uint32 target_power,const sint32 target_speed, const goods_desc_t * target_freight, bool include_electric, bool not_obsolete );
 
 	/* for replacement during load time
 	 * prev_veh==NULL equals leading of convoi
