@@ -5,26 +5,36 @@
 
 #include "wasser.h"
 
-#include "../simworld.h"
-
-#include "../descriptor/ground_desc.h"
-
 #include "../dataobj/environment.h"
-
+#include "../descriptor/ground_desc.h"
 #include "../obj/gebaeude.h"
-
+#include "../simworld.h"
 
 
 int wasser_t::stage = 0;
 bool wasser_t::change_stage = false;
 
-wasser_t::wasser_t(koord3d pos): grund_t(pos), ribi(ribi_t::none), canal_ribi(ribi_t::none)
-, display_ribi(ribi_t::none)
+
+wasser_t::wasser_t(loadsave_t *file, koord pos) :
+	grund_t(koord3d(pos,0) ),
+	ribi(ribi_t::none),
+	canal_ribi(ribi_t::none)
+{
+	rdwr(file);
+}
+
+
+wasser_t::wasser_t(koord3d pos) :
+	grund_t(pos),
+	ribi(ribi_t::none),
+	canal_ribi(ribi_t::none),
+	display_ribi(ribi_t::none)
 {
 	set_hoehe( welt->get_water_hgt( pos.get_2d() ) );
 	slope = slope_t::flat;
 }
 
+
 // for animated waves
 void wasser_t::prepare_for_refresh()
 {
@@ -53,9 +63,9 @@ void wasser_t::calc_image_internal(const bool calc_only_snowline_change)
 {
 	if(  !calc_only_snowline_change  ) {
 		koord pos2d( get_pos().get_2d() );
-		sint16 height = welt->get_water_hgt( pos2d );\
+		sint8 height = welt->get_water_hgt( pos2d );\
 
-		sint16 zpos = min( welt->lookup_hgt( pos2d ), height ); // otherwise slope will fail ...
+		sint8 zpos = min( welt->lookup_hgt( pos2d ), height ); // otherwise slope will fail ...
 
 		if(  grund_t::underground_mode == grund_t::ugm_level  &&  grund_t::underground_level < zpos  ) {
 			set_image(IMG_EMPTY);
@@ -66,7 +76,7 @@ void wasser_t::calc_image_internal(const bool calc_only_snowline_change)
 		recalc_ribis();
 
 		// artifical walls from here on ...
-		grund_t::calc_back_image( height, 0 );
+		grund_t::calc_back_image( height, slope_t::flat );
 	}
 }
 
@@ -82,7 +92,7 @@ void wasser_t::recalc_ribis()
 
 	for(  uint8 i = 0;  i < 4;  i++  ) {
 		grund_t *gr_neighbour = NULL;
-		ribi_t::ribi test = ribi_t::nsew[i];
+		ribi_t::ribi test = ribi_t::nesw[i];
 
 		if( get_neighbour(gr_neighbour, invalid_wt, test) ) {
 			// neighbour tile has water ways
@@ -122,7 +132,7 @@ void wasser_t::recalc_water_neighbours()
 
 	for(  uint8 i = 0;  i < 4;  i++  ) {
 		grund_t *gr_neighbour = NULL;
-		ribi_t::ribi test = ribi_t::nsew[i];
+		ribi_t::ribi test = ribi_t::nesw[i];
 
 		if( get_neighbour(gr_neighbour, invalid_wt, test) ) {
 			if (wasser_t* gr_water = dynamic_cast<wasser_t*>(gr_neighbour) ) {
@@ -140,3 +150,9 @@ void wasser_t::rotate90()
 	canal_ribi = ribi_t::rotate90(canal_ribi);
 	display_ribi = ribi_t::rotate90(display_ribi);
 }
+
+
+const char* wasser_t::get_name() const
+{
+	return pos.z > welt->get_groundwater() ? "Lake" : "Sea";
+}
