@@ -8,7 +8,7 @@
 #include "../boden/grund.h"
 #include "../simworld.h"
 #include "../display/simimg.h"
-#include "../simobj.h"
+#include "simobj.h"
 #include "../player/simplay.h"
 #include "../simtool.h"
 
@@ -46,16 +46,26 @@ const way_obj_desc_t *wayobj_t::default_oberleitung=NULL;
 stringhashtable_tpl<const way_obj_desc_t *> wayobj_t::table;
 
 
-wayobj_t::wayobj_t(loadsave_t* const file) : obj_no_info_t()
+wayobj_t::wayobj_t(loadsave_t* const file) :
+	obj_no_info_t(),
+	desc(NULL),
+	diagonal(false),
+	hang(slope_t::flat),
+	nw(false),
+	dir(dir_unknown)
 {
 	rdwr(file);
 }
 
 
-wayobj_t::wayobj_t(koord3d const pos, player_t* const owner, ribi_t::ribi const d, way_obj_desc_t const* const b) : obj_no_info_t(pos)
+wayobj_t::wayobj_t(koord3d const pos, player_t* const owner, ribi_t::ribi const d, way_obj_desc_t const* const b) :
+	obj_no_info_t(pos),
+	desc(b),
+	diagonal(false),
+	hang(slope_t::flat),
+	nw(false),
+	dir(d)
 {
-	desc = b;
-	dir = d;
 	set_owner(owner);
 }
 
@@ -105,14 +115,14 @@ wayobj_t::~wayobj_t()
 	if( gr ) {
 		for( uint8 i = 0; i < 4; i++ ) {
 			// Remove ribis from adjacent wayobj.
-			if( ribi_t::nsew[i] & get_dir() ) {
+			if( ribi_t::nesw[i] & get_dir() ) {
 				grund_t *next_gr;
-				if( gr->get_neighbour( next_gr, desc->get_wtyp(), ribi_t::nsew[i] ) ) {
+				if( gr->get_neighbour( next_gr, desc->get_wtyp(), ribi_t::nesw[i] ) ) {
 					wayobj_t *wo2 = next_gr->get_wayobj( desc->get_wtyp() );
 					if( wo2 ) {
 						wo2->mark_image_dirty( wo2->get_front_image(), 0 );
 						wo2->mark_image_dirty( wo2->get_image(), 0 );
-						wo2->set_dir( wo2->get_dir() & ~ribi_t::backward(ribi_t::nsew[i]) );
+						wo2->set_dir( wo2->get_dir() & ~ribi_t::backward(ribi_t::nesw[i]) );
 						wo2->mark_image_dirty( wo2->get_front_image(), 0 );
 						wo2->mark_image_dirty( wo2->get_image(), 0 );
 						wo2->set_flag(obj_t::dirty);
@@ -177,7 +187,7 @@ void wayobj_t::cleanup(player_t *player)
 // players can remove public owned wayobjs
 const char *wayobj_t::is_deletable(const player_t *player)
 {
-	if(  get_player_nr()==welt->get_public_player()->get_player_nr()  ) {
+	if(  get_owner_nr()==PUBLIC_PLAYER_NR  ) {
 		return NULL;
 	}
 	return obj_t::is_deletable(player);
@@ -315,7 +325,7 @@ void wayobj_t::calc_image()
 					grund_t *to;
 					rekursion++;
 					for(int r = 0; r < 4; r++) {
-						if(gr->get_neighbour(to, wt, ribi_t::nsew[r])) {
+						if(gr->get_neighbour(to, wt, ribi_t::nesw[r])) {
 							wayobj_t* wo = to->get_wayobj( wt );
 							if(wo) {
 								wo->calc_image();
@@ -381,14 +391,14 @@ void wayobj_t::extend_wayobj(koord3d pos, player_t *owner, ribi_t::ribi dir, con
 
 		for( uint8 i = 0; i < 4; i++ ) {
 		// Extend wayobjects around the new one, that aren't already connected.
-			if( ribi_t::nsew[i] & ~wo->get_dir() ) {
+			if( ribi_t::nesw[i] & ~wo->get_dir() ) {
 				grund_t *next_gr;
-				if( gr->get_neighbour( next_gr, desc->get_wtyp(), ribi_t::nsew[i] ) ) {
+				if( gr->get_neighbour( next_gr, desc->get_wtyp(), ribi_t::nesw[i] ) ) {
 					wayobj_t *wo2 = next_gr->get_wayobj( desc->get_wtyp() );
 					if( wo2 ) {
-						wo2->set_dir( wo2->get_dir() | ribi_t::backward(ribi_t::nsew[i]) );
+						wo2->set_dir( wo2->get_dir() | ribi_t::backward(ribi_t::nesw[i]) );
 						wo2->mark_image_dirty( wo2->get_front_image(), 0 );
-						wo->set_dir( wo->get_dir() | ribi_t::nsew[i] );
+						wo->set_dir( wo->get_dir() | ribi_t::nesw[i] );
 						wo->mark_image_dirty( wo->get_front_image(), 0 );
 					}
 				}
