@@ -67,21 +67,22 @@ public:
 		luft           = air_wt,
 		narrowgauge    = narrowgauge_wt,
 		leitung        = powerline_wt,
-		river          = 127,
-		bautyp_mask    = 255,
-		bot_flag       = 0x100, // do not connect to other ways
-		elevated_flag  = 0x200, // elevated structure
-		terraform_flag = 0x400,
-		tunnel_flag    = 0x800  // underground structure
+		river          = 0x7F,
+		bautyp_mask    = 0xFF,
+
+		bot_flag       = 1 << 8,  // do not connect to other ways
+		elevated_flag  = 1 << 9,  // elevated structure
+		terraform_flag = 1 << 10,
+		tunnel_flag    = 1 << 11  // underground structure
 	};
 
 private:
 	/// flags used in intern_calc_route, saved in the otherwise unused route_t::ANode->count
 	enum build_type_t {
-		build_straight      = 1, ///< next step has to be straight
-		terraform           = 2, ///< terraform this tile
-		build_tunnel_bridge = 4, ///< bridge/tunnel ends here
-		is_upperlayer       = 8  ///< only used when elevated  true:upperlayer
+		build_straight      = 1 << 0, ///< next step has to be straight
+		terraform           = 1 << 1, ///< terraform this tile
+		build_tunnel_bridge = 1 << 2, ///< bridge/tunnel ends here
+		is_upperlayer       = 1 << 3  ///< only used when elevated  true:upperlayer
 	};
 
 	struct next_gr_t
