@@ -1,9 +1,10 @@
 /*
- * This file is part of the Simutrans project under the artistic licence.
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
  */
 
-#ifndef boden_wege_maglev_h
-#define boden_wege_maglev_h
+#ifndef BODEN_WEGE_MAGLEV_H
+#define BODEN_WEGE_MAGLEV_H
 
 
 #include "schiene.h"
@@ -21,7 +22,6 @@ public:
 
 	/**
 	 * File loading constructor.
-	 * @author prissi
 	 */
 	maglev_t(loadsave_t *file);
 
