@@ -20,7 +20,7 @@
 #include "../../simworld.h"
 #include "../../display/simimg.h"
 #include "../../simhalt.h"
-#include "../../simobj.h"
+#include "../../obj/simobj.h"
 #include "../../player/simplay.h"
 #include "../../obj/roadsign.h"
 #include "../../obj/signal.h"
@@ -114,6 +114,7 @@ const char *weg_t::waytype_to_string(waytype_t wt)
 void weg_t::set_desc(const way_desc_t *b)
 {
 	desc = b;
+
 	if(  hat_gehweg() &&  desc->get_wtyp() == road_wt  &&  desc->get_topspeed() > 50  ) {
 		max_speed = 50;
 	}
@@ -168,9 +169,9 @@ void weg_t::rdwr(loadsave_t *file)
 
 	// save owner
 	if(  file->is_version_atleast(99, 6)  ) {
-		sint8 spnum=get_player_nr();
+		sint8 spnum=get_owner_nr();
 		file->rdwr_byte(spnum);
-		set_player_nr(spnum);
+		set_owner_nr(spnum);
 	}
 
 	// all connected directions
@@ -420,9 +421,9 @@ void weg_t::calc_image()
 		return; // otherwise crashing during enlargement
 	}
 	else if(  from->ist_tunnel() &&  from->ist_karten_boden()  &&  (grund_t::underground_mode==grund_t::ugm_none || (grund_t::underground_mode==grund_t::ugm_level && from->get_hoehe()<grund_t::underground_level))  ) {
-		// in tunnel mouth, no underground mode
-		set_image(IMG_EMPTY);
-		set_foreground_image(IMG_EMPTY);
+		// handled by tunnel mouth, no underground mode
+//		set_image(IMG_EMPTY);
+//		set_foreground_image(IMG_EMPTY);
 	}
 	else if(  from->ist_bruecke()  &&  from->obj_bei(0)==this  ) {
 		// first way on a bridge (bruecke_t will set the image)
@@ -454,7 +455,7 @@ void weg_t::calc_image()
 			if(recursion == 0) {
 				recursion++;
 				for(int r = 0; r < 4; r++) {
-					if(  from->get_neighbour(to, get_waytype(), ribi_t::nsew[r])  ) {
+					if(  from->get_neighbour(to, get_waytype(), ribi_t::nesw[r])  ) {
 						// can fail on water tiles
 						if(  weg_t *w=to->get_weg(get_waytype())  )  {
 							// and will only change the outcome, if it has a diagonal image ...
@@ -556,7 +557,7 @@ void weg_t::finish_rd()
 // players can remove public owned ways
 const char *weg_t::is_deletable(const player_t *player)
 {
-	if(  get_player_nr()==welt->get_public_player()->get_player_nr()  ) {
+	if(  get_owner_nr()==PUBLIC_PLAYER_NR  ) {
 		return NULL;
 	}
 	return obj_t::is_deletable(player);
