@@ -1,13 +1,11 @@
 /*
- * Dialog to configure the generation of a new map
- *
- * Hj. Malthaner
- *
- * April 2000
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
  */
 
-#ifndef welt_gui_h
-#define welt_gui_h
+#ifndef GUI_WELT_H
+#define GUI_WELT_H
+
 
 #include "gui_frame.h"
 #include "components/gui_button.h"
@@ -23,8 +21,6 @@ class settings_t;
 
 /**
  * The dialog for new world generation
- *
- * @author Hj. Malthaner, Niels Roest
  */
 class welt_gui_t  :
 	public  gui_frame_t,
@@ -35,7 +31,6 @@ class welt_gui_t  :
 
 		/**
 		* Mini Map-Preview
-		* @author Hj. Malthaner
 		*/
 		array2d_tpl<PIXVAL> map;
 		scr_size            map_size;
@@ -87,7 +82,6 @@ class welt_gui_t  :
 	/**
 	* Calculates preview from height map
 	* @param filename name of heightfield file
-	* @author Hajo/prissi
 	*/
 	bool update_from_heightfield(const char *filename);
 
@@ -102,7 +96,6 @@ public:
 		/**
 		* Berechnet Preview-Karte neu. Inititialisiert RNG neu!
 		* public, because also the climate dialog need it
-		* @author Hj. Malthaner
 		*/
 		void update_preview(bool load_heightfield = false);
 		void clear_loaded_heightfield() { loaded_heightfield =0; }
@@ -111,7 +104,6 @@ public:
 		/**
 		* Set the window associated helptext
 		 * @return the filename for the helptext, or NULL
-		 * @author Hj. Malthaner
 		 */
 		const char * get_help_filename() const OVERRIDE {return "new_world.txt";}
 
@@ -126,7 +118,6 @@ public:
 		 * Draw new component. The values to be passed refer to the window
 		 * i.e. It's the screen coordinates of the window where the
 		 * component is displayed.
-		 * @author Hj. Malthaner
 		 */
 		void draw(scr_coord pos, scr_size size) OVERRIDE;
 
